@@ -4,10 +4,10 @@
      $                   WORK, NWORK, RWORK, IWORK, SELECT, RESULT,
      $                   INFO )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDU, NOUNIT, NSIZES, NTYPES, NWORK
@@ -394,10 +394,10 @@
       PARAMETER          ( MAXTYP = 21 )
 *     ..
 *     .. Local Scalars ..
-      LOGICAL            BADNN
+      LOGICAL            BADNN, MATCH
       INTEGER            I, IHI, IINFO, ILO, IMODE, IN, ITYPE, J, JCOL,
-     $                   JSIZE, JTYPE, MTYPES, N, N1, NERRS, NMATS,
-     $                   NMAX, NTEST, NTESTT
+     $                   JJ, JSIZE, JTYPE, K, MTYPES, N, N1, NERRS,
+     $                   NMATS, NMAX, NTEST, NTESTT
       REAL               ANINV, ANORM, COND, CONDS, OVFL, RTOVFL, RTULP,
      $                   RTULPI, RTUNFL, TEMP1, TEMP2, ULP, ULPINV, UNFL
 *     ..
@@ -414,8 +414,8 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           CCOPY, CGEHRD, CGEMM, CGET10, CGET22, CHSEIN,
-     $                   CHSEQR, CHST01, CLACPY, CLATME, CLATMR, CLATMS,
-     $                   CLASET, CTREVC, CUNGHR, CUNMHR, SLABAD, SLAFTS,
+     $                   CHSEQR, CHST01, CLACPY, CLASET, CLATME, CLATMR,
+     $                   CLATMS, CTREVC, CUNGHR, CUNMHR, SLABAD, SLAFTS,
      $                   SLASUM, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
@@ -489,7 +489,7 @@
       NERRS = 0
       NMATS = 0
 *
-      DO 200 JSIZE = 1, NSIZES
+      DO 260 JSIZE = 1, NSIZES
          N = NN( JSIZE )
          N1 = MAX( 1, N )
          ANINV = ONE / REAL( N1 )
@@ -500,9 +500,9 @@
             MTYPES = MIN( MAXTYP+1, NTYPES )
          END IF
 *
-         DO 190 JTYPE = 1, MTYPES
+         DO 250 JTYPE = 1, MTYPES
             IF( .NOT.DOTYPE( JTYPE ) )
-     $         GO TO 190
+     $         GO TO 250
             NMATS = NMATS + 1
             NTEST = 0
 *
@@ -685,7 +685,7 @@
                WRITE( NOUNIT, FMT = 9999 )'CGEHRD', IINFO, N, JTYPE,
      $            IOLDSD
                INFO = ABS( IINFO )
-               GO TO 180
+               GO TO 240
             END IF
 *
             DO 120 J = 1, N - 1
@@ -719,7 +719,7 @@
      $            IOLDSD
                IF( IINFO.LE.N+2 ) THEN
                   INFO = ABS( IINFO )
-                  GO TO 180
+                  GO TO 240
                END IF
             END IF
 *
@@ -733,7 +733,7 @@
                WRITE( NOUNIT, FMT = 9999 )'CHSEQR(S)', IINFO, N, JTYPE,
      $            IOLDSD
                INFO = ABS( IINFO )
-               GO TO 180
+               GO TO 240
             END IF
 *
 *           Eigenvalues (W1), Schur Form (T1), and Schur Vectors (UZ)
@@ -747,7 +747,7 @@
                WRITE( NOUNIT, FMT = 9999 )'CHSEQR(V)', IINFO, N, JTYPE,
      $            IOLDSD
                INFO = ABS( IINFO )
-               GO TO 180
+               GO TO 240
             END IF
 *
 *           Compute Z = U' UZ
@@ -790,16 +790,22 @@
 *
             NTEST = 9
             RESULT( 9 ) = ULPINV
+*
+*           Select every other eigenvector
+*
             DO 140 J = 1, N
-               SELECT( J ) = .TRUE.
+               SELECT( J ) = .FALSE.
   140       CONTINUE
-            CALL CTREVC( 'Right', 'Some', SELECT, N, T1, LDA, CDUMMA,
+            DO 150 J = 1, N, 2
+               SELECT( J ) = .TRUE.
+  150       CONTINUE
+            CALL CTREVC( 'Right', 'All', SELECT, N, T1, LDA, CDUMMA,
      $                   LDU, EVECTR, LDU, N, IN, WORK, RWORK, IINFO )
             IF( IINFO.NE.0 ) THEN
-               WRITE( NOUNIT, FMT = 9999 )'CTREVC(R)', IINFO, N, JTYPE,
-     $            IOLDSD
+               WRITE( NOUNIT, FMT = 9999 )'CTREVC(R,A)', IINFO, N,
+     $            JTYPE, IOLDSD
                INFO = ABS( IINFO )
-               GO TO 180
+               GO TO 240
             END IF
 *
 *           Test 9:  | TR - RW | / ( |T| |R| ulp )
@@ -812,20 +818,47 @@
      $            DUMMA( 2 ), N, JTYPE, IOLDSD
             END IF
 *
+*           Compute selected right eigenvectors and confirm that
+*           they agree with previous right eigenvectors
+*
+            CALL CTREVC( 'Right', 'Some', SELECT, N, T1, LDA, CDUMMA,
+     $                   LDU, EVECTL, LDU, N, IN, WORK, RWORK, IINFO )
+            IF( IINFO.NE.0 ) THEN
+               WRITE( NOUNIT, FMT = 9999 )'CTREVC(R,S)', IINFO, N,
+     $            JTYPE, IOLDSD
+               INFO = ABS( IINFO )
+               GO TO 240
+            END IF
+*
+            K = 1
+            MATCH = .TRUE.
+            DO 170 J = 1, N
+               IF( SELECT( J ) ) THEN
+                  DO 160 JJ = 1, N
+                     IF( EVECTR( JJ, J ).NE.EVECTL( JJ, K ) ) THEN
+                        MATCH = .FALSE.
+                        GO TO 180
+                     END IF
+  160             CONTINUE
+                  K = K + 1
+               END IF
+  170       CONTINUE
+  180       CONTINUE
+            IF( .NOT.MATCH )
+     $         WRITE( NOUNIT, FMT = 9997 )'Right', 'CTREVC', N, JTYPE,
+     $         IOLDSD
+*
 *           Compute the Left eigenvector Matrix:
 *
             NTEST = 10
             RESULT( 10 ) = ULPINV
-            DO 150 J = 1, N
-               SELECT( J ) = .TRUE.
-  150       CONTINUE
-            CALL CTREVC( 'Left', 'Some', SELECT, N, T1, LDA, EVECTL,
-     $                   LDU, CDUMMA, LDU, N, IN, WORK, RWORK, IINFO )
+            CALL CTREVC( 'Left', 'All', SELECT, N, T1, LDA, EVECTL, LDU,
+     $                   CDUMMA, LDU, N, IN, WORK, RWORK, IINFO )
             IF( IINFO.NE.0 ) THEN
-               WRITE( NOUNIT, FMT = 9999 )'CTREVC(L)', IINFO, N, JTYPE,
-     $            IOLDSD
+               WRITE( NOUNIT, FMT = 9999 )'CTREVC(L,A)', IINFO, N,
+     $            JTYPE, IOLDSD
                INFO = ABS( IINFO )
-               GO TO 180
+               GO TO 240
             END IF
 *
 *           Test 10:  | LT - WL | / ( |T| |L| ulp )
@@ -838,13 +871,43 @@
      $            N, JTYPE, IOLDSD
             END IF
 *
+*           Compute selected left eigenvectors and confirm that
+*           they agree with previous left eigenvectors
+*
+            CALL CTREVC( 'Left', 'Some', SELECT, N, T1, LDA, EVECTR,
+     $                   LDU, CDUMMA, LDU, N, IN, WORK, RWORK, IINFO )
+            IF( IINFO.NE.0 ) THEN
+               WRITE( NOUNIT, FMT = 9999 )'CTREVC(L,S)', IINFO, N,
+     $            JTYPE, IOLDSD
+               INFO = ABS( IINFO )
+               GO TO 240
+            END IF
+*
+            K = 1
+            MATCH = .TRUE.
+            DO 200 J = 1, N
+               IF( SELECT( J ) ) THEN
+                  DO 190 JJ = 1, N
+                     IF( EVECTL( JJ, J ).NE.EVECTR( JJ, K ) ) THEN
+                        MATCH = .FALSE.
+                        GO TO 210
+                     END IF
+  190             CONTINUE
+                  K = K + 1
+               END IF
+  200       CONTINUE
+  210       CONTINUE
+            IF( .NOT.MATCH )
+     $         WRITE( NOUNIT, FMT = 9997 )'Left', 'CTREVC', N, JTYPE,
+     $         IOLDSD
+*
 *           Call CHSEIN for Right eigenvectors of H, do test 11
 *
             NTEST = 11
             RESULT( 11 ) = ULPINV
-            DO 160 J = 1, N
+            DO 220 J = 1, N
                SELECT( J ) = .TRUE.
-  160       CONTINUE
+  220       CONTINUE
 *
             CALL CHSEIN( 'Right', 'Qr', 'Ninitv', SELECT, N, H, LDA, W3,
      $                   CDUMMA, LDU, EVECTX, LDU, N1, IN, WORK, RWORK,
@@ -854,7 +917,7 @@
      $            IOLDSD
                INFO = ABS( IINFO )
                IF( IINFO.LT.0 )
-     $            GO TO 180
+     $            GO TO 240
             ELSE
 *
 *              Test 11:  | HX - XW | / ( |H| |X| ulp )
@@ -875,9 +938,9 @@
 *
             NTEST = 12
             RESULT( 12 ) = ULPINV
-            DO 170 J = 1, N
+            DO 230 J = 1, N
                SELECT( J ) = .TRUE.
-  170       CONTINUE
+  230       CONTINUE
 *
             CALL CHSEIN( 'Left', 'Qr', 'Ninitv', SELECT, N, H, LDA, W3,
      $                   EVECTY, LDU, CDUMMA, LDU, N1, IN, WORK, RWORK,
@@ -887,7 +950,7 @@
      $            IOLDSD
                INFO = ABS( IINFO )
                IF( IINFO.LT.0 )
-     $            GO TO 180
+     $            GO TO 240
             ELSE
 *
 *              Test 12:  | YH - WY | / ( |H| |Y| ulp )
@@ -916,7 +979,7 @@
      $            IOLDSD
                INFO = ABS( IINFO )
                IF( IINFO.LT.0 )
-     $            GO TO 180
+     $            GO TO 240
             ELSE
 *
 *              Test 13:  | AX - XW | / ( |A| |X| ulp )
@@ -941,7 +1004,7 @@
      $            IOLDSD
                INFO = ABS( IINFO )
                IF( IINFO.LT.0 )
-     $            GO TO 180
+     $            GO TO 240
             ELSE
 *
 *              Test 14:  | YA - WY | / ( |A| |Y| ulp )
@@ -956,14 +1019,14 @@
 *
 *           End of Loop -- Check for RESULT(j) > THRESH
 *
-  180       CONTINUE
+  240       CONTINUE
 *
             NTESTT = NTESTT + NTEST
             CALL SLAFTS( 'CHS', N, N, JTYPE, NTEST, RESULT, IOLDSD,
      $                   THRESH, NOUNIT, NERRS )
 *
-  190    CONTINUE
-  200 CONTINUE
+  250    CONTINUE
+  260 CONTINUE
 *
 *     Summary
 *
@@ -977,6 +1040,9 @@
      $      'normalized.', / ' Bits of error=', 0P, G10.3, ',', 9X,
      $      'N=', I6, ', JTYPE=', I6, ', ISEED=(', 3( I5, ',' ), I5,
      $      ')' )
+ 9997 FORMAT( ' CCHKHS: Selected ', A, ' Eigenvectors from ', A,
+     $      ' do not match other eigenvectors ', 9X, 'N=', I6,
+     $      ', JTYPE=', I6, ', ISEED=(', 3( I5, ',' ), I5, ')' )
 *
 *     End of CCHKHS
 *
