@@ -1,15 +1,17 @@
       SUBROUTINE CCHKST( NSIZES, NN, NTYPES, DOTYPE, ISEED, THRESH,
      $                   NOUNIT, A, LDA, AP, SD, SE, D1, D2, D3, D4, D5,
      $                   WA1, WA2, WA3, WR, U, LDU, V, VP, TAU, Z, WORK,
-     $                   LWORK, RWORK, IWORK, RESULT, INFO )
+     $                   LWORK, RWORK, LRWORK, IWORK, LIWORK, RESULT,
+     $                   INFO )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
-      INTEGER            INFO, LDA, LDU, LWORK, NOUNIT, NSIZES, NTYPES
+      INTEGER            INFO, LDA, LDU, LIWORK, LRWORK, LWORK, NOUNIT,
+     $                   NSIZES, NTYPES
       REAL               THRESH
 *     ..
 *     .. Array Arguments ..
@@ -25,7 +27,7 @@
 *  Purpose
 *  =======
 *
-*  CCHKST  checks the (complex) hermitian eigenvalue problem routines.
+*  CCHKST  checks the Hermitian eigenvalue problem routines.
 *
 *     CHETRD factors A as  U S U* , where * means conjugate transpose,
 *     S is real symmetric tridiagonal, and U is unitary.
@@ -51,7 +53,7 @@
 *     PWK method, which does not yield eigenvectors.
 *
 *     CPTEQR factors S as  Z4 D4 Z4* , for a
-*     hermitian positive definite tridiagonal matrix.
+*     Hermitian positive definite tridiagonal matrix.
 *     D5 is the matrix of eigenvalues computed when Z is not
 *     computed.
 *
@@ -64,78 +66,130 @@
 *     CSTEIN computes Y, the eigenvectors of S, given the
 *     eigenvalues.
 *
-*     CSTEDC factors S as Z D1 Z' , where Z is the
+*     CSTEDC factors S as Z D1 Z* , where Z is the unitary
 *     matrix of eigenvectors and D1 is a diagonal matrix with
 *     the eigenvalues on the diagonal ('I' option). It may also
 *     update an input unitary matrix, usually the output
 *     from CHETRD/CUNGTR or CHPTRD/CUPGTR ('V' option). It may
 *     also just compute eigenvalues ('N' option).
 *
+*     CSTEGR factors S as Z D1 Z* , where Z is the unitary
+*     matrix of eigenvectors and D1 is a diagonal matrix with
+*     the eigenvalues on the diagonal ('I' option).  CSTEGR
+*     uses the Relatively Robust Representation whenever possible.
+*
 *  When CCHKST is called, a number of matrix "sizes" ("n's") and a
 *  number of matrix "types" are specified.  For each size ("n")
 *  and each type of matrix, one matrix will be generated and used
-*  to test the hermitian eigenroutines.  For each matrix, a number
+*  to test the Hermitian eigenroutines.  For each matrix, a number
 *  of tests will be performed:
 *
-*  (1)     | A - V S V* | / ( |A| n ulp )  computed by CHETRD with
-*                                          UPLO='U'
+*  (1)     | A - V S V* | / ( |A| n ulp ) CHETRD( UPLO='U', ... )
 *
-*  (2)     | I - UV* | / ( n ulp )         test of CUNGTR w/ UPLO='U'
+*  (2)     | I - UV* | / ( n ulp )        CUNGTR( UPLO='U', ... )
 *
-*  (3)     | A - V S V* | / ( |A| n ulp )  computed by CHETRD with
-*                                          UPLO='L'
+*  (3)     | A - V S V* | / ( |A| n ulp ) CHETRD( UPLO='L', ... )
 *
-*  (4)     | I - UV* | / ( n ulp )         test of CUNGTR w/ UPLO='L'
+*  (4)     | I - UV* | / ( n ulp )        CUNGTR( UPLO='L', ... )
 *
 *  (5-8)   Same as 1-4, but for CHPTRD and CUPGTR.
 *
-*  (9)     | S - Z D Z* | / ( |S| n ulp )
+*  (9)     | S - Z D Z* | / ( |S| n ulp ) CSTEQR('V',...)
 *
-*  (10)    | I - ZZ* | / ( n ulp )
+*  (10)    | I - ZZ* | / ( n ulp )        CSTEQR('V',...)
 *
-*  (11)    | D1 - D2 | / ( |D1| ulp )
+*  (11)    | D1 - D2 | / ( |D1| ulp )        CSTEQR('N',...)
 *
-*  (12)    | D1 - D3 | / ( |D1| ulp )
+*  (12)    | D1 - D3 | / ( |D1| ulp )        SSTERF
 *
-*  (13)    0 if the true eigenvalues of S are within THRESH of
+*  (13)    0 if the true eigenvalues (computed by sturm count)
+*          of S are within THRESH of
 *          those in D1.  2*THRESH if they are not.  (Tested using
 *          SSTECH)
 *
 *  For S positive definite,
 *
-*  (14)    | S - Z4 D4 Z4* | / ( |S| n ulp )
+*  (14)    | S - Z4 D4 Z4* | / ( |S| n ulp ) CPTEQR('V',...)
 *
-*  (15)    | I - Z4 Z4* | / ( n ulp )
+*  (15)    | I - Z4 Z4* | / ( n ulp )        CPTEQR('V',...)
 *
-*  (16)    | D4 - D5 | / ( 100 |D4| ulp )
+*  (16)    | D4 - D5 | / ( 100 |D4| ulp )       CPTEQR('N',...)
 *
 *  When S is also diagonally dominant by the factor gamma < 1,
 *
 *  (17)    max | D4(i) - WR(i) | / ( |D4(i)| omega ) ,
 *           i
 *          omega = 2 (2n-1) ULP (1 + 8 gamma**2) / (1 - gamma)**4
+*                                               SSTEBZ( 'A', 'E', ...)
 *
-*  (18)    | WA1 - D3 | / ( |D3| ulp )
+*  (18)    | WA1 - D3 | / ( |D3| ulp )          SSTEBZ( 'A', 'E', ...)
 *
 *  (19)    ( max { min | WA2(i)-WA3(j) | } +
 *             i     j
 *            max { min | WA3(i)-WA2(j) | } ) / ( |D3| ulp )
 *             i     j
+*                                               SSTEBZ( 'I', 'E', ...)
 *
-*  (20)    | S - Y WA1 Y* | / ( |S| n ulp )
+*  (20)    | S - Y WA1 Y* | / ( |S| n ulp )  SSTEBZ, CSTEIN
 *
-*  (21)    | I - Y Y* | / ( n ulp )
+*  (21)    | I - Y Y* | / ( n ulp )          SSTEBZ, CSTEIN
 *
-*  (22)    | S - Y D Y* | / ( |S| n ulp ) for CSTEDC('I')
+*  (22)    | S - Z D Z* | / ( |S| n ulp )    CSTEDC('I')
 *
-*  (23)    | I - YY* | / ( n ulp ) for CSTEDC('I')
+*  (23)    | I - ZZ* | / ( n ulp )           CSTEDC('I')
 *
-*  (24)    | S - Y D Y* | / ( |S| n ulp ) for CSTEDC('V')
+*  (24)    | S - Z D Z* | / ( |S| n ulp )    CSTEDC('V')
 *
-*  (25)    | I - YY*' | / ( n ulp ) for CSTEDC('V')
+*  (25)    | I - ZZ* | / ( n ulp )           CSTEDC('V')
 *
-*  (26)    | D1 - D2 | / ( |D1| ulp ) for CSTEDC('V') and CSTEDC('N')
+*  (26)    | D1 - D2 | / ( |D1| ulp )           CSTEDC('V') and
+*                                               CSTEDC('N')
 *
+*  Test 27 is disabled at the moment because CSTEGR does not
+*  guarantee high relatvie accuracy.
+*
+*  (27)    max | D6(i) - WR(i) | / ( |D6(i)| omega ) ,
+*           i
+*          omega = 2 (2n-1) ULP (1 + 8 gamma**2) / (1 - gamma)**4
+*                                               CSTEGR('V', 'A')
+*
+*  (28)    max | D6(i) - WR(i) | / ( |D6(i)| omega ) ,
+*           i
+*          omega = 2 (2n-1) ULP (1 + 8 gamma**2) / (1 - gamma)**4
+*                                               CSTEGR('V', 'I')
+*
+*  Tests 29 through 34 are disable at present because @9pre)STEGR
+*  does not handle partial specturm requests.
+*
+*  (29)    | S - Z D Z* | / ( |S| n ulp )    CSTEGR('V', 'I')
+*
+*  (30)    | I - ZZ* | / ( n ulp )           CSTEGR('V', 'I')
+*
+*  (31)    ( max { min | WA2(i)-WA3(j) | } +
+*             i     j
+*            max { min | WA3(i)-WA2(j) | } ) / ( |D3| ulp )
+*             i     j
+*          CSTEGR('N', 'I') vs. CSTEGR('V', 'I')
+*
+*  (32)    | S - Z D Z* | / ( |S| n ulp )    CSTEGR('V', 'V')
+*
+*  (33)    | I - ZZ* | / ( n ulp )           CSTEGR('V', 'V')
+*
+*  (34)    ( max { min | WA2(i)-WA3(j) | } +
+*             i     j
+*            max { min | WA3(i)-WA2(j) | } ) / ( |D3| ulp )
+*             i     j
+*          CSTEGR('N', 'V') vs. CSTEGR('V', 'V')
+*
+*  (35)    | S - Z D Z* | / ( |S| n ulp )    CSTEGR('V', 'A')
+*
+*  (36)    | I - ZZ* | / ( n ulp )           CSTEGR('V', 'A')
+*
+*  (37)    ( max { min | WA2(i)-WA3(j) | } +
+*             i     j
+*            max { min | WA3(i)-WA2(j) | } ) / ( |D3| ulp )
+*             i     j
+*          CSTEGR('N', 'A') vs. CSTEGR('V', 'A')
 *
 *  The "sizes" are specified by an array NN(1:NSIZES); the value of
 *  each element NN(j) specifies one size.
@@ -311,7 +365,7 @@
 *          The unitary matrix of eigenvectors computed by CSTEQR,
 *          CPTEQR, and CSTEIN.
 *
-*  WORK    (workspace) COMPLEX array of
+*  WORK    (workspace/output) COMPLEX array of
 *                      dimension( LWORK )
 *
 *  LWORK   (input) INTEGER
@@ -319,12 +373,12 @@
 *          1 + 4 * Nmax + 2 * Nmax * lg Nmax + 3 * Nmax**2
 *          where Nmax = max( NN(j), 2 ) and lg = log base 2.
 *
-*  IWORK   (workspace) INTEGER array,
+*  IWORK   (workspace/output) INTEGER array,
 *             dimension (6 + 6*Nmax + 5 * Nmax * lg Nmax )
 *          where Nmax = max( NN(j), 2 ) and lg = log base 2.
 *          Workspace.
 *
-*  RWORK   (workspace) REAL array of
+*  RWORK   (workspace/output) REAL array of
 *                      dimension( ??? )
 *
 *  RESULT  (output) REAL array, dimension (26)
@@ -341,7 +395,7 @@
 *           -9: LDA < 1 or LDA < NMAX, where NMAX is max( NN(j) ).
 *          -23: LDU < 1 or LDU < NMAX.
 *          -29: LWORK too small.
-*          If  CLATMR, SLATMS, CHETRD, CUNGTR, CSTEQR, SSTERF,
+*          If  CLATMR, CLATMS, CHETRD, CUNGTR, CSTEQR, SSTERF,
 *              or CUNMC2 returns an error code, the
 *              absolute value of it is returned.
 *
@@ -376,15 +430,19 @@
 *
 *     .. Parameters ..
       REAL               ZERO, ONE, TWO, EIGHT, TEN, HUN
-      PARAMETER          ( ZERO = 0.0E+0, ONE = 1.0E+0, TWO = 2.0E+0,
-     $                   EIGHT = 8.0E+0, TEN = 10.0E+0, HUN = 100.0E+0 )
-      REAL               HALF
-      PARAMETER          ( HALF = ONE / TWO )
+      PARAMETER          ( ZERO = 0.0E0, ONE = 1.0E0, TWO = 2.0E0,
+     $                   EIGHT = 8.0E0, TEN = 10.0E0, HUN = 100.0E0 )
       COMPLEX            CZERO, CONE
       PARAMETER          ( CZERO = ( 0.0E+0, 0.0E+0 ),
      $                   CONE = ( 1.0E+0, 0.0E+0 ) )
+      REAL               HALF
+      PARAMETER          ( HALF = ONE / TWO )
       INTEGER            MAXTYP
       PARAMETER          ( MAXTYP = 21 )
+      LOGICAL            CRANGE
+      PARAMETER          ( CRANGE = .FALSE. )
+      LOGICAL            CREL
+      PARAMETER          ( CREL = .FALSE. )
 *     ..
 *     .. Local Scalars ..
       LOGICAL            BADNN
@@ -410,22 +468,27 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           CCOPY, CHET21, CHETRD, CHPT21, CHPTRD, CLACPY,
-     $                   CLASET, CLATMR, CLATMS, CPTEQR, CSTEDC, CSTEIN,
-     $                   CSTEQR, CSTT21, CUNGTR, CUPGTR, SCOPY, SLABAD,
-     $                   SLASUM, SSTEBZ, SSTECH, SSTERF, XERBLA
+     $                   CLASET, CLATMR, CLATMS, CPTEQR, CSTEDC, CSTEGR,
+     $                   CSTEIN, CSTEQR, CSTT21, CSTT22, CUNGTR, CUPGTR,
+     $                   SCOPY, SLABAD, SLASUM, SSTEBZ, SSTECH, SSTERF,
+     $                   XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, CONJG, INT, LOG, MAX, MIN, REAL, SQRT
 *     ..
 *     .. Data statements ..
-      DATA               KTYPE / 1, 2, 5*4, 5*5, 3*8, 5*9, 10 /
-      DATA               KMAGN / 2*1, 1, 1, 1, 2, 3, 1, 1, 1, 2, 3, 1,
-     $                   2, 3, 3*1, 2, 3, 1 /
-      DATA               KMODE / 2*0, 4, 3, 1, 4, 4, 4, 3, 1, 4, 4, 0,
+      DATA               KTYPE / 1, 2, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 8,
+     $                   8, 8, 9, 9, 9, 9, 9, 10 /
+      DATA               KMAGN / 1, 1, 1, 1, 1, 2, 3, 1, 1, 1, 2, 3, 1,
+     $                   2, 3, 1, 1, 1, 2, 3, 1 /
+      DATA               KMODE / 0, 0, 4, 3, 1, 4, 4, 4, 3, 1, 4, 4, 0,
      $                   0, 0, 4, 3, 1, 4, 4, 3 /
 *     ..
 *     .. Executable Statements ..
 *
+*     Keep ftnchek happy
+      IDUMMA( 1 ) = 1
+*
 *     Check for errors
 *
       NTESTT = 0
@@ -465,7 +528,7 @@
          RETURN
       END IF
 *
-*     Quick return if nothing to do
+*     Quick return if possible
 *
       IF( NSIZES.EQ.0 .OR. NTYPES.EQ.0 )
      $   RETURN
@@ -489,7 +552,7 @@
       NERRS = 0
       NMATS = 0
 *
-      DO 250 JSIZE = 1, NSIZES
+      DO 310 JSIZE = 1, NSIZES
          N = NN( JSIZE )
          IF( N.GT.0 ) THEN
             LGN = INT( LOG( REAL( N ) ) / LOG( TWO ) )
@@ -514,9 +577,9 @@
             MTYPES = MIN( MAXTYP+1, NTYPES )
          END IF
 *
-         DO 240 JTYPE = 1, MTYPES
+         DO 300 JTYPE = 1, MTYPES
             IF( .NOT.DOTYPE( JTYPE ) )
-     $         GO TO 240
+     $         GO TO 300
             NMATS = NMATS + 1
             NTEST = 0
 *
@@ -533,10 +596,10 @@
 *           =2  large  clustered 2  identity
 *           =3  small  exponential  (none)
 *           =4         arithmetic   diagonal, (w/ eigenvalues)
-*           =5         random log   hermitian, w/ eigenvalues
+*           =5         random log   Hermitian, w/ eigenvalues
 *           =6         random       (none)
 *           =7                      random diagonal
-*           =8                      random hermitian
+*           =8                      random Hermitian
 *           =9                      positive definite
 *           =10                     diagonally dominant tridiagonal
 *
@@ -593,6 +656,7 @@
 *
                CALL CLATMS( N, N, 'S', ISEED, 'H', RWORK, IMODE, COND,
      $                      ANORM, 0, 0, 'N', A, LDA, WORK, IINFO )
+*
 *
             ELSE IF( ITYPE.EQ.5 ) THEN
 *
@@ -673,7 +737,7 @@
                   RETURN
                ELSE
                   RESULT( 1 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -689,7 +753,7 @@
                   RETURN
                ELSE
                   RESULT( 2 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -717,7 +781,7 @@
                   RETURN
                ELSE
                   RESULT( 3 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -733,7 +797,7 @@
                   RETURN
                ELSE
                   RESULT( 4 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -767,7 +831,7 @@
                   RETURN
                ELSE
                   RESULT( 5 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -781,7 +845,7 @@
                   RETURN
                ELSE
                   RESULT( 6 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -817,7 +881,7 @@
                   RETURN
                ELSE
                   RESULT( 7 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -831,7 +895,7 @@
                   RETURN
                ELSE
                   RESULT( 8 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -860,7 +924,7 @@
                   RETURN
                ELSE
                   RESULT( 9 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -881,7 +945,7 @@
                   RETURN
                ELSE
                   RESULT( 11 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -901,7 +965,7 @@
                   RETURN
                ELSE
                   RESULT( 12 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -966,7 +1030,7 @@
                      RETURN
                   ELSE
                      RESULT( 14 ) = ULPINV
-                     GO TO 220
+                     GO TO 280
                   END IF
                END IF
 *
@@ -992,7 +1056,7 @@
                      RETURN
                   ELSE
                      RESULT( 16 ) = ULPINV
-                     GO TO 220
+                     GO TO 280
                   END IF
                END IF
 *
@@ -1036,7 +1100,7 @@
                      RETURN
                   ELSE
                      RESULT( 17 ) = ULPINV
-                     GO TO 220
+                     GO TO 280
                   END IF
                END IF
 *
@@ -1071,7 +1135,7 @@
                   RETURN
                ELSE
                   RESULT( 18 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -1094,8 +1158,8 @@
                IL = 1
                IU = N
             ELSE
-               IL = 1 + ( N-1 )*SLARND( 1, ISEED2 )
-               IU = 1 + ( N-1 )*SLARND( 1, ISEED2 )
+               IL = 1 + ( N-1 )*INT( SLARND( 1, ISEED2 ) )
+               IU = 1 + ( N-1 )*INT( SLARND( 1, ISEED2 ) )
                IF( IU.LT.IL ) THEN
                   ITEMP = IU
                   IU = IL
@@ -1114,7 +1178,7 @@
                   RETURN
                ELSE
                   RESULT( 19 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -1152,13 +1216,13 @@
                   RETURN
                ELSE
                   RESULT( 19 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
             IF( M3.EQ.0 .AND. N.NE.0 ) THEN
                RESULT( 19 ) = ULPINV
-               GO TO 220
+               GO TO 280
             END IF
 *
 *           Do test 19
@@ -1190,7 +1254,7 @@
                ELSE
                   RESULT( 20 ) = ULPINV
                   RESULT( 21 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -1206,7 +1270,7 @@
                ELSE
                   RESULT( 20 ) = ULPINV
                   RESULT( 21 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -1237,7 +1301,7 @@
                   RETURN
                ELSE
                   RESULT( 22 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -1266,7 +1330,7 @@
                   RETURN
                ELSE
                   RESULT( 24 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -1295,7 +1359,7 @@
                   RETURN
                ELSE
                   RESULT( 26 ) = ULPINV
-                  GO TO 220
+                  GO TO 280
                END IF
             END IF
 *
@@ -1311,14 +1375,359 @@
 *
             RESULT( 26 ) = TEMP2 / MAX( UNFL, ULP*MAX( TEMP1, TEMP2 ) )
 *
+*           Only test CSTEGR if IEEE compliant
+*
+            IF( ILAENV( 10, 'CSTEGR', 'VA', 1, 0, 0, 0 ).EQ.1 .AND.
+     $          ILAENV( 11, 'CSTEGR', 'VA', 1, 0, 0, 0 ).EQ.1 ) THEN
+*
+*           Call CSTEGR, do test 27 (relative eigenvalue accuracy)
+*
+*              If S is positive definite and diagonally dominant,
+*              ask for all eigenvalues with high relative accuracy.
+*
+               VL = ZERO
+               VU = ZERO
+               IL = 0
+               IU = 0
+               IF( JTYPE.EQ.21 .AND. CREL ) THEN
+                  NTEST = 27
+                  ABSTOL = UNFL + UNFL
+                  CALL CSTEGR( 'V', 'A', N, SD, SE, VL, VU, IL, IU,
+     $                         ABSTOL, M, WR, Z, LDU, IWORK( 1 ), RWORK,
+     $                         LRWORK, IWORK( 2*N+1 ), LWORK-2*N,
+     $                         IINFO )
+                  IF( IINFO.NE.0 ) THEN
+                     WRITE( NOUNIT, FMT = 9999 )'CSTEGR(V,A,rel)',
+     $                  IINFO, N, JTYPE, IOLDSD
+                     INFO = ABS( IINFO )
+                     IF( IINFO.LT.0 ) THEN
+                        RETURN
+                     ELSE
+                        RESULT( 27 ) = ULPINV
+                        GO TO 270
+                     END IF
+                  END IF
+*
+*              Do test 27
+*
+                  TEMP2 = TWO*( TWO*N-ONE )*ULP*( ONE+EIGHT*HALF**2 ) /
+     $                    ( ONE-HALF )**4
+*
+                  TEMP1 = ZERO
+                  DO 220 J = 1, N
+                     TEMP1 = MAX( TEMP1, ABS( D4( J )-WR( N-J+1 ) ) /
+     $                       ( ABSTOL+ABS( D4( J ) ) ) )
+  220             CONTINUE
+*
+                  RESULT( 27 ) = TEMP1 / TEMP2
+*
+                  IL = 1 + ( N-1 )*INT( SLARND( 1, ISEED2 ) )
+                  IU = 1 + ( N-1 )*INT( SLARND( 1, ISEED2 ) )
+                  IF( IU.LT.IL ) THEN
+                     ITEMP = IU
+                     IU = IL
+                     IL = ITEMP
+                  END IF
+*
+                  IF( CRANGE ) THEN
+                     NTEST = 28
+                     ABSTOL = UNFL + UNFL
+                     CALL CSTEGR( 'V', 'I', N, SD, SE, VL, VU, IL, IU,
+     $                            ABSTOL, M, WR, Z, LDU, IWORK( 1 ),
+     $                            RWORK, LRWORK, IWORK( 2*N+1 ),
+     $                            LWORK-2*N, IINFO )
+*
+                     IF( IINFO.NE.0 ) THEN
+                        WRITE( NOUNIT, FMT = 9999 )'CSTEGR(V,I,rel)',
+     $                     IINFO, N, JTYPE, IOLDSD
+                        INFO = ABS( IINFO )
+                        IF( IINFO.LT.0 ) THEN
+                           RETURN
+                        ELSE
+                           RESULT( 28 ) = ULPINV
+                           GO TO 270
+                        END IF
+                     END IF
+*
+*
+*                 Do test 28
+*
+                     TEMP2 = TWO*( TWO*N-ONE )*ULP*
+     $                       ( ONE+EIGHT*HALF**2 ) / ( ONE-HALF )**4
+*
+                     TEMP1 = ZERO
+                     DO 230 J = IL, IU
+                        TEMP1 = MAX( TEMP1, ABS( WR( J-IL+1 )-D4( N-J+
+     $                          1 ) ) / ( ABSTOL+ABS( WR( J-IL+1 ) ) ) )
+  230                CONTINUE
+*
+                     RESULT( 28 ) = TEMP1 / TEMP2
+                  ELSE
+                     RESULT( 28 ) = ZERO
+                  END IF
+               ELSE
+                  RESULT( 27 ) = ZERO
+                  RESULT( 28 ) = ZERO
+               END IF
+*
+*           Call CSTEGR(V,I) to compute D1 and Z, do tests.
+*
+*           Compute D1 and Z
+*
+               CALL SCOPY( N, SD, 1, D5, 1 )
+               IF( N.GT.0 )
+     $            CALL SCOPY( N-1, SE, 1, RWORK, 1 )
+               CALL CLASET( 'Full', N, N, CZERO, CONE, Z, LDU )
+*
+               IF( CRANGE ) THEN
+                  NTEST = 29
+                  IL = 1 + ( N-1 )*INT( SLARND( 1, ISEED2 ) )
+                  IU = 1 + ( N-1 )*INT( SLARND( 1, ISEED2 ) )
+                  IF( IU.LT.IL ) THEN
+                     ITEMP = IU
+                     IU = IL
+                     IL = ITEMP
+                  END IF
+                  CALL CSTEGR( 'V', 'I', N, D5, RWORK, VL, VU, IL, IU,
+     $                         ABSTOL, M, D1, Z, LDU, IWORK( 1 ),
+     $                         RWORK( N+1 ), LRWORK-N, IWORK( 2*N+1 ),
+     $                         LIWORK-2*N, IINFO )
+                  IF( IINFO.NE.0 ) THEN
+                     WRITE( NOUNIT, FMT = 9999 )'CSTEGR(V,I)', IINFO,
+     $                  N, JTYPE, IOLDSD
+                     INFO = ABS( IINFO )
+                     IF( IINFO.LT.0 ) THEN
+                        RETURN
+                     ELSE
+                        RESULT( 29 ) = ULPINV
+                        GO TO 280
+                     END IF
+                  END IF
+*
+*           Do Tests 29 and 30
+*
+*
+*           Call CSTEGR to compute D2, do tests.
+*
+*           Compute D2
+*
+                  CALL SCOPY( N, SD, 1, D5, 1 )
+                  IF( N.GT.0 )
+     $               CALL SCOPY( N-1, SE, 1, RWORK, 1 )
+*
+                  NTEST = 31
+                  CALL CSTEGR( 'N', 'I', N, D5, RWORK, VL, VU, IL, IU,
+     $                         ABSTOL, M, D2, Z, LDU, IWORK( 1 ),
+     $                         RWORK( N+1 ), LRWORK-N, IWORK( 2*N+1 ),
+     $                         LIWORK-2*N, IINFO )
+                  IF( IINFO.NE.0 ) THEN
+                     WRITE( NOUNIT, FMT = 9999 )'CSTEGR(N,I)', IINFO,
+     $                  N, JTYPE, IOLDSD
+                     INFO = ABS( IINFO )
+                     IF( IINFO.LT.0 ) THEN
+                        RETURN
+                     ELSE
+                        RESULT( 31 ) = ULPINV
+                        GO TO 280
+                     END IF
+                  END IF
+*
+*           Do Test 31
+*
+                  TEMP1 = ZERO
+                  TEMP2 = ZERO
+*
+                  DO 240 J = 1, IU - IL + 1
+                     TEMP1 = MAX( TEMP1, ABS( D1( J ) ),
+     $                       ABS( D2( J ) ) )
+                     TEMP2 = MAX( TEMP2, ABS( D1( J )-D2( J ) ) )
+  240             CONTINUE
+*
+                  RESULT( 31 ) = TEMP2 / MAX( UNFL,
+     $                           ULP*MAX( TEMP1, TEMP2 ) )
+*
+*
+*           Call CSTEGR(V,V) to compute D1 and Z, do tests.
+*
+*           Compute D1 and Z
+*
+                  CALL SCOPY( N, SD, 1, D5, 1 )
+                  IF( N.GT.0 )
+     $               CALL SCOPY( N-1, SE, 1, RWORK, 1 )
+                  CALL CLASET( 'Full', N, N, CZERO, CONE, Z, LDU )
+*
+                  NTEST = 32
+*
+                  IF( N.GT.0 ) THEN
+                     IF( IL.NE.1 ) THEN
+                        VL = D2( IL ) - MAX( HALF*
+     $                       ( D2( IL )-D2( IL-1 ) ), ULP*ANORM,
+     $                       TWO*RTUNFL )
+                     ELSE
+                        VL = D2( 1 ) - MAX( HALF*( D2( N )-D2( 1 ) ),
+     $                       ULP*ANORM, TWO*RTUNFL )
+                     END IF
+                     IF( IU.NE.N ) THEN
+                        VU = D2( IU ) + MAX( HALF*
+     $                       ( D2( IU+1 )-D2( IU ) ), ULP*ANORM,
+     $                       TWO*RTUNFL )
+                     ELSE
+                        VU = D2( N ) + MAX( HALF*( D2( N )-D2( 1 ) ),
+     $                       ULP*ANORM, TWO*RTUNFL )
+                     END IF
+                  ELSE
+                     VL = ZERO
+                     VU = ONE
+                  END IF
+*
+                  CALL CSTEGR( 'V', 'V', N, D5, RWORK, VL, VU, IL, IU,
+     $                         ABSTOL, M, D1, Z, LDU, IWORK( 1 ),
+     $                         RWORK( N+1 ), LRWORK-N, IWORK( 2*N+1 ),
+     $                         LIWORK-2*N, IINFO )
+                  IF( IINFO.NE.0 ) THEN
+                     WRITE( NOUNIT, FMT = 9999 )'CSTEGR(V,V)', IINFO,
+     $                  N, JTYPE, IOLDSD
+                     INFO = ABS( IINFO )
+                     IF( IINFO.LT.0 ) THEN
+                        RETURN
+                     ELSE
+                        RESULT( 32 ) = ULPINV
+                        GO TO 280
+                     END IF
+                  END IF
+*
+*           Do Tests 32 and 33
+*
+                  CALL CSTT22( N, M, 0, SD, SE, D1, DUMMA, Z, LDU, WORK,
+     $                         M, RWORK, RESULT( 32 ) )
+*
+*           Call CSTEGR to compute D2, do tests.
+*
+*           Compute D2
+*
+                  CALL SCOPY( N, SD, 1, D5, 1 )
+                  IF( N.GT.0 )
+     $               CALL SCOPY( N-1, SE, 1, RWORK, 1 )
+*
+                  NTEST = 34
+                  CALL CSTEGR( 'N', 'V', N, D5, RWORK, VL, VU, IL, IU,
+     $                         ABSTOL, M, D2, Z, LDU, IWORK( 1 ),
+     $                         RWORK( N+1 ), LRWORK-N, IWORK( 2*N+1 ),
+     $                         LIWORK-2*N, IINFO )
+                  IF( IINFO.NE.0 ) THEN
+                     WRITE( NOUNIT, FMT = 9999 )'CSTEGR(N,V)', IINFO,
+     $                  N, JTYPE, IOLDSD
+                     INFO = ABS( IINFO )
+                     IF( IINFO.LT.0 ) THEN
+                        RETURN
+                     ELSE
+                        RESULT( 34 ) = ULPINV
+                        GO TO 280
+                     END IF
+                  END IF
+*
+*           Do Test 34
+*
+                  TEMP1 = ZERO
+                  TEMP2 = ZERO
+*
+                  DO 250 J = 1, IU - IL + 1
+                     TEMP1 = MAX( TEMP1, ABS( D1( J ) ),
+     $                       ABS( D2( J ) ) )
+                     TEMP2 = MAX( TEMP2, ABS( D1( J )-D2( J ) ) )
+  250             CONTINUE
+*
+                  RESULT( 34 ) = TEMP2 / MAX( UNFL,
+     $                           ULP*MAX( TEMP1, TEMP2 ) )
+               ELSE
+                  RESULT( 29 ) = ZERO
+                  RESULT( 30 ) = ZERO
+                  RESULT( 31 ) = ZERO
+                  RESULT( 32 ) = ZERO
+                  RESULT( 33 ) = ZERO
+                  RESULT( 34 ) = ZERO
+               END IF
+*
+*
+*           Call CSTEGR(V,A) to compute D1 and Z, do tests.
+*
+*           Compute D1 and Z
+*
+               CALL SCOPY( N, SD, 1, D5, 1 )
+               IF( N.GT.0 )
+     $            CALL SCOPY( N-1, SE, 1, RWORK, 1 )
+*
+               NTEST = 35
+*
+               CALL CSTEGR( 'V', 'A', N, D5, RWORK, VL, VU, IL, IU,
+     $                      ABSTOL, M, D1, Z, LDU, IWORK( 1 ),
+     $                      RWORK( N+1 ), LRWORK-N, IWORK( 2*N+1 ),
+     $                      LIWORK-2*N, IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'CSTEGR(V,A)', IINFO, N,
+     $               JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( 35 ) = ULPINV
+                     GO TO 280
+                  END IF
+               END IF
+*
+*           Do Tests 35 and 36
+*
+               CALL CSTT22( N, M, 0, SD, SE, D1, DUMMA, Z, LDU, WORK, M,
+     $                      RWORK, RESULT( 35 ) )
+*
+*           Call CSTEGR to compute D2, do tests.
+*
+*           Compute D2
+*
+               CALL SCOPY( N, SD, 1, D5, 1 )
+               IF( N.GT.0 )
+     $            CALL SCOPY( N-1, SE, 1, RWORK, 1 )
+*
+               NTEST = 37
+               CALL CSTEGR( 'N', 'A', N, D5, RWORK, VL, VU, IL, IU,
+     $                      ABSTOL, M, D2, Z, LDU, IWORK( 1 ),
+     $                      RWORK( N+1 ), LRWORK-N, IWORK( 2*N+1 ),
+     $                      LIWORK-2*N, IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'CSTEGR(N,A)', IINFO, N,
+     $               JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( 37 ) = ULPINV
+                     GO TO 280
+                  END IF
+               END IF
+*
+*           Do Test 34
+*
+               TEMP1 = ZERO
+               TEMP2 = ZERO
+*
+               DO 260 J = 1, N
+                  TEMP1 = MAX( TEMP1, ABS( D1( J ) ), ABS( D2( J ) ) )
+                  TEMP2 = MAX( TEMP2, ABS( D1( J )-D2( J ) ) )
+  260          CONTINUE
+*
+               RESULT( 37 ) = TEMP2 / MAX( UNFL,
+     $                        ULP*MAX( TEMP1, TEMP2 ) )
+            END IF
+  270       CONTINUE
+  280       CONTINUE
+            NTESTT = NTESTT + NTEST
+*
 *           End of Loop -- Check for RESULT(j) > THRESH
 *
-  220       CONTINUE
-            NTESTT = NTESTT + NTEST
 *
 *           Print out tests which fail.
 *
-            DO 230 JR = 1, NTEST
+            DO 290 JR = 1, NTEST
                IF( RESULT( JR ).GE.THRESH ) THEN
 *
 *                 If this is the first test to fail,
@@ -1328,19 +1737,15 @@
                      WRITE( NOUNIT, FMT = 9998 )'CST'
                      WRITE( NOUNIT, FMT = 9997 )
                      WRITE( NOUNIT, FMT = 9996 )
-                     WRITE( NOUNIT, FMT = 9995 )'Hermetian'
+                     WRITE( NOUNIT, FMT = 9995 )'Hermitian'
                      WRITE( NOUNIT, FMT = 9994 )
 *
 *                    Tests performed
 *
-                     WRITE( NOUNIT, FMT = 9993 )'unitary',
-     $                  '*=conjugate transpose', ( '*', J = 1, 4 )
-                     WRITE( NOUNIT, FMT = 9992 )( '*', J = 1, 6 )
-                     WRITE( NOUNIT, FMT = 9991 )( '*', J = 1, 4 )
-                     WRITE( NOUNIT, FMT = 9990 )( '''', J = 1, 4 )
+                     WRITE( NOUNIT, FMT = 9987 )
                   END IF
                   NERRS = NERRS + 1
-                  IF( RESULT( JR ).LT.10000.0 ) THEN
+                  IF( RESULT( JR ).LT.10000.0E0 ) THEN
                      WRITE( NOUNIT, FMT = 9989 )N, JTYPE, IOLDSD, JR,
      $                  RESULT( JR )
                   ELSE
@@ -1348,10 +1753,9 @@
      $                  RESULT( JR )
                   END IF
                END IF
-  230       CONTINUE
-*
-  240    CONTINUE
-  250 CONTINUE
+  290       CONTINUE
+  300    CONTINUE
+  310 CONTINUE
 *
 *     Summary
 *
@@ -1424,11 +1828,11 @@
      $      A1, ' | / ( n ulp )       for CSTEDC(V)',
      $      / ' 26= | D1(CSTEDC(V)) - D2(CSTEDC(N)) | / ( |D1| ulp )' )
  9989 FORMAT( ' Matrix order=', I5, ', type=', I2, ', seed=',
-     $      4( I4, ',' ), ' result ', I2, ' is', 0P, F8.2 )
+     $      4( I4, ',' ), ' result ', I3, ' is', 0P, F8.2 )
  9988 FORMAT( ' Matrix order=', I5, ', type=', I2, ', seed=',
-     $      4( I4, ',' ), ' result ', I2, ' is', 1P, E10.3 )
-*
+     $      4( I4, ',' ), ' result ', I3, ' is', 1P, E10.3 )
 *
+ 9987 FORMAT( / 'Test performed:  see CCHKST for details.', / )
 *     End of CCHKST
 *
       END
