@@ -1,12 +1,12 @@
       SUBROUTINE DCHKBD( NSIZES, MVAL, NVAL, NTYPES, DOTYPE, NRHS,
      $                   ISEED, THRESH, A, LDA, BD, BE, S1, S2, X, LDX,
      $                   Y, Z, Q, LDQ, PT, LDPT, U, VT, WORK, LWORK,
-     $                   NOUT, INFO )
+     $                   IWORK, NOUT, INFO )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDPT, LDQ, LDX, LWORK, NOUT, NRHS,
@@ -15,7 +15,7 @@
 *     ..
 *     .. Array Arguments ..
       LOGICAL            DOTYPE( * )
-      INTEGER            ISEED( 4 ), MVAL( * ), NVAL( * )
+      INTEGER            ISEED( 4 ), IWORK( * ), MVAL( * ), NVAL( * )
       DOUBLE PRECISION   A( LDA, * ), BD( * ), BE( * ), PT( LDPT, * ),
      $                   Q( LDQ, * ), S1( * ), S2( * ), U( LDPT, * ),
      $                   VT( LDPT, * ), WORK( * ), X( LDX, * ),
@@ -46,6 +46,15 @@
 *  In addition, DBDSQR has an option to apply the left orthogonal matrix
 *  U to a matrix X, useful in least squares applications.
 *
+*  DBDSDC computes the singular value decomposition of the bidiagonal
+*  matrix B as B = U S V' using divide-and-conquer. It is called twice
+*  to compute
+*     1) B = U S1 V', where S1 is the diagonal matrix of singular
+*         values and the columns of the matrices U and V are the left
+*         and right singular vectors, respectively, of B.
+*     2) Same as 1), but the singular values are stored in S2 and the
+*         singular vectors are not computed.
+*
 *  For each pair of matrix dimensions (M,N) and each selected matrix
 *  type, an M by N matrix A and an M by NRHS matrix X are generated.
 *  The problem dimensions are as follows
@@ -97,6 +106,19 @@
 *
 *  (14)  | I - (VT PT) (PT'VT') | / ( N ulp )
 *
+*  Test DBDSDC on bidiagonal matrix B
+*
+*  (15)  | B - U S1 VT | / ( |B| min(M,N) ulp ), VT = V'
+*
+*  (16)  | I - U' U | / ( min(M,N) ulp )
+*
+*  (17)  | I - VT VT' | / ( min(M,N) ulp )
+*
+*  (18)  S1 contains min(M,N) nonnegative values in decreasing order.
+*        (Return 0 if true, 1/ULP if false.)
+*
+*  (19)  | S1 - S2 | / ( |S1| ulp ), where S2 is computed without
+*                                    computing U and V.
 *  The possible matrix types are
 *
 *  (1)  The zero matrix.
@@ -248,6 +270,8 @@
 *          3(M+N) and  M(M + max(M,N,k) + 1) + N*min(M,N)  for all
 *          pairs  (M,N)=(MM(j),NN(j))
 *
+*  IWORK   (workspace) INTEGER array, dimension at least 8*min(M,N)
+*
 *  NOUT    (input) INTEGER
 *          The FORTRAN unit number for printing out error messages
 *          (e.g., if a routine returns IINFO not equal to 0.)
@@ -318,18 +342,18 @@
      $                   TEMP1, TEMP2, ULP, ULPINV, UNFL
 *     ..
 *     .. Local Arrays ..
-      INTEGER            IOLDSD( 4 ), IWORK( 1 ), KMAGN( MAXTYP ),
+      INTEGER            IDUM( 1 ), IOLDSD( 4 ), KMAGN( MAXTYP ),
      $                   KMODE( MAXTYP ), KTYPE( MAXTYP )
-      DOUBLE PRECISION   DUMMA( 1 ), RESULT( 14 )
+      DOUBLE PRECISION   DUM( 1 ), DUMMA( 1 ), RESULT( 19 )
 *     ..
 *     .. External Functions ..
       DOUBLE PRECISION   DLAMCH, DLARND
       EXTERNAL           DLAMCH, DLARND
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ALASUM, DBDSQR, DBDT01, DBDT02, DBDT03, DCOPY,
-     $                   DGEBRD, DGEMM, DLABAD, DLACPY, DLAHD2, DLASET,
-     $                   DLATMR, DLATMS, DORGBR, DORT01, DSVDCH, XERBLA
+      EXTERNAL           ALASUM, DBDSDC, DBDSQR, DBDT01, DBDT02, DBDT03,
+     $                   DCOPY, DGEBRD, DGEMM, DLABAD, DLACPY, DLAHD2,
+     $                   DLASET, DLATMR, DLATMS, DORGBR, DORT01, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, EXP, INT, LOG, MAX, MIN, SQRT
@@ -405,7 +429,7 @@
 *
 *     Initialize constants
 *
-      PATH( 1: 1 ) = 'D'
+      PATH( 1: 1 ) = 'Double precision'
       PATH( 2: 3 ) = 'BD'
       NFAIL = 0
       NTEST = 0
@@ -421,7 +445,7 @@
 *
 *     Loop over sizes, types
 *
-      DO 180 JSIZE = 1, NSIZES
+      DO 200 JSIZE = 1, NSIZES
          M = MVAL( JSIZE )
          N = NVAL( JSIZE )
          MNMIN = MIN( M, N )
@@ -433,9 +457,9 @@
             MTYPES = MIN( MAXTYP+1, NTYPES )
          END IF
 *
-         DO 170 JTYPE = 1, MTYPES
+         DO 190 JTYPE = 1, MTYPES
             IF( .NOT.DOTYPE( JTYPE ) )
-     $         GO TO 170
+     $         GO TO 190
 *
             DO 20 J = 1, 4
                IOLDSD( J ) = ISEED( J )
@@ -707,7 +731,7 @@
                   RETURN
                ELSE
                   RESULT( 4 ) = ULPINV
-                  GO TO 150
+                  GO TO 170
                END IF
             END IF
 *
@@ -731,7 +755,7 @@
                   RETURN
                ELSE
                   RESULT( 9 ) = ULPINV
-                  GO TO 150
+                  GO TO 170
                END IF
             END IF
 *
@@ -783,7 +807,7 @@
             TEMP1 = THRESH*( HALF-ULP )
 *
             DO 130 J = 0, LOG2UI
-               CALL DSVDCH( MNMIN, BD, BE, S1, TEMP1, IINFO )
+*               CALL DSVDCH( MNMIN, BD, BE, S1, TEMP1, IINFO )
                IF( IINFO.EQ.0 )
      $            GO TO 140
                TEMP1 = TEMP1*TWO
@@ -818,10 +842,99 @@
      $                      RESULT( 14 ) )
             END IF
 *
+*           Use DBDSDC to form the SVD of the bidiagonal matrix B:
+*           B := U * S1 * VT
+*
+            CALL DCOPY( MNMIN, BD, 1, S1, 1 )
+            IF( MNMIN.GT.0 )
+     $         CALL DCOPY( MNMIN-1, BE, 1, WORK, 1 )
+            CALL DLASET( 'Full', MNMIN, MNMIN, ZERO, ONE, U, LDPT )
+            CALL DLASET( 'Full', MNMIN, MNMIN, ZERO, ONE, VT, LDPT )
+*
+            CALL DBDSDC( UPLO, 'I', MNMIN, S1, WORK, U, LDPT, VT, LDPT,
+     $                   DUM, IDUM, WORK( MNMIN+1 ), IWORK, IINFO )
+*
+*           Check error code from DBDSDC.
+*
+            IF( IINFO.NE.0 ) THEN
+               WRITE( NOUT, FMT = 9998 )'DBDSDC(vects)', IINFO, M, N,
+     $            JTYPE, IOLDSD
+               INFO = ABS( IINFO )
+               IF( IINFO.LT.0 ) THEN
+                  RETURN
+               ELSE
+                  RESULT( 15 ) = ULPINV
+                  GO TO 170
+               END IF
+            END IF
+*
+*           Use DBDSDC to compute only the singular values of the
+*           bidiagonal matrix B;  U and VT should not be modified.
+*
+            CALL DCOPY( MNMIN, BD, 1, S2, 1 )
+            IF( MNMIN.GT.0 )
+     $         CALL DCOPY( MNMIN-1, BE, 1, WORK, 1 )
+*
+            CALL DBDSDC( UPLO, 'N', MNMIN, S2, WORK, DUM, 1, DUM, 1,
+     $                   DUM, IDUM, WORK( MNMIN+1 ), IWORK, IINFO )
+*
+*           Check error code from DBDSDC.
+*
+            IF( IINFO.NE.0 ) THEN
+               WRITE( NOUT, FMT = 9998 )'DBDSDC(values)', IINFO, M, N,
+     $            JTYPE, IOLDSD
+               INFO = ABS( IINFO )
+               IF( IINFO.LT.0 ) THEN
+                  RETURN
+               ELSE
+                  RESULT( 18 ) = ULPINV
+                  GO TO 170
+               END IF
+            END IF
+*
+*           Test 15:  Check the decomposition B := U * S1 * VT
+*                16:  Check the orthogonality of U
+*                17:  Check the orthogonality of VT
+*
+            CALL DBDT03( UPLO, MNMIN, 1, BD, BE, U, LDPT, S1, VT, LDPT,
+     $                   WORK, RESULT( 15 ) )
+            CALL DORT01( 'Columns', MNMIN, MNMIN, U, LDPT, WORK, LWORK,
+     $                   RESULT( 16 ) )
+            CALL DORT01( 'Rows', MNMIN, MNMIN, VT, LDPT, WORK, LWORK,
+     $                   RESULT( 17 ) )
+*
+*           Test 18:  Check that the singular values are sorted in
+*                     non-increasing order and are non-negative
+*
+            RESULT( 18 ) = ZERO
+            DO 150 I = 1, MNMIN - 1
+               IF( S1( I ).LT.S1( I+1 ) )
+     $            RESULT( 18 ) = ULPINV
+               IF( S1( I ).LT.ZERO )
+     $            RESULT( 18 ) = ULPINV
+  150       CONTINUE
+            IF( MNMIN.GE.1 ) THEN
+               IF( S1( MNMIN ).LT.ZERO )
+     $            RESULT( 18 ) = ULPINV
+            END IF
+*
+*           Test 19:  Compare DBDSQR with and without singular vectors
+*
+            TEMP2 = ZERO
+*
+            DO 160 J = 1, MNMIN
+               TEMP1 = ABS( S1( J )-S2( J ) ) /
+     $                 MAX( SQRT( UNFL )*MAX( S1( 1 ), ONE ),
+     $                 ULP*MAX( ABS( S1( 1 ) ), ABS( S2( 1 ) ) ) )
+               TEMP2 = MAX( TEMP1, TEMP2 )
+  160       CONTINUE
+*
+            RESULT( 19 ) = TEMP2
+*
 *           End of Loop -- Check for RESULT(j) > THRESH
 *
-  150       CONTINUE
-            DO 160 J = 1, 14
+  170       CONTINUE
+            DO 180 J = 1, 19
                IF( RESULT( J ).GE.THRESH ) THEN
                   IF( NFAIL.EQ.0 )
      $               CALL DLAHD2( NOUT, PATH )
@@ -829,15 +942,15 @@
      $               RESULT( J )
                   NFAIL = NFAIL + 1
                END IF
-  160       CONTINUE
+  180       CONTINUE
             IF( .NOT.BIDIAG ) THEN
-               NTEST = NTEST + 14
+               NTEST = NTEST + 19
             ELSE
                NTEST = NTEST + 5
             END IF
 *
-  170    CONTINUE
-  180 CONTINUE
+  190    CONTINUE
+  200 CONTINUE
 *
 *     Summary
 *
