@@ -6,7 +6,7 @@
 *  -- LAPACK test routine (release 2.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDAB, LDC, LDP, LDQ, LWORK, NOUNIT,
@@ -254,10 +254,10 @@
 *     ..
 *     .. Local Scalars ..
       LOGICAL            BADMM, BADNN, BADNNB
-      INTEGER            I, IINFO, IMODE, ITYPE, IWORK, J, JCOL, JR,
-     $                   JSIZE, JTYPE, JWIDTH, K, KL, KMAX, KU, M, MMAX,
-     $                   MNMAX, MNMIN, MTYPES, N, NERRS, NMATS, NMAX,
-     $                   NTEST, NTESTT
+      INTEGER            I, IINFO, IMODE, ITYPE, J, JCOL, JR, JSIZE,
+     $                   JTYPE, JWIDTH, K, KL, KMAX, KU, M, MMAX, MNMAX,
+     $                   MNMIN, MTYPES, N, NERRS, NMATS, NMAX, NTEST,
+     $                   NTESTT
       REAL               AMNINV, ANORM, COND, OVFL, RTOVFL, RTUNFL, ULP,
      $                   ULPINV, UNFL
 *     ..
@@ -491,8 +491,8 @@
 *
                CALL SLATMR( M, NRHS, 'S', ISEED, 'N', WORK, 6, ONE, ONE,
      $                      'T', 'N', WORK( M+1 ), 1, ONE,
-     $                      WORK( 2*M+1 ), 1, ONE, 'N', IWORK, M, NRHS,
-     $                      ZERO, ONE, 'NO', C, LDC, IWORK, IINFO )
+     $                      WORK( 2*M+1 ), 1, ONE, 'N', IDUMMA, M, NRHS,
+     $                      ZERO, ONE, 'NO', C, LDC, IDUMMA, IINFO )
 *
                IF( IINFO.NE.0 ) THEN
                   WRITE( NOUNIT, FMT = 9999 )'Generator', IINFO, N,
