@@ -1,9 +1,9 @@
       PROGRAM SCHKEE
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *  Purpose
 *  =======
@@ -20,8 +20,8 @@
 *                  SSYEVD,   SSBEVD,   SSPEVD,   SSTEVD
 *
 *  SVD (Singular Value Decomposition):
-*      Test SGEBRD, SORGBR, and SBDSQR
-*      and the driver routine SGESVD
+*      Test SGEBRD, SORGBR, SBDSQR, SBDSDC
+*      and the drivers SGESVD, SGESDD
 *
 *  SEV (Nonsymmetric Eigenvalue/eigenvector Driver):
 *      Test SGEEV
@@ -39,8 +39,21 @@
 *      Test SGGHRD, SGGBAL, SGGBAK, SHGEQZ, and STGEVC
 *      and the driver routines SGEGS and SGEGV
 *
+*  SGS (Generalized Nonsymmetric Schur form Driver):
+*      Test SGGES
+*
+*  SGV (Generalized Nonsymmetric Eigenvalue/eigenvector Driver):
+*      Test SGGEV
+*
+*  SGX (Generalized Nonsymmetric Schur form Expert Driver):
+*      Test SGGESX
+*
+*  SXV (Generalized Nonsymmetric Eigenvalue/eigenvector Expert Driver):
+*      Test SGGEVX
+*
 *  SSG (Symmetric Generalized Eigenvalue Problem):
-*      Test SSYGST, SSYGV, SSPGST, SSPGV, SSBGST, and SSBGV
+*      Test SSYGST, SSYGV, SSYGVD, SSYGVX, SSPGST, SSPGV, SSPGVD,
+*      SSPGVX, SSBGST, SSBGV, SSBGVD, and SSBGVX
 *
 *  SSB (Symmetric Band Eigenvalue Problem):
 *      Test SSBTRD
@@ -99,6 +112,10 @@
 *  SSX             21     SDRVSX
 *  SGG             26     SCHKGG (routines)
 *                  26     SDRVGG (drivers)
+*  SGS             26     SDRGES
+*  SGX              5     SDRGSX
+*  SGV             26     SDRGEV
+*  SXV              2     SDRGVX
 *  SSG             21     SDRVSG
 *  SSB             15     SCHKSB
 *  SBB             15     SCHKBB
@@ -492,6 +509,162 @@
 *
 *-----------------------------------------------------------------------
 *
+*  SGS and SGV input files:
+*
+*  line 1:  'SGS' or 'SGV' in columns 1 to 3.
+*
+*  line 2:  NN, INTEGER
+*           Number of values of N.
+*
+*  line 3:  NVAL, INTEGER array, dimension(NN)
+*           Dimensions of matrices to be tested.
+*
+*  line 4:  NB, NBMIN, NX, NS, NBCOL, INTEGERs
+*           These integer parameters determine how blocking is done
+*           (see ILAENV for details)
+*           NB     : block size
+*           NBMIN  : minimum block size
+*           NX     : minimum dimension for blocking
+*           NS     : number of shifts in xHGEQR
+*           NBCOL  : minimum column dimension for blocking
+*
+*  line 5:  THRESH, REAL
+*           The test threshold against which computed residuals are
+*           compared. Should generally be in the range from 10. to 20.
+*           If it is 0., all test case data will be printed.
+*
+*  line 6:  TSTERR, LOGICAL
+*           Flag indicating whether or not to test the error exits.
+*
+*  line 7:  NEWSD, INTEGER
+*           A code indicating how to set the random number seed.
+*           = 0:  Set the seed to a default value before each run
+*           = 1:  Initialize the seed to a default value only before the
+*                 first run
+*           = 2:  Like 1, but use the seed values on the next line
+*
+*  If line 17 was 2:
+*
+*  line 7:  INTEGER array, dimension (4)
+*           Four integer values for the random number seed.
+*
+*  lines 7-EOF:  Lines specifying matrix types, as for NEP.
+*           The 3-character path name is 'SGS' for the generalized
+*           eigenvalue problem routines and driver routines.
+*
+*-----------------------------------------------------------------------
+*
+*  SXV input files:
+*
+*  line 1:  'SXV' in columns 1 to 3.
+*
+*  line 2:  N, INTEGER
+*           Value of N.
+*
+*  line 3:  NB, NBMIN, NX, NS, NBCOL, INTEGERs
+*           These integer parameters determine how blocking is done
+*           (see ILAENV for details)
+*           NB     : block size
+*           NBMIN  : minimum block size
+*           NX     : minimum dimension for blocking
+*           NS     : number of shifts in xHGEQR
+*           NBCOL  : minimum column dimension for blocking
+*
+*  line 4:  THRESH, REAL
+*           The test threshold against which computed residuals are
+*           compared. Should generally be in the range from 10. to 20.
+*           Information will be printed about each test for which the
+*           test ratio is greater than or equal to the threshold.
+*
+*  line 5:  TSTERR, LOGICAL
+*           Flag indicating whether or not to test the error exits for
+*           the LAPACK routines and driver routines.
+*
+*  line 6:  NEWSD, INTEGER
+*           A code indicating how to set the random number seed.
+*           = 0:  Set the seed to a default value before each run
+*           = 1:  Initialize the seed to a default value only before the
+*                 first run
+*           = 2:  Like 1, but use the seed values on the next line
+*
+*  If line 6 was 2:
+*
+*  line 7: INTEGER array, dimension (4)
+*           Four integer values for the random number seed.
+*
+*  If line 2 was 0:
+*
+*  line 7-EOF: Precomputed examples are tested.
+*
+*  remaining lines : Each example is stored on 3+2*N lines, where N is
+*           its dimension. The first line contains the dimension (a
+*           single integer). The next N lines contain the matrix A, one
+*           row per line. The next N lines contain the matrix B.  The
+*           next line contains the reciprocals of the eigenvalue
+*           condition numbers.  The last line contains the reciprocals of
+*           the eigenvector condition numbers.  The end of data is
+*           indicated by dimension N=0.  Even if no data is to be tested,
+*           there must be at least one line containing N=0.
+*
+*-----------------------------------------------------------------------
+*
+*  SGX input files:
+*
+*  line 1:  'SGX' in columns 1 to 3.
+*
+*  line 2:  N, INTEGER
+*           Value of N.
+*
+*  line 3:  NB, NBMIN, NX, NS, NBCOL, INTEGERs
+*           These integer parameters determine how blocking is done
+*           (see ILAENV for details)
+*           NB     : block size
+*           NBMIN  : minimum block size
+*           NX     : minimum dimension for blocking
+*           NS     : number of shifts in xHGEQR
+*           NBCOL  : minimum column dimension for blocking
+*
+*  line 4:  THRESH, REAL
+*           The test threshold against which computed residuals are
+*           compared. Should generally be in the range from 10. to 20.
+*           Information will be printed about each test for which the
+*           test ratio is greater than or equal to the threshold.
+*
+*  line 5:  TSTERR, LOGICAL
+*           Flag indicating whether or not to test the error exits for
+*           the LAPACK routines and driver routines.
+*
+*  line 6:  NEWSD, INTEGER
+*           A code indicating how to set the random number seed.
+*           = 0:  Set the seed to a default value before each run
+*           = 1:  Initialize the seed to a default value only before the
+*                 first run
+*           = 2:  Like 1, but use the seed values on the next line
+*
+*  If line 6 was 2:
+*
+*  line 7: INTEGER array, dimension (4)
+*           Four integer values for the random number seed.
+*
+*  If line 2 was 0:
+*
+*  line 7-EOF: Precomputed examples are tested.
+*
+*  remaining lines : Each example is stored on 3+2*N lines, where N is
+*           its dimension. The first line contains the dimension (a
+*           single integer).  The next line contains an integer k such
+*           that only the last k eigenvalues will be selected and appear
+*           in the leading diagonal blocks of $A$ and $B$. The next N
+*           lines contain the matrix A, one row per line.  The next N
+*           lines contain the matrix B.  The last line contains the
+*           reciprocal of the eigenvalue cluster condition number and the
+*           reciprocal of the deflating subspace (associated with the
+*           selected eigencluster) condition number.  The end of data is
+*           indicated by dimension N=0.  Even if no data is to be tested,
+*           there must be at least one line containing N=0.
+*
+*-----------------------------------------------------------------------
+*
 *  SSB input file:
 *
 *  line 2:  NN, INTEGER
@@ -788,12 +961,14 @@
 *     .. Parameters ..
       INTEGER            NMAX
       PARAMETER          ( NMAX = 132 )
+      INTEGER            NCMAX
+      PARAMETER          ( NCMAX = 20 )
       INTEGER            NEED
       PARAMETER          ( NEED = 14 )
       INTEGER            LWORK
       PARAMETER          ( LWORK = NMAX*( 5*NMAX+5 )+1 )
       INTEGER            LIWORK
-      PARAMETER          ( LIWORK = NMAX*( NMAX+20 ) )
+      PARAMETER          ( LIWORK = NMAX*( 5*NMAX+20 ) )
       INTEGER            MAXIN
       PARAMETER          ( MAXIN = 20 )
       INTEGER            MAXT
@@ -803,8 +978,9 @@
 *     ..
 *     .. Local Scalars ..
       LOGICAL            FATAL, GLM, GQR, GSV, LSE, NEP, SBB, SBK, SBL,
-     $                   SEP, SES, SEV, SGG, SGK, SGL, SSB, SSX, SVD,
-     $                   SVX, TSTCHK, TSTDIF, TSTDRV, TSTERR
+     $                   SEP, SES, SEV, SGG, SGK, SGL, SGS, SGV, SGX,
+     $                   SSB, SSX, SVD, SVX, SXV, TSTCHK, TSTDIF,
+     $                   TSTDRV, TSTERR
       CHARACTER          C1
       CHARACTER*3        C3, PATH
       CHARACTER*6        VNAME
@@ -822,8 +998,9 @@
      $                   NSVAL( MAXIN ), NVAL( MAXIN ), NXVAL( MAXIN ),
      $                   PVAL( MAXIN )
       REAL               A( NMAX*NMAX, NEED ), B( NMAX*NMAX, 5 ),
-     $                   D( NMAX, 12 ), RESULT( 105 ), TAUA( NMAX ),
-     $                   TAUB( NMAX ), WORK( LWORK ), X( 5*NMAX )
+     $                   C( NCMAX*NCMAX, NCMAX*NCMAX ), D( NMAX, 12 ),
+     $                   RESULT( 500 ), TAUA( NMAX ), TAUB( NMAX ),
+     $                   WORK( LWORK ), X( 5*NMAX )
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAMEN
@@ -833,9 +1010,10 @@
 *     .. External Subroutines ..
       EXTERNAL           ALAREQ, SCHKBB, SCHKBD, SCHKBK, SCHKBL, SCHKEC,
      $                   SCHKGG, SCHKGK, SCHKGL, SCHKHS, SCHKSB, SCHKST,
-     $                   SCKGLM, SCKGQR, SCKGSV, SCKLSE, SDRVBD, SDRVES,
-     $                   SDRVEV, SDRVGG, SDRVSG, SDRVST, SDRVSX, SDRVVX,
-     $                   SERRBD, SERRED, SERRGG, SERRHS, SERRST, XLAENV
+     $                   SCKGLM, SCKGQR, SCKGSV, SCKLSE, SDRGES, SDRGEV,
+     $                   SDRGSX, SDRGVX, SDRVBD, SDRVES, SDRVEV, SDRVGG,
+     $                   SDRVSG, SDRVST, SDRVSX, SDRVVX, SERRBD, SERRED,
+     $                   SERRGG, SERRHS, SERRST, XLAENV
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          LEN, MIN
@@ -874,7 +1052,7 @@
 *
 *     Read the first line and set the 3-character test path
 *
-      READ( NIN, FMT = '(A80)', END = 370 )LINE
+      READ( NIN, FMT = '(A80)', END = 380 )LINE
       PATH = LINE( 1: 3 )
       NEP = LSAMEN( 3, PATH, 'NEP' ) .OR. LSAMEN( 3, PATH, 'SHS' )
       SEP = LSAMEN( 3, PATH, 'SEP' ) .OR. LSAMEN( 3, PATH, 'SST' ) .OR.
@@ -885,6 +1063,10 @@
       SVX = LSAMEN( 3, PATH, 'SVX' )
       SSX = LSAMEN( 3, PATH, 'SSX' )
       SGG = LSAMEN( 3, PATH, 'SGG' )
+      SGS = LSAMEN( 3, PATH, 'SGS' )
+      SGX = LSAMEN( 3, PATH, 'SGX' )
+      SGV = LSAMEN( 3, PATH, 'SGV' )
+      SXV = LSAMEN( 3, PATH, 'SXV' )
       SSB = LSAMEN( 3, PATH, 'SSB' )
       SBB = LSAMEN( 3, PATH, 'SBB' )
       GLM = LSAMEN( 3, PATH, 'GLM' )
@@ -916,6 +1098,14 @@
          WRITE( NOUT, FMT = 9976 )
       ELSE IF( SGG ) THEN
          WRITE( NOUT, FMT = 9975 )
+      ELSE IF( SGS ) THEN
+         WRITE( NOUT, FMT = 9964 )
+      ELSE IF( SGX ) THEN
+         WRITE( NOUT, FMT = 9965 )
+      ELSE IF( SGV ) THEN
+         WRITE( NOUT, FMT = 9963 )
+      ELSE IF( SXV ) THEN
+         WRITE( NOUT, FMT = 9962 )
       ELSE IF( SSB ) THEN
          WRITE( NOUT, FMT = 9974 )
       ELSE IF( SBB ) THEN
@@ -970,7 +1160,7 @@
 *     Read the number of values of M, P, and N.
 *
       READ( NIN, FMT = * )NN
-      IF( NN.LT.1 ) THEN
+      IF( NN.LT.0 ) THEN
          WRITE( NOUT, FMT = 9989 )'   NN ', NN, 1
          NN = 0
          FATAL = .TRUE.
@@ -982,22 +1172,24 @@
 *
 *     Read the values of M
 *
-      READ( NIN, FMT = * )( MVAL( I ), I = 1, NN )
-      IF( SVD ) THEN
-         VNAME = '    M '
-      ELSE
-         VNAME = '    N '
-      END IF
-      DO 20 I = 1, NN
-         IF( MVAL( I ).LT.0 ) THEN
-            WRITE( NOUT, FMT = 9989 )VNAME, MVAL( I ), 0
-            FATAL = .TRUE.
-         ELSE IF( MVAL( I ).GT.NMAX ) THEN
-            WRITE( NOUT, FMT = 9988 )VNAME, MVAL( I ), NMAX
-            FATAL = .TRUE.
+      IF( .NOT.( SGX .OR. SXV ) ) THEN
+         READ( NIN, FMT = * )( MVAL( I ), I = 1, NN )
+         IF( SVD ) THEN
+            VNAME = '    M '
+         ELSE
+            VNAME = '    N '
          END IF
-   20 CONTINUE
-      WRITE( NOUT, FMT = 9983 )'M:    ', ( MVAL( I ), I = 1, NN )
+         DO 20 I = 1, NN
+            IF( MVAL( I ).LT.0 ) THEN
+               WRITE( NOUT, FMT = 9989 )VNAME, MVAL( I ), 0
+               FATAL = .TRUE.
+            ELSE IF( MVAL( I ).GT.NMAX ) THEN
+               WRITE( NOUT, FMT = 9988 )VNAME, MVAL( I ), NMAX
+               FATAL = .TRUE.
+            END IF
+   20    CONTINUE
+         WRITE( NOUT, FMT = 9983 )'M:    ', ( MVAL( I ), I = 1, NN )
+      END IF
 *
 *     Read the values of P
 *
@@ -1033,7 +1225,11 @@
             NVAL( I ) = MVAL( I )
    50    CONTINUE
       END IF
-      WRITE( NOUT, FMT = 9983 )'N:    ', ( NVAL( I ), I = 1, NN )
+      IF( .NOT.( SGX .OR. SXV ) ) THEN
+         WRITE( NOUT, FMT = 9983 )'N:    ', ( NVAL( I ), I = 1, NN )
+      ELSE
+         WRITE( NOUT, FMT = 9983 )'N:    ', NN
+      END IF
 *
 *     Read the number of values of K, followed by the values of K
 *
@@ -1052,7 +1248,8 @@
          WRITE( NOUT, FMT = 9983 )'K:    ', ( KVAL( I ), I = 1, NK )
       END IF
 *
-      IF( SEV .OR. SES .OR. SVX .OR. SSX ) THEN
+      IF( SEV .OR. SES .OR. SVX .OR. SSX .OR. SGS .OR. SGX .OR. SGV .OR.
+     $    SXV ) THEN
 *
 *        For the nonsymmetric driver routines, only one set of
 *        parameters is allowed.
@@ -1279,61 +1476,72 @@
 *     4-80.
 *
   190 CONTINUE
-      READ( NIN, FMT = '(A80)', END = 370 )LINE
-      C3 = LINE( 1: 3 )
-      LENP = LEN( LINE )
-      I = 3
-      ITMP = 0
-      I1 = 0
-  200 CONTINUE
-      I = I + 1
-      IF( I.GT.LENP ) THEN
-         IF( I1.GT.0 ) THEN
-            GO TO 230
-         ELSE
-            NTYPES = MAXT
-            GO TO 230
+*
+      IF( .NOT.( SGX .OR. SXV ) ) THEN
+*
+  200    CONTINUE
+         READ( NIN, FMT = '(A80)', END = 380 )LINE
+         C3 = LINE( 1: 3 )
+         LENP = LEN( LINE )
+         I = 3
+         ITMP = 0
+         I1 = 0
+  210    CONTINUE
+         I = I + 1
+         IF( I.GT.LENP ) THEN
+            IF( I1.GT.0 ) THEN
+               GO TO 240
+            ELSE
+               NTYPES = MAXT
+               GO TO 240
+            END IF
          END IF
-      END IF
-      IF( LINE( I: I ).NE.' ' .AND. LINE( I: I ).NE.',' ) THEN
-         I1 = I
-         C1 = LINE( I1: I1 )
+         IF( LINE( I: I ).NE.' ' .AND. LINE( I: I ).NE.',' ) THEN
+            I1 = I
+            C1 = LINE( I1: I1 )
 *
 *        Check that a valid integer was read
 *
-         DO 210 K = 1, 10
-            IF( C1.EQ.INTSTR( K: K ) ) THEN
-               IC = K - 1
-               GO TO 220
-            END IF
-  210    CONTINUE
-         WRITE( NOUT, FMT = 9991 )I, LINE
-         GO TO 190
-  220    CONTINUE
-         ITMP = 10*ITMP + IC
-         GO TO 200
-      ELSE IF( I1.GT.0 ) THEN
-         GO TO 230
-      ELSE
-         GO TO 200
-      END IF
-  230 CONTINUE
-      NTYPES = ITMP
+            DO 220 K = 1, 10
+               IF( C1.EQ.INTSTR( K: K ) ) THEN
+                  IC = K - 1
+                  GO TO 230
+               END IF
+  220       CONTINUE
+            WRITE( NOUT, FMT = 9991 )I, LINE
+            GO TO 200
+  230       CONTINUE
+            ITMP = 10*ITMP + IC
+            GO TO 210
+         ELSE IF( I1.GT.0 ) THEN
+            GO TO 240
+         ELSE
+            GO TO 210
+         END IF
+  240    CONTINUE
+         NTYPES = ITMP
 *
 *     Skip the tests if NTYPES is <= 0.
 *
-      IF( .NOT.( SEV .OR. SES .OR. SVX .OR. SSX ) .AND. NTYPES.LE.0 )
-     $     THEN
-         WRITE( NOUT, FMT = 9990 )C3
-         GO TO 190
+         IF( .NOT.( SEV .OR. SES .OR. SVX .OR. SSX .OR. SGV .OR.
+     $       SGS ) .AND. NTYPES.LE.0 ) THEN
+            WRITE( NOUT, FMT = 9990 )C3
+            GO TO 200
+         END IF
+*
+      ELSE
+         IF( SXV )
+     $      C3 = 'SXV'
+         IF( SGX )
+     $      C3 = 'SGX'
       END IF
 *
 *     Reset the random number seed.
 *
       IF( NEWSD.EQ.0 ) THEN
-         DO 240 K = 1, 4
+         DO 250 K = 1, 4
             ISEED( K ) = IOLDSD( K )
-  240    CONTINUE
+  250    CONTINUE
       END IF
 *
       IF( LSAMEN( 3, C3, 'SHS' ) .OR. LSAMEN( 3, C3, 'NEP' ) ) THEN
@@ -1353,7 +1561,7 @@
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
          IF( TSTERR )
      $      CALL SERRHS( 'SHSEQR', NOUT )
-         DO 260 I = 1, NPARMS
+         DO 270 I = 1, NPARMS
             CALL XLAENV( 1, NBVAL( I ) )
             CALL XLAENV( 2, NBMIN( I ) )
             CALL XLAENV( 3, NXVAL( I ) )
@@ -1361,9 +1569,9 @@
             CALL XLAENV( 8, MXBVAL( I ) )
 *
             IF( NEWSD.EQ.0 ) THEN
-               DO 250 K = 1, 4
+               DO 260 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  250          CONTINUE
+  260          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9998 )C3, NBVAL( I ), NBMIN( I ),
      $         NXVAL( I ), NSVAL( I ), MXBVAL( I )
@@ -1376,7 +1584,7 @@
      $                   IWORK, LOGWRK, RESULT, INFO )
             IF( INFO.NE.0 )
      $         WRITE( NOUT, FMT = 9980 )'SCHKHS', INFO
-  260    CONTINUE
+  270    CONTINUE
 *
       ELSE IF( LSAMEN( 3, C3, 'SST' ) .OR. LSAMEN( 3, C3, 'SEP' ) ) THEN
 *
@@ -1388,20 +1596,21 @@
 *           NBMIN = minimum block size
 *           NX    = crossover point
 *
-         MAXTYP = 15
+         MAXTYP = 21
          NTYPES = MIN( MAXTYP, NTYPES )
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+         CALL XLAENV( 9, 25 )
          IF( TSTERR )
      $      CALL SERRST( 'SST', NOUT )
-         DO 280 I = 1, NPARMS
+         DO 290 I = 1, NPARMS
             CALL XLAENV( 1, NBVAL( I ) )
             CALL XLAENV( 2, NBMIN( I ) )
             CALL XLAENV( 3, NXVAL( I ) )
 *
             IF( NEWSD.EQ.0 ) THEN
-               DO 270 K = 1, 4
+               DO 280 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  270          CONTINUE
+  280          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9997 )C3, NBVAL( I ), NBMIN( I ),
      $         NXVAL( I )
@@ -1412,21 +1621,21 @@
      $                      D( 1, 6 ), D( 1, 7 ), D( 1, 8 ), D( 1, 9 ),
      $                      D( 1, 10 ), D( 1, 11 ), A( 1, 3 ), NMAX,
      $                      A( 1, 4 ), A( 1, 5 ), D( 1, 12 ), A( 1, 6 ),
-     $                      WORK, LWORK, IWORK, RESULT, INFO )
+     $                      WORK, LWORK, IWORK, LIWORK, RESULT, INFO )
                IF( INFO.NE.0 )
      $            WRITE( NOUT, FMT = 9980 )'SCHKST', INFO
             END IF
             IF( TSTDRV ) THEN
-               CALL SDRVST( NN, NVAL, MAXTYP, DOTYPE, ISEED, THRESH,
+               CALL SDRVST( NN, NVAL, 18, DOTYPE, ISEED, THRESH,
      $                      NOUT, A( 1, 1 ), NMAX, D( 1, 3 ), D( 1, 4 ),
      $                      D( 1, 5 ), D( 1, 6 ), D( 1, 8 ), D( 1, 9 ),
-     $                      D( 1, 10 ), A( 1, 2 ), NMAX, A( 1, 3 ),
-     $                      D( 1, 12 ), A( 1, 4 ), WORK, LWORK, IWORK,
-     $                      RESULT, INFO )
+     $                      D( 1, 10 ), D( 1, 11), A( 1, 2 ), NMAX, 
+     $                      A( 1, 3 ), D( 1, 12 ), A( 1, 4 ), WORK, 
+     $                      LWORK, IWORK, LIWORK, RESULT, INFO )
                IF( INFO.NE.0 )
      $            WRITE( NOUT, FMT = 9980 )'SDRVST', INFO
             END IF
-  280    CONTINUE
+  290    CONTINUE
 *
       ELSE IF( LSAMEN( 3, C3, 'SSG' ) ) THEN
 *
@@ -1441,15 +1650,16 @@
          MAXTYP = 21
          NTYPES = MIN( MAXTYP, NTYPES )
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
-         DO 300 I = 1, NPARMS
+         CALL XLAENV( 9, 25 )
+         DO 310 I = 1, NPARMS
             CALL XLAENV( 1, NBVAL( I ) )
             CALL XLAENV( 2, NBMIN( I ) )
             CALL XLAENV( 3, NXVAL( I ) )
 *
             IF( NEWSD.EQ.0 ) THEN
-               DO 290 K = 1, 4
+               DO 300 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  290          CONTINUE
+  300          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9997 )C3, NBVAL( I ), NBMIN( I ),
      $         NXVAL( I )
@@ -1458,11 +1668,11 @@
      $                      NOUT, A( 1, 1 ), NMAX, A( 1, 2 ), NMAX,
      $                      D( 1, 3 ), A( 1, 3 ), NMAX, A( 1, 4 ),
      $                      A( 1, 5 ), A( 1, 6 ), A( 1, 7 ), WORK,
-     $                      LWORK, IWORK, RESULT, INFO )
+     $                      LWORK, IWORK, LIWORK, RESULT, INFO )
                IF( INFO.NE.0 )
      $            WRITE( NOUT, FMT = 9980 )'SDRVSG', INFO
             END IF
-  300    CONTINUE
+  310    CONTINUE
 *
       ELSE IF( LSAMEN( 3, C3, 'SBD' ) .OR. LSAMEN( 3, C3, 'SVD' ) ) THEN
 *
@@ -1478,23 +1688,24 @@
          MAXTYP = 16
          NTYPES = MIN( MAXTYP, NTYPES )
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+         CALL XLAENV( 9, 25 )
 *
 *        Test the error exits
 *
          IF( TSTERR .AND. TSTCHK )
-     $      CALL SERRBD( 'SBDSQR', NOUT )
+     $      CALL SERRBD( 'SBD', NOUT )
          IF( TSTERR .AND. TSTDRV )
-     $      CALL SERRED( 'SBDSQR', NOUT )
+     $      CALL SERRED( 'SBD', NOUT )
 *
-         DO 320 I = 1, NPARMS
+         DO 330 I = 1, NPARMS
             NRHS = NSVAL( I )
             CALL XLAENV( 1, NBVAL( I ) )
             CALL XLAENV( 2, NBMIN( I ) )
             CALL XLAENV( 3, NXVAL( I ) )
             IF( NEWSD.EQ.0 ) THEN
-               DO 310 K = 1, 4
+               DO 320 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  310          CONTINUE
+  320          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9995 )C3, NBVAL( I ), NBMIN( I ),
      $         NXVAL( I ), NRHS
@@ -1504,7 +1715,7 @@
      $                      D( 1, 2 ), D( 1, 3 ), D( 1, 4 ), A( 1, 2 ),
      $                      NMAX, A( 1, 3 ), A( 1, 4 ), A( 1, 5 ), NMAX,
      $                      A( 1, 6 ), NMAX, A( 1, 7 ), A( 1, 8 ), WORK,
-     $                      LWORK, NOUT, INFO )
+     $                      LWORK, IWORK, NOUT, INFO )
                IF( INFO.NE.0 )
      $            WRITE( NOUT, FMT = 9980 )'SCHKBD', INFO
             END IF
@@ -1513,8 +1724,8 @@
      $                      THRESH, A( 1, 1 ), NMAX, A( 1, 2 ), NMAX,
      $                      A( 1, 3 ), NMAX, A( 1, 4 ), A( 1, 5 ),
      $                      A( 1, 6 ), D( 1, 1 ), D( 1, 2 ), D( 1, 3 ),
-     $                      WORK, LWORK, NOUT, INFO )
-  320    CONTINUE
+     $                      WORK, LWORK, IWORK, NOUT, INFO )
+  330    CONTINUE
 *
       ELSE IF( LSAMEN( 3, C3, 'SEV' ) ) THEN
 *
@@ -1577,7 +1788,7 @@
 *
          MAXTYP = 21
          NTYPES = MIN( MAXTYP, NTYPES )
-         IF( NTYPES.LE.0 ) THEN
+         IF( NTYPES.LT.0 ) THEN
             WRITE( NOUT, FMT = 9990 )C3
          ELSE
             IF( TSTERR )
@@ -1605,7 +1816,7 @@
 *
          MAXTYP = 21
          NTYPES = MIN( MAXTYP, NTYPES )
-         IF( NTYPES.LE.0 ) THEN
+         IF( NTYPES.LT.0 ) THEN
             WRITE( NOUT, FMT = 9990 )C3
          ELSE
             IF( TSTERR )
@@ -1640,7 +1851,7 @@
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
          IF( TSTCHK .AND. TSTERR )
      $      CALL SERRGG( C3, NOUT )
-         DO 340 I = 1, NPARMS
+         DO 350 I = 1, NPARMS
             CALL XLAENV( 1, NBVAL( I ) )
             CALL XLAENV( 2, NBMIN( I ) )
             CALL XLAENV( 4, NSVAL( I ) )
@@ -1648,9 +1859,9 @@
             CALL XLAENV( 5, NBCOL( I ) )
 *
             IF( NEWSD.EQ.0 ) THEN
-               DO 330 K = 1, 4
+               DO 340 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  330          CONTINUE
+  340          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9996 )C3, NBVAL( I ), NBMIN( I ),
      $         NSVAL( I ), MXBVAL( I ), NBCOL( I )
@@ -1680,7 +1891,116 @@
                IF( INFO.NE.0 )
      $            WRITE( NOUT, FMT = 9980 )'SDRVGG', INFO
             END IF
-  340    CONTINUE
+  350    CONTINUE
+*
+      ELSE IF( LSAMEN( 3, C3, 'SGS' ) ) THEN
+*
+*        -------------------------------------------------
+*        SGS:  Generalized Nonsymmetric Eigenvalue Problem
+*              SGGES (Schur form)
+*        -------------------------------------------------
+*
+         MAXTYP = 26
+         NTYPES = MIN( MAXTYP, NTYPES )
+         IF( NTYPES.LE.0 ) THEN
+            WRITE( NOUT, FMT = 9990 )C3
+         ELSE
+            IF( TSTERR )
+     $         CALL SERRGG( C3, NOUT )
+            CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+            CALL SDRGES( NN, NVAL, MAXTYP, DOTYPE, ISEED, THRESH, NOUT,
+     $                   A( 1, 1 ), NMAX, A( 1, 2 ), A( 1, 3 ),
+     $                   A( 1, 4 ), A( 1, 7 ), NMAX, A( 1, 8 ),
+     $                   D( 1, 1 ), D( 1, 2 ), D( 1, 3 ), WORK, LWORK,
+     $                   RESULT, LOGWRK, INFO )
+*
+            IF( INFO.NE.0 )
+     $         WRITE( NOUT, FMT = 9980 )'SDRGES', INFO
+         END IF
+         WRITE( NOUT, FMT = 9973 )
+         GO TO 10
+*
+      ELSE IF( SGX ) THEN
+*
+*        -------------------------------------------------
+*        SGX:  Generalized Nonsymmetric Eigenvalue Problem
+*              SGGESX (Schur form and condition numbers)
+*        -------------------------------------------------
+*
+         MAXTYP = 5
+         NTYPES = MAXTYP
+         IF( NN.LT.0 ) THEN
+            WRITE( NOUT, FMT = 9990 )C3
+         ELSE
+            IF( TSTERR )
+     $         CALL SERRGG( C3, NOUT )
+            CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+            CALL SDRGSX( NN, NCMAX, THRESH, NIN, NOUT, A( 1, 1 ), NMAX,
+     $                   A( 1, 2 ), A( 1, 3 ), A( 1, 4 ), A( 1, 5 ),
+     $                   A( 1, 6 ), D( 1, 1 ), D( 1, 2 ), D( 1, 3 ),
+     $                   C( 1, 1 ), NCMAX*NCMAX, A( 1, 12 ), WORK,
+     $                   LWORK, IWORK, LIWORK, LOGWRK, INFO )
+            IF( INFO.NE.0 )
+     $         WRITE( NOUT, FMT = 9980 )'SDRGSX', INFO
+         END IF
+         WRITE( NOUT, FMT = 9973 )
+         GO TO 10
+*
+      ELSE IF( LSAMEN( 3, C3, 'SGV' ) ) THEN
+*
+*        -------------------------------------------------
+*        SGV:  Generalized Nonsymmetric Eigenvalue Problem
+*              SGGEV (Eigenvalue/vector form)
+*        -------------------------------------------------
+*
+         MAXTYP = 26
+         NTYPES = MIN( MAXTYP, NTYPES )
+         IF( NTYPES.LE.0 ) THEN
+            WRITE( NOUT, FMT = 9990 )C3
+         ELSE
+            IF( TSTERR )
+     $         CALL SERRGG( C3, NOUT )
+            CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+            CALL SDRGEV( NN, NVAL, MAXTYP, DOTYPE, ISEED, THRESH, NOUT,
+     $                   A( 1, 1 ), NMAX, A( 1, 2 ), A( 1, 3 ),
+     $                   A( 1, 4 ), A( 1, 7 ), NMAX, A( 1, 8 ),
+     $                   A( 1, 9 ), NMAX, D( 1, 1 ), D( 1, 2 ),
+     $                   D( 1, 3 ), D( 1, 4 ), D( 1, 5 ), D( 1, 6 ),
+     $                   WORK, LWORK, RESULT, INFO )
+            IF( INFO.NE.0 )
+     $         WRITE( NOUT, FMT = 9980 )'SDRGEV', INFO
+         END IF
+         WRITE( NOUT, FMT = 9973 )
+         GO TO 10
+*
+      ELSE IF( SXV ) THEN
+*
+*        -------------------------------------------------
+*        SXV:  Generalized Nonsymmetric Eigenvalue Problem
+*              SGGEVX (eigenvalue/vector with condition numbers)
+*        -------------------------------------------------
+*
+         MAXTYP = 2
+         NTYPES = MAXTYP
+         IF( NN.LT.0 ) THEN
+            WRITE( NOUT, FMT = 9990 )C3
+         ELSE
+            IF( TSTERR )
+     $         CALL SERRGG( C3, NOUT )
+            CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+            CALL SDRGVX( NN, THRESH, NIN, NOUT, A( 1, 1 ), NMAX,
+     $                   A( 1, 2 ), A( 1, 3 ), A( 1, 4 ), D( 1, 1 ),
+     $                   D( 1, 2 ), D( 1, 3 ), A( 1, 5 ), A( 1, 6 ),
+     $                   IWORK( 1 ), IWORK( 2 ), D( 1, 4 ), D( 1, 5 ),
+     $                   D( 1, 6 ), D( 1, 7 ), D( 1, 8 ), D( 1, 9 ),
+     $                   WORK, LWORK, IWORK( 3 ), LIWORK-2, RESULT,
+     $                   LOGWRK, INFO )
+*
+            IF( INFO.NE.0 )
+     $         WRITE( NOUT, FMT = 9980 )'SDRGVX', INFO
+         END IF
+         WRITE( NOUT, FMT = 9973 )
+         GO TO 10
 *
       ELSE IF( LSAMEN( 3, C3, 'SSB' ) ) THEN
 *
@@ -1708,13 +2028,13 @@
          MAXTYP = 15
          NTYPES = MIN( MAXTYP, NTYPES )
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
-         DO 360 I = 1, NPARMS
+         DO 370 I = 1, NPARMS
             NRHS = NSVAL( I )
 *
             IF( NEWSD.EQ.0 ) THEN
-               DO 350 K = 1, 4
+               DO 360 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  350          CONTINUE
+  360          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9966 )C3, NRHS
             CALL SCHKBB( NN, MVAL, NVAL, NK, KVAL, MAXTYP, DOTYPE, NRHS,
@@ -1724,7 +2044,7 @@
      $                   NMAX, A( 1, 7 ), WORK, LWORK, RESULT, INFO )
             IF( INFO.NE.0 )
      $         WRITE( NOUT, FMT = 9980 )'SCHKBB', INFO
-  360    CONTINUE
+  370    CONTINUE
 *
       ELSE IF( LSAMEN( 3, C3, 'GLM' ) ) THEN
 *
@@ -1791,8 +2111,9 @@
          WRITE( NOUT, FMT = * )
          WRITE( NOUT, FMT = 9992 )C3
       END IF
-      GO TO 190
-  370 CONTINUE
+      IF( .NOT.( SGX .OR. SXV ) )
+     $   GO TO 190
+  380 CONTINUE
       WRITE( NOUT, FMT = 9994 )
       S2 = SECOND( )
       WRITE( NOUT, FMT = 9993 )S2 - S1
@@ -1839,7 +2160,7 @@
  9974 FORMAT( ' Tests of SSBTRD', / ' (reduction of a symmetric band ',
      $      'matrix to tridiagonal form)' )
  9973 FORMAT( / 1X, 71( '-' ) )
- 9972 FORMAT( / ' LAPACK VERSION 2.0, released September 30, 1994 ' )
+ 9972 FORMAT( / ' LAPACK VERSION 3.0, released June 30, 1999 ' )
  9971 FORMAT( / ' Tests of the Generalized Linear Regression Model ',
      $      'routines' )
  9970 FORMAT( / ' Tests of the Generalized QR and RQ routines' )
@@ -1849,6 +2170,14 @@
  9967 FORMAT( ' Tests of SGBBRD', / ' (reduction of a general band ',
      $      'matrix to real bidiagonal form)' )
  9966 FORMAT( / / 1X, A3, ':  NRHS =', I4 )
+ 9965 FORMAT( / ' Tests of the Generalized Nonsymmetric Eigenvalue ',
+     $      'Problem Expert Driver SGGESX' )
+ 9964 FORMAT( / ' Tests of the Generalized Nonsymmetric Eigenvalue ',
+     $      'Problem Driver SGGES' )
+ 9963 FORMAT( / ' Tests of the Generalized Nonsymmetric Eigenvalue ',
+     $      'Problem Driver SGGEV' )
+ 9962 FORMAT( / ' Tests of the Generalized Nonsymmetric Eigenvalue ',
+     $      'Problem Expert Driver SGGEVX' )
 *
 *     End of SCHKEE
 *
