@@ -4,10 +4,10 @@
      $                   UU, TAU, WORK, NWORK, IWORK, SELECT, RESULT,
      $                   INFO )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDU, NOUNIT, NSIZES, NTYPES, NWORK
@@ -384,10 +384,10 @@
       PARAMETER          ( MAXTYP = 21 )
 *     ..
 *     .. Local Scalars ..
-      LOGICAL            BADNN
+      LOGICAL            BADNN, MATCH
       INTEGER            I, IHI, IINFO, ILO, IMODE, IN, ITYPE, J, JCOL,
-     $                   JSIZE, JTYPE, MTYPES, N, N1, NERRS, NMATS,
-     $                   NMAX, NTEST, NTESTT
+     $                   JJ, JSIZE, JTYPE, K, MTYPES, N, N1, NERRS,
+     $                   NMATS, NMAX, NSELC, NSELR, NTEST, NTESTT
       REAL               ANINV, ANORM, COND, CONDS, OVFL, RTOVFL, RTULP,
      $                   RTULPI, RTUNFL, TEMP1, TEMP2, ULP, ULPINV, UNFL
 *     ..
@@ -404,8 +404,8 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           SCOPY, SGEHRD, SGEMM, SGET10, SGET22, SHSEIN,
-     $                   SHSEQR, SHST01, SLABAD, SLACPY, SLAFTS, SLASUM,
-     $                   SLATME, SLATMR, SLATMS, SLASET, SORGHR, SORMHR,
+     $                   SHSEQR, SHST01, SLABAD, SLACPY, SLAFTS, SLASET,
+     $                   SLASUM, SLATME, SLATMR, SLATMS, SORGHR, SORMHR,
      $                   STREVC, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
@@ -479,7 +479,7 @@
       NERRS = 0
       NMATS = 0
 *
-      DO 200 JSIZE = 1, NSIZES
+      DO 270 JSIZE = 1, NSIZES
          N = NN( JSIZE )
          N1 = MAX( 1, N )
          ANINV = ONE / REAL( N1 )
@@ -490,9 +490,9 @@
             MTYPES = MIN( MAXTYP+1, NTYPES )
          END IF
 *
-         DO 190 JTYPE = 1, MTYPES
+         DO 260 JTYPE = 1, MTYPES
             IF( .NOT.DOTYPE( JTYPE ) )
-     $         GO TO 190
+     $         GO TO 260
             NMATS = NMATS + 1
             NTEST = 0
 *
@@ -679,7 +679,7 @@
                WRITE( NOUNIT, FMT = 9999 )'SGEHRD', IINFO, N, JTYPE,
      $            IOLDSD
                INFO = ABS( IINFO )
-               GO TO 180
+               GO TO 250
             END IF
 *
             DO 120 J = 1, N - 1
@@ -713,7 +713,7 @@
      $            IOLDSD
                IF( IINFO.LE.N+2 ) THEN
                   INFO = ABS( IINFO )
-                  GO TO 180
+                  GO TO 250
                END IF
             END IF
 *
@@ -727,7 +727,7 @@
                WRITE( NOUNIT, FMT = 9999 )'SHSEQR(S)', IINFO, N, JTYPE,
      $            IOLDSD
                INFO = ABS( IINFO )
-               GO TO 180
+               GO TO 250
             END IF
 *
 *           Eigenvalues (WR1,WI1), Schur Form (T1), and Schur vectors
@@ -742,7 +742,7 @@
                WRITE( NOUNIT, FMT = 9999 )'SHSEQR(V)', IINFO, N, JTYPE,
      $            IOLDSD
                INFO = ABS( IINFO )
-               GO TO 180
+               GO TO 250
             END IF
 *
 *           Compute Z = U' UZ
@@ -786,16 +786,42 @@
 *
             NTEST = 9
             RESULT( 9 ) = ULPINV
-            DO 140 J = 1, N
-               SELECT( J ) = .TRUE.
+*
+*           Select last max(N/4,1) real, max(N/4,1) complex eigenvectors
+*
+            NSELC = 0
+            NSELR = 0
+            J = N
   140       CONTINUE
+            IF( WI1( J ).EQ.ZERO ) THEN
+               IF( NSELR.LT.MAX( N / 4, 1 ) ) THEN
+                  NSELR = NSELR + 1
+                  SELECT( J ) = .TRUE.
+               ELSE
+                  SELECT( J ) = .FALSE.
+               END IF
+               J = J - 1
+            ELSE
+               IF( NSELC.LT.MAX( N / 4, 1 ) ) THEN
+                  NSELC = NSELC + 1
+                  SELECT( J ) = .TRUE.
+                  SELECT( J-1 ) = .FALSE.
+               ELSE
+                  SELECT( J ) = .FALSE.
+                  SELECT( J-1 ) = .FALSE.
+               END IF
+               J = J - 2
+            END IF
+            IF( J.GT.0 )
+     $         GO TO 140
+*
             CALL STREVC( 'Right', 'All', SELECT, N, T1, LDA, DUMMA, LDU,
      $                   EVECTR, LDU, N, IN, WORK, IINFO )
             IF( IINFO.NE.0 ) THEN
-               WRITE( NOUNIT, FMT = 9999 )'STREVC(R)', IINFO, N, JTYPE,
-     $            IOLDSD
+               WRITE( NOUNIT, FMT = 9999 )'STREVC(R,A)', IINFO, N,
+     $            JTYPE, IOLDSD
                INFO = ABS( IINFO )
-               GO TO 180
+               GO TO 250
             END IF
 *
 *           Test 9:  | TR - RW | / ( |T| |R| ulp )
@@ -808,20 +834,56 @@
      $            DUMMA( 2 ), N, JTYPE, IOLDSD
             END IF
 *
+*           Compute selected right eigenvectors and confirm that
+*           they agree with previous right eigenvectors
+*
+            CALL STREVC( 'Right', 'Some', SELECT, N, T1, LDA, DUMMA,
+     $                   LDU, EVECTL, LDU, N, IN, WORK, IINFO )
+            IF( IINFO.NE.0 ) THEN
+               WRITE( NOUNIT, FMT = 9999 )'STREVC(R,S)', IINFO, N,
+     $            JTYPE, IOLDSD
+               INFO = ABS( IINFO )
+               GO TO 250
+            END IF
+*
+            K = 1
+            MATCH = .TRUE.
+            DO 170 J = 1, N
+               IF( SELECT( J ) .AND. WI1( J ).EQ.ZERO ) THEN
+                  DO 150 JJ = 1, N
+                     IF( EVECTR( JJ, J ).NE.EVECTL( JJ, K ) ) THEN
+                        MATCH = .FALSE.
+                        GO TO 180
+                     END IF
+  150             CONTINUE
+                  K = K + 1
+               ELSE IF( SELECT( J ) .AND. WI1( J ).NE.ZERO ) THEN
+                  DO 160 JJ = 1, N
+                     IF( EVECTR( JJ, J ).NE.EVECTL( JJ, K ) .OR.
+     $                   EVECTR( JJ, J+1 ).NE.EVECTL( JJ, K+1 ) ) THEN
+                        MATCH = .FALSE.
+                        GO TO 180
+                     END IF
+  160             CONTINUE
+                  K = K + 2
+               END IF
+  170       CONTINUE
+  180       CONTINUE
+            IF( .NOT.MATCH )
+     $         WRITE( NOUNIT, FMT = 9997 )'Right', 'STREVC', N, JTYPE,
+     $         IOLDSD
+*
 *           Compute the Left eigenvector Matrix:
 *
             NTEST = 10
             RESULT( 10 ) = ULPINV
-            DO 150 J = 1, N
-               SELECT( J ) = .TRUE.
-  150       CONTINUE
             CALL STREVC( 'Left', 'All', SELECT, N, T1, LDA, EVECTL, LDU,
      $                   DUMMA, LDU, N, IN, WORK, IINFO )
             IF( IINFO.NE.0 ) THEN
-               WRITE( NOUNIT, FMT = 9999 )'STREVC(L)', IINFO, N, JTYPE,
-     $            IOLDSD
+               WRITE( NOUNIT, FMT = 9999 )'STREVC(L,A)', IINFO, N,
+     $            JTYPE, IOLDSD
                INFO = ABS( IINFO )
-               GO TO 180
+               GO TO 250
             END IF
 *
 *           Test 10:  | LT - WL | / ( |T| |L| ulp )
@@ -834,13 +896,52 @@
      $            N, JTYPE, IOLDSD
             END IF
 *
+*           Compute selected left eigenvectors and confirm that
+*           they agree with previous left eigenvectors
+*
+            CALL STREVC( 'Left', 'Some', SELECT, N, T1, LDA, EVECTR,
+     $                   LDU, DUMMA, LDU, N, IN, WORK, IINFO )
+            IF( IINFO.NE.0 ) THEN
+               WRITE( NOUNIT, FMT = 9999 )'STREVC(L,S)', IINFO, N,
+     $            JTYPE, IOLDSD
+               INFO = ABS( IINFO )
+               GO TO 250
+            END IF
+*
+            K = 1
+            MATCH = .TRUE.
+            DO 210 J = 1, N
+               IF( SELECT( J ) .AND. WI1( J ).EQ.ZERO ) THEN
+                  DO 190 JJ = 1, N
+                     IF( EVECTL( JJ, J ).NE.EVECTR( JJ, K ) ) THEN
+                        MATCH = .FALSE.
+                        GO TO 220
+                     END IF
+  190             CONTINUE
+                  K = K + 1
+               ELSE IF( SELECT( J ) .AND. WI1( J ).NE.ZERO ) THEN
+                  DO 200 JJ = 1, N
+                     IF( EVECTL( JJ, J ).NE.EVECTR( JJ, K ) .OR.
+     $                   EVECTL( JJ, J+1 ).NE.EVECTR( JJ, K+1 ) ) THEN
+                        MATCH = .FALSE.
+                        GO TO 220
+                     END IF
+  200             CONTINUE
+                  K = K + 2
+               END IF
+  210       CONTINUE
+  220       CONTINUE
+            IF( .NOT.MATCH )
+     $         WRITE( NOUNIT, FMT = 9997 )'Left', 'STREVC', N, JTYPE,
+     $         IOLDSD
+*
 *           Call SHSEIN for Right eigenvectors of H, do test 11
 *
             NTEST = 11
             RESULT( 11 ) = ULPINV
-            DO 160 J = 1, N
+            DO 230 J = 1, N
                SELECT( J ) = .TRUE.
-  160       CONTINUE
+  230       CONTINUE
 *
             CALL SHSEIN( 'Right', 'Qr', 'Ninitv', SELECT, N, H, LDA,
      $                   WR3, WI3, DUMMA, LDU, EVECTX, LDU, N1, IN,
@@ -850,7 +951,7 @@
      $            IOLDSD
                INFO = ABS( IINFO )
                IF( IINFO.LT.0 )
-     $            GO TO 180
+     $            GO TO 250
             ELSE
 *
 *              Test 11:  | HX - XW | / ( |H| |X| ulp )
@@ -871,9 +972,9 @@
 *
             NTEST = 12
             RESULT( 12 ) = ULPINV
-            DO 170 J = 1, N
+            DO 240 J = 1, N
                SELECT( J ) = .TRUE.
-  170       CONTINUE
+  240       CONTINUE
 *
             CALL SHSEIN( 'Left', 'Qr', 'Ninitv', SELECT, N, H, LDA, WR3,
      $                   WI3, EVECTY, LDU, DUMMA, LDU, N1, IN, WORK,
@@ -883,7 +984,7 @@
      $            IOLDSD
                INFO = ABS( IINFO )
                IF( IINFO.LT.0 )
-     $            GO TO 180
+     $            GO TO 250
             ELSE
 *
 *              Test 12:  | YH - WY | / ( |H| |Y| ulp )
@@ -912,7 +1013,7 @@
      $            IOLDSD
                INFO = ABS( IINFO )
                IF( IINFO.LT.0 )
-     $            GO TO 180
+     $            GO TO 250
             ELSE
 *
 *              Test 13:  | AX - XW | / ( |A| |X| ulp )
@@ -937,7 +1038,7 @@
      $            IOLDSD
                INFO = ABS( IINFO )
                IF( IINFO.LT.0 )
-     $            GO TO 180
+     $            GO TO 250
             ELSE
 *
 *              Test 14:  | YA - WY | / ( |A| |Y| ulp )
@@ -952,14 +1053,14 @@
 *
 *           End of Loop -- Check for RESULT(j) > THRESH
 *
-  180       CONTINUE
+  250       CONTINUE
 *
             NTESTT = NTESTT + NTEST
             CALL SLAFTS( 'SHS', N, N, JTYPE, NTEST, RESULT, IOLDSD,
      $                   THRESH, NOUNIT, NERRS )
 *
-  190    CONTINUE
-  200 CONTINUE
+  260    CONTINUE
+  270 CONTINUE
 *
 *     Summary
 *
@@ -973,6 +1074,9 @@
      $      'normalized.', / ' Bits of error=', 0P, G10.3, ',', 9X,
      $      'N=', I6, ', JTYPE=', I6, ', ISEED=(', 3( I5, ',' ), I5,
      $      ')' )
+ 9997 FORMAT( ' SCHKHS: Selected ', A, ' Eigenvectors from ', A,
+     $      ' do not match other eigenvectors ', 9X, 'N=', I6,
+     $      ', JTYPE=', I6, ', ISEED=(', 3( I5, ',' ), I5, ')' )
 *
 *     End of SCHKHS
 *
