@@ -3,10 +3,10 @@
      $                   LDQ, Z, ALPHR1, ALPHI1, BETA1, ALPHR2, ALPHI2,
      $                   BETA2, VL, VR, WORK, LWORK, RESULT, INFO )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDQ, LWORK, NOUNIT, NSIZES, NTYPES
@@ -796,26 +796,26 @@
 *                 print a header to the data file.
 *
                   IF( NERRS.EQ.0 ) THEN
-                     WRITE( NOUNIT, FMT = 9994 )'SGG'
+                     WRITE( NOUNIT, FMT = 9995 )'SGG'
 *
 *                    Matrix types
 *
+                     WRITE( NOUNIT, FMT = 9994 )
                      WRITE( NOUNIT, FMT = 9993 )
-                     WRITE( NOUNIT, FMT = 9992 )
-                     WRITE( NOUNIT, FMT = 9991 )'Orthogonal'
+                     WRITE( NOUNIT, FMT = 9992 )'Orthogonal'
 *
 *                    Tests performed
 *
-                     WRITE( NOUNIT, FMT = 9990 )'orthogonal', '''',
+                     WRITE( NOUNIT, FMT = 9991 )'orthogonal', '''',
      $                  'transpose', ( '''', J = 1, 5 )
 *
                   END IF
                   NERRS = NERRS + 1
                   IF( RESULT( JR ).LT.10000.0 ) THEN
-                     WRITE( NOUNIT, FMT = 9989 )N, JTYPE, IOLDSD, JR,
+                     WRITE( NOUNIT, FMT = 9990 )N, JTYPE, IOLDSD, JR,
      $                  RESULT( JR )
                   ELSE
-                     WRITE( NOUNIT, FMT = 9988 )N, JTYPE, IOLDSD, JR,
+                     WRITE( NOUNIT, FMT = 9989 )N, JTYPE, IOLDSD, JR,
      $                  RESULT( JR )
                   END IF
                END IF
@@ -845,16 +845,12 @@
      $      / 9X, 'N=', I6, ', JTYPE=', I6, ', ISEED=(', 3( I5, ',' ),
      $      I5, ')' )
 *
- 9995 FORMAT( ' SDRVGG: Bad complex pair returned by SGEGV at ',
-     $      'eigenvalue ', I6, '.', / 9X, 'N=', I6, ', JTYPE=', I6,
-     $      ', ISEED=(', 3( I5, ',' ), I5, ')' )
-*
- 9994 FORMAT( / 1X, A3, ' -- Real Generalized eigenvalue problem driver'
+ 9995 FORMAT( / 1X, A3, ' -- Real Generalized eigenvalue problem driver'
      $       )
 *
- 9993 FORMAT( ' Matrix types (see SDRVGG for details): ' )
+ 9994 FORMAT( ' Matrix types (see SDRVGG for details): ' )
 *
- 9992 FORMAT( ' Special Matrices:', 23X,
+ 9993 FORMAT( ' Special Matrices:', 23X,
      $      '(J''=transposed Jordan block)',
      $      / '   1=(0,0)  2=(I,0)  3=(0,I)  4=(I,I)  5=(J'',J'')  ',
      $      '6=(diag(J'',I), diag(I,J''))', / ' Diagonal Matrices:  ( ',
@@ -862,7 +858,7 @@
      $      ')  11=(large*I, small*D)  13=(large*D, large*I)', /
      $      '   8=(I,D)  10=(small*D, large*I)  12=(small*I, large*D) ',
      $      ' 14=(small*D, small*I)', / '  15=(D, reversed D)' )
- 9991 FORMAT( ' Matrices Rotated by Random ', A, ' Matrices U, V:',
+ 9992 FORMAT( ' Matrices Rotated by Random ', A, ' Matrices U, V:',
      $      / '  16=Transposed Jordan Blocks             19=geometric ',
      $      'alpha, beta=0,1', / '  17=arithm. alpha&beta             ',
      $      '      20=arithmetic alpha, beta=0,1', / '  18=clustered ',
@@ -871,7 +867,7 @@
      $      '23=(small,large)    24=(small,small)    25=(large,large)',
      $      / '  26=random O(1) matrices.' )
 *
- 9990 FORMAT( / ' Tests performed:  (S is Schur, T is triangular, ',
+ 9991 FORMAT( / ' Tests performed:  (S is Schur, T is triangular, ',
      $      'Q and Z are ', A, ',', / 20X,
      $      'l and r are the appropriate left and right', / 19X,
      $      'eigenvectors, resp., a is alpha, b is beta, and', / 19X, A,
@@ -884,10 +880,10 @@
      $      ' (S,T)', / ' 6 = max | ( b A - a B )', A,
      $      ' l | / const.   7 = max | ( b A - a B ) r | / const.',
      $      / 1X )
+ 9990 FORMAT( ' Matrix order=', I5, ', type=', I2, ', seed=',
+     $      4( I4, ',' ), ' result ', I3, ' is', 0P, F8.2 )
  9989 FORMAT( ' Matrix order=', I5, ', type=', I2, ', seed=',
-     $      4( I4, ',' ), ' result ', I2, ' is', 0P, F8.2 )
- 9988 FORMAT( ' Matrix order=', I5, ', type=', I2, ', seed=',
-     $      4( I4, ',' ), ' result ', I2, ' is', 1P, E10.3 )
+     $      4( I4, ',' ), ' result ', I3, ' is', 1P, E10.3 )
 *
 *     End of SDRVGG
 *
