@@ -113,8 +113,7 @@
 *
 *           Tests performed
 *
-            WRITE( IOUNIT, FMT = 9980 )'orthogonal', '''=transpose',
-     $         ( '''', J = 1, 6 )
+            WRITE( IOUNIT, FMT = 9968 )
 *
          ELSE
 *
@@ -130,8 +129,7 @@
 *
 *           Tests performed
 *
-            WRITE( IOUNIT, FMT = 9980 )'unitary', '*=conj.transp.',
-     $         ( '*', J = 1, 6 )
+            WRITE( IOUNIT, FMT = 9967 )
          END IF
 *
       ELSE IF( LSAMEN( 2, C2, 'SG' ) ) THEN
@@ -144,14 +142,14 @@
 *
 *           Matrix types
 *
+            WRITE( IOUNIT, FMT = 9980 )
             WRITE( IOUNIT, FMT = 9979 )
-            WRITE( IOUNIT, FMT = 9978 )
-            WRITE( IOUNIT, FMT = 9977 )'Symmetric'
+            WRITE( IOUNIT, FMT = 9978 )'Symmetric'
 *
 *           Tests performed
 *
+            WRITE( IOUNIT, FMT = 9977 )
             WRITE( IOUNIT, FMT = 9976 )
-            WRITE( IOUNIT, FMT = 9975 )
 *
          ELSE
 *
@@ -161,14 +159,14 @@
 *
 *           Matrix types
 *
+            WRITE( IOUNIT, FMT = 9980 )
             WRITE( IOUNIT, FMT = 9979 )
-            WRITE( IOUNIT, FMT = 9978 )
-            WRITE( IOUNIT, FMT = 9977 )'Hermitian'
+            WRITE( IOUNIT, FMT = 9978 )'Hermitian'
 *
 *           Tests performed
 *
+            WRITE( IOUNIT, FMT = 9975 )
             WRITE( IOUNIT, FMT = 9974 )
-            WRITE( IOUNIT, FMT = 9973 )
 *
          END IF
 *
@@ -182,12 +180,12 @@
 *
 *           Matrix types
 *
-            WRITE( IOUNIT, FMT = 9972 )
+            WRITE( IOUNIT, FMT = 9973 )
 *
 *           Tests performed
 *
-            WRITE( IOUNIT, FMT = 9971 )'orthogonal'
-            WRITE( IOUNIT, FMT = 9970 )
+            WRITE( IOUNIT, FMT = 9972 )'orthogonal'
+            WRITE( IOUNIT, FMT = 9971 )
          ELSE
 *
 *           Complex Singular Value Decomposition:
@@ -196,12 +194,12 @@
 *
 *           Matrix types
 *
-            WRITE( IOUNIT, FMT = 9972 )
+            WRITE( IOUNIT, FMT = 9973 )
 *
 *           Tests performed
 *
-            WRITE( IOUNIT, FMT = 9971 )'unitary   '
-            WRITE( IOUNIT, FMT = 9970 )
+            WRITE( IOUNIT, FMT = 9972 )'unitary   '
+            WRITE( IOUNIT, FMT = 9971 )
          END IF
 *
       ELSE IF( LSAMEN( 2, C2, 'BB' ) ) THEN
@@ -214,11 +212,11 @@
 *
 *           Matrix types
 *
-            WRITE( IOUNIT, FMT = 9969 )
+            WRITE( IOUNIT, FMT = 9970 )
 *
 *           Tests performed
 *
-            WRITE( IOUNIT, FMT = 9968 )'orthogonal'
+            WRITE( IOUNIT, FMT = 9969 )'orthogonal'
          ELSE
 *
 *           Complex Band reduction to bidiagonal form:
@@ -227,11 +225,11 @@
 *
 *           Matrix types
 *
-            WRITE( IOUNIT, FMT = 9969 )
+            WRITE( IOUNIT, FMT = 9970 )
 *
 *           Tests performed
 *
-            WRITE( IOUNIT, FMT = 9968 )'unitary   '
+            WRITE( IOUNIT, FMT = 9969 )'unitary   '
          END IF
 *
       ELSE
@@ -309,30 +307,18 @@
      $      '              ', ' 14=Matrix with large random entries.',
      $      / ' 11=Large, evenly spaced eigenvals.     ', ' 15=Matrix ',
      $      'with small random entries.' )
-*
- 9980 FORMAT( / ' Tests performed:   ', '(S is Tridiag, D is diagonal,',
-     $      ' U and Z are ', A, ',', / 20X, A, ', W is a diagonal matr',
-     $      'ix of eigenvalues)', / '  1= | A - U S U', A1, ' | / ( |A',
-     $      '| n ulp )     ', '  2= | I - U U', A1, ' | / ( n ulp )',
-     $      / '  3= | S - Z D Z', A1, ' | / ( |S| n ulp )     ', '  4=',
-     $      ' | I - Z Z', A1, ' | / ( n ulp )',
-     $      / '  5= | A - UZ D (UZ)', A1, ' | / ( |A| n ulp ) ', '  6=',
-     $      ' | I - UZ (UZ)', A1, ' | / ( n ulp )', / '  7= |D(with Z)',
-     $      ' - D(w/o Z)| / (|D| ulp) ', '  8= | D(PWK) - D(QR) | / (|',
-     $      'D| ulp)', / '  9=   Sturm sequence test on W         ',
-     $      ' 10= | Z(inv it.) - Z(QR) | / (|Z| ulp)' )
 *
 *     Symmetric/Hermitian Generalized eigenproblem
 *
- 9979 FORMAT( ' Matrix types (see xDRVSG for details): ' )
+ 9980 FORMAT( ' Matrix types (see xDRVSG for details): ' )
 *
- 9978 FORMAT( / ' Special Matrices:', / '  1=Zero matrix.             ',
+ 9979 FORMAT( / ' Special Matrices:', / '  1=Zero matrix.             ',
      $      '           ', '  5=Diagonal: clustered entries.', / '  2=',
      $      'Identity matrix.                    ', '  6=Diagonal: lar',
      $      'ge, evenly spaced.', / '  3=Diagonal: evenly spaced entri',
      $      'es.    ', '  7=Diagonal: small, evenly spaced.', / '  4=D',
      $      'iagonal: geometr. spaced entries.' )
- 9977 FORMAT( ' Dense or Banded ', A, ' Matrices: ',
+ 9978 FORMAT( ' Dense or Banded ', A, ' Matrices: ',
      $      / '  8=Evenly spaced eigenvals.         ',
      $      ' 15=Matrix with small random entries.',
      $      / '  9=Geometrically spaced eigenvals.  ',
@@ -347,7 +333,7 @@
      $      ' 20=Evenly spaced eigenvals, KA=3, KB=2.',
      $      / ' 14=Matrix with large random entries.',
      $      ' 21=Evenly spaced eigenvals, KA=3, KB=3.' )
- 9976 FORMAT( / ' Tests performed:   ',
+ 9977 FORMAT( / ' Tests performed:   ',
      $      / '( For each pair (A,B), where A is of the given type ',
      $      / ' and B is a random well-conditioned matrix. D is ',
      $      / ' diagonal, and Z is orthogonal. )',
@@ -363,7 +349,7 @@
      $      '  | A Z - B Z D | / ( |A| |Z| n ulp )     ',
      $      / ' 6 = SSBGV, with ITYPE=1 and UPLO=''L'':',
      $      '  | A Z - B Z D | / ( |A| |Z| n ulp )     ' )
- 9975 FORMAT( ' 7 = SSYGV, with ITYPE=2 and UPLO=''U'':',
+ 9976 FORMAT( ' 7 = SSYGV, with ITYPE=2 and UPLO=''U'':',
      $      '  | A B Z - Z D | / ( |A| |Z| n ulp )     ',
      $      / ' 8 = SSPGV, with ITYPE=2 and UPLO=''U'':',
      $      '  | A B Z - Z D | / ( |A| |Z| n ulp )     ',
@@ -379,7 +365,7 @@
      $      '  | B A Z - Z D | / ( |A| |Z| n ulp )     ',
      $      / '14 = SSPGV, with ITYPE=3 and UPLO=''L'':',
      $      '  | B A Z - Z D | / ( |A| |Z| n ulp )     ' )
- 9974 FORMAT( / ' Tests performed:   ',
+ 9975 FORMAT( / ' Tests performed:   ',
      $      / '( For each pair (A,B), where A is of the given type ',
      $      / ' and B is a random well-conditioned matrix. D is ',
      $      / ' diagonal, and Z is unitary. )',
@@ -395,7 +381,7 @@
      $      '  | A Z - B Z D | / ( |A| |Z| n ulp )     ',
      $      / ' 6 = CHBGV, with ITYPE=1 and UPLO=''L'':',
      $      '  | A Z - B Z D | / ( |A| |Z| n ulp )     ' )
- 9973 FORMAT( ' 7 = CHEGV, with ITYPE=2 and UPLO=''U'':',
+ 9974 FORMAT( ' 7 = CHEGV, with ITYPE=2 and UPLO=''U'':',
      $      '  | A B Z - Z D | / ( |A| |Z| n ulp )     ',
      $      / ' 8 = CHPGV, with ITYPE=2 and UPLO=''U'':',
      $      '  | A B Z - Z D | / ( |A| |Z| n ulp )     ',
@@ -414,7 +400,7 @@
 *
 *     Singular Value Decomposition
 *
- 9972 FORMAT( ' Matrix types (see xCHKBD for details):',
+ 9973 FORMAT( ' Matrix types (see xCHKBD for details):',
      $      / ' Diagonal matrices:', / '   1: Zero', 28X,
      $      ' 5: Clustered entries', / '   2: Identity', 24X,
      $      ' 6: Large, evenly spaced entries',
@@ -429,7 +415,7 @@
      $      / '  11: Large, evenly spaced sing vals  ',
      $      '15: Random, scaled near underflow' )
 *
- 9971 FORMAT( / ' Test ratios:  ',
+ 9972 FORMAT( / ' Test ratios:  ',
      $      '(B: bidiagonal, S: diagonal, Q, P, U, and V: ', A10, / 16X,
      $      'X: m x nrhs, Y = Q'' X, and Z = U'' Y)',
      $      / '   1: norm( A - Q B P'' ) / ( norm(A) max(m,n) ulp )',
@@ -439,9 +425,9 @@
      $      '   5: norm( Y - U Z )    / ( norm(Z) max(min(m,n),k) ulp )'
      $      , / '   6: norm( I - U'' U )   / ( min(m,n) ulp )',
      $      / '   7: norm( I - V'' V )   / ( min(m,n) ulp )' )
- 9970 FORMAT( '   8: Test ordering of S  (0 if nondecreasing, 1/ulp ',
-     $      ' otherwise)', 
-     $      / '   9: norm( S - S2 )     / ( norm(S) ulp ),',
+ 9971 FORMAT( '   8: Test ordering of S  (0 if nondecreasing, 1/ulp ',
+     $      ' otherwise)', /
+     $      '   9: norm( S - S2 )     / ( norm(S) ulp ),',
      $      ' where S2 is computed', / 44X,
      $      'without computing U and V''',
      $      / '  10: Sturm sequence test ',
@@ -454,7 +440,7 @@
 *
 *     Band reduction to bidiagonal form
 *
- 9969 FORMAT( ' Matrix types (see xCHKBB for details):',
+ 9970 FORMAT( ' Matrix types (see xCHKBB for details):',
      $      / ' Diagonal matrices:', / '   1: Zero', 28X,
      $      ' 5: Clustered entries', / '   2: Identity', 24X,
      $      ' 6: Large, evenly spaced entries',
@@ -469,12 +455,14 @@
      $      / '  11: Large, evenly spaced sing vals  ',
      $      '15: Random, scaled near underflow' )
 *
- 9968 FORMAT( / ' Test ratios:  ', '(B: upper bidiagonal, Q and P: ',
+ 9969 FORMAT( / ' Test ratios:  ', '(B: upper bidiagonal, Q and P: ',
      $      A10, / 16X, 'C: m x nrhs, PT = P'', Y = Q'' C)',
      $      / ' 1: norm( A - Q B PT ) / ( norm(A) max(m,n) ulp )',
      $      / ' 2: norm( I - Q'' Q )   / ( m ulp )',
      $      / ' 3: norm( I - PT PT'' )   / ( n ulp )',
      $      / ' 4: norm( Y - Q'' C )   / ( norm(Y) max(m,nrhs) ulp )' )
+ 9968 FORMAT( / ' Tests performed:  See sdrvst.f' )
+ 9967 FORMAT( / ' Tests performed:  See cdrvst.f' )
 *
 *     End of SLAHD2
 *
