@@ -1,9 +1,9 @@
       PROGRAM ZCHKEE
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *  Purpose
 *  =======
@@ -21,7 +21,7 @@
 *
 *  SVD (Singular Value Decomposition):
 *      Test ZGEBRD, ZUNGBR, and ZBDSQR
-*      and the driver routine ZGESVD
+*      and the drivers ZGESVD, ZGESDD
 *
 *  ZEV (Nonsymmetric Eigenvalue/eigenvector Driver):
 *      Test ZGEEV
@@ -39,8 +39,21 @@
 *      Test ZGGHRD, ZGGBAL, ZGGBAK, ZHGEQZ, and ZTGEVC
 *      and the driver routines ZGEGS and ZGEGV
 *
+*  ZGS (Generalized Nonsymmetric Schur form Driver):
+*      Test ZGGES
+*
+*  ZGV (Generalized Nonsymmetric Eigenvalue/eigenvector Driver):
+*      Test ZGGEV
+*
+*  ZGX (Generalized Nonsymmetric Schur form Expert Driver):
+*      Test ZGGESX
+*
+*  ZXV (Generalized Nonsymmetric Eigenvalue/eigenvector Expert Driver):
+*      Test ZGGEVX
+*
 *  ZSG (Hermitian Generalized Eigenvalue Problem):
-*      Test ZHEGST, ZHEGV, ZHPGST, ZHPGV, ZHBGST, and ZHBGV
+*      Test ZHEGST, ZHEGV, ZHEGVD, ZHEGVX, ZHPGST, ZHPGV, ZHPGVD,
+*      ZHPGVX, ZHBGST, ZHBGV, ZHBGVD, and ZHBGVX
 *
 *  ZHB (Hermitian Band Eigenvalue Problem):
 *      Test ZHBTRD
@@ -98,6 +111,10 @@
 *  ZSX             21     ZDRVSX
 *  ZGG             26     ZCHKGG (routines)
 *                  26     ZDRVGG (drivers)
+*  ZGS             26     ZDRGES
+*  ZGX              5     ZDRGSX
+*  ZGV             26     ZDRGEV
+*  ZXV              2     ZDRGVX
 *  ZSG             21     ZDRVSG
 *  ZHB             15     ZCHKHB
 *  ZBB             15     ZCHKBB
@@ -331,8 +348,8 @@
 *           Four integer values for the random number seed.
 *
 *  lines 8 and following:  Lines specifying matrix types, as for NEP.
-*           The 3-character path name is 'ZEV' to test ZGEEV, or
-*           'ZES' to test ZGEES.
+*           The 3-character path name is 'ZEV' to test CGEEV, or
+*           'ZES' to test CGEES.
 *
 *-----------------------------------------------------------------------
 *
@@ -488,6 +505,160 @@
 *
 *-----------------------------------------------------------------------
 *
+*  ZGS and ZGV input files:
+*
+*  line 1:  'ZGS' or 'ZGV' in columns 1 to 3.
+*
+*  line 2:  NN, INTEGER
+*           Number of values of N.
+*
+*  line 3:  NVAL, INTEGER array, dimension(NN)
+*           Dimensions of matrices to be tested.
+*
+*  line 4:  NB, NBMIN, NX, NS, NBCOL, INTEGERs
+*           These integer parameters determine how blocking is done
+*           (see ILAENV for details)
+*           NB     : block size
+*           NBMIN  : minimum block size
+*           NX     : minimum dimension for blocking
+*           NS     : number of shifts in xHGEQR
+*           NBCOL  : minimum column dimension for blocking
+*
+*  line 5:  THRESH, REAL
+*           The test threshold against which computed residuals are
+*           compared. Should generally be in the range from 10. to 20.
+*           If it is 0., all test case data will be printed.
+*
+*  line 6:  TSTERR, LOGICAL
+*           Flag indicating whether or not to test the error exits.
+*
+*  line 7:  NEWSD, INTEGER
+*           A code indicating how to set the random number seed.
+*           = 0:  Set the seed to a default value before each run
+*           = 1:  Initialize the seed to a default value only before the
+*                 first run
+*           = 2:  Like 1, but use the seed values on the next line
+*
+*  If line 17 was 2:
+*
+*  line 7:  INTEGER array, dimension (4)
+*           Four integer values for the random number seed.
+*
+*  lines 7-EOF:  Lines specifying matrix types, as for NEP.
+*           The 3-character path name is 'ZGS' for the generalized
+*           eigenvalue problem routines and driver routines.
+*
+*-----------------------------------------------------------------------
+*
+*  ZGX input file:
+*  line 1:  'ZGX' in columns 1 to 3.
+*
+*  line 2:  N, INTEGER
+*           Value of N.
+*
+*  line 3:  NB, NBMIN, NX, NS, NBCOL, INTEGERs
+*           These integer parameters determine how blocking is done
+*           (see ILAENV for details)
+*           NB     : block size
+*           NBMIN  : minimum block size
+*           NX     : minimum dimension for blocking
+*           NS     : number of shifts in xHGEQR
+*           NBCOL  : minimum column dimension for blocking
+*
+*  line 4:  THRESH, REAL
+*           The test threshold against which computed residuals are
+*           compared. Should generally be in the range from 10. to 20.
+*           Information will be printed about each test for which the
+*           test ratio is greater than or equal to the threshold.
+*
+*  line 5:  TSTERR, LOGICAL
+*           Flag indicating whether or not to test the error exits for
+*           the LAPACK routines and driver routines.
+*
+*  line 6:  NEWSD, INTEGER
+*           A code indicating how to set the random number seed.
+*           = 0:  Set the seed to a default value before each run
+*           = 1:  Initialize the seed to a default value only before the
+*                 first run
+*           = 2:  Like 1, but use the seed values on the next line
+*
+*  If line 6 was 2:
+*
+*  line 7: INTEGER array, dimension (4)
+*           Four integer values for the random number seed.
+*
+*  If line 2 was 0:
+*
+*  line 7-EOF: Precomputed examples are tested.
+*
+*  remaining lines : Each example is stored on 3+2*N*N lines, where N is
+*           its dimension. The first line contains the dimension (a
+*           single integer).  The next line contains an integer k such
+*           that only the last k eigenvalues will be selected and appear
+*           in the leading diagonal blocks of $A$ and $B$. The next N*N
+*           lines contain the matrix A, one element per line. The next N*N
+*           lines contain the matrix B. The last line contains the
+*           reciprocal of the eigenvalue cluster condition number and the
+*           reciprocal of the deflating subspace (associated with the
+*           selected eigencluster) condition number.  The end of data is
+*           indicated by dimension N=0.  Even if no data is to be tested,
+*           there must be at least one line containing N=0.
+*
+*-----------------------------------------------------------------------
+*
+*  ZXV input files:
+*  line 1:  'ZXV' in columns 1 to 3.
+*
+*  line 2:  N, INTEGER
+*           Value of N.
+*
+*  line 3:  NB, NBMIN, NX, NS, NBCOL, INTEGERs
+*           These integer parameters determine how blocking is done
+*           (see ILAENV for details)
+*           NB     : block size
+*           NBMIN  : minimum block size
+*           NX     : minimum dimension for blocking
+*           NS     : number of shifts in xHGEQR
+*           NBCOL  : minimum column dimension for blocking
+*
+*  line 4:  THRESH, REAL
+*           The test threshold against which computed residuals are
+*           compared. Should generally be in the range from 10. to 20.
+*           Information will be printed about each test for which the
+*           test ratio is greater than or equal to the threshold.
+*
+*  line 5:  TSTERR, LOGICAL
+*           Flag indicating whether or not to test the error exits for
+*           the LAPACK routines and driver routines.
+*
+*  line 6:  NEWSD, INTEGER
+*           A code indicating how to set the random number seed.
+*           = 0:  Set the seed to a default value before each run
+*           = 1:  Initialize the seed to a default value only before the
+*                 first run
+*           = 2:  Like 1, but use the seed values on the next line
+*
+*  If line 6 was 2:
+*
+*  line 7: INTEGER array, dimension (4)
+*           Four integer values for the random number seed.
+*
+*  If line 2 was 0:
+*
+*  line 7-EOF: Precomputed examples are tested.
+*
+*  remaining lines : Each example is stored on 3+2*N*N lines, where N is
+*           its dimension. The first line contains the dimension (a
+*           single integer). The next N*N lines contain the matrix A, one
+*           element per line. The next N*N lines contain the matrix B.
+*           The next line contains the reciprocals of the eigenvalue
+*           condition numbers.  The last line contains the reciprocals of
+*           the eigenvector condition numbers.  The end of data is
+*           indicated by dimension N=0.  Even if no data is to be tested,
+*           there must be at least one line containing N=0.
+*
+*-----------------------------------------------------------------------
+*
 *  ZHB input file:
 *
 *  line 2:  NN, INTEGER
@@ -586,8 +757,8 @@
 *
 *  ZBL and ZBK input files:
 *
-*  line 1:  'ZBL' in columns 1-3 to test ZGEBAL, or 'ZBK' in
-*           columns 1-3 to test ZGEBAK.
+*  line 1:  'ZBL' in columns 1-3 to test CGEBAL, or 'ZBK' in
+*           columns 1-3 to test CGEBAK.
 *
 *  The remaining lines consist of specially constructed test cases.
 *
@@ -784,6 +955,8 @@
 *     .. Parameters ..
       INTEGER            NMAX
       PARAMETER          ( NMAX = 132 )
+      INTEGER            NCMAX
+      PARAMETER          ( NCMAX = 20 )
       INTEGER            NEED
       PARAMETER          ( NEED = 14 )
       INTEGER            LWORK
@@ -798,9 +971,10 @@
       PARAMETER          ( NIN = 5, NOUT = 6 )
 *     ..
 *     .. Local Scalars ..
-      LOGICAL            FATAL, GLM, GQR, GSV, LSE, NEP, SEP, SVD,
-     $                   TSTCHK, TSTDIF, TSTDRV, TSTERR, ZBB, ZBK, ZBL,
-     $                   ZES, ZEV, ZGG, ZGK, ZGL, ZHB, ZSX, ZVX
+      LOGICAL            ZBK, ZBL, ZES, ZEV, ZGK, ZGL, ZGS, ZGV, ZGX,
+     $                   ZSX, ZVX, ZXV, FATAL, GLM, GQR, GSV, LSE, NEP,
+     $                   SEP, SVD, TSTCHK, TSTDIF, TSTDRV, TSTERR, ZBB,
+     $                   ZGG, ZHB
       CHARACTER          C1
       CHARACTER*3        C3, PATH
       CHARACTER*6        VNAME
@@ -817,11 +991,12 @@
      $                   NBCOL( MAXIN ), NBMIN( MAXIN ), NBVAL( MAXIN ),
      $                   NSVAL( MAXIN ), NVAL( MAXIN ), NXVAL( MAXIN ),
      $                   PVAL( MAXIN )
-      DOUBLE PRECISION   ALPHA( NMAX ), BETA( NMAX ), DR( NMAX, 11 ),
-     $                   RESULT( 105 ), RWORK( LWORK )
+      DOUBLE PRECISION   ALPHA( NMAX ), BETA( NMAX ), DR( NMAX, 12 ),
+     $                   RESULT( 500 ), RWORK( LWORK ), S( NMAX*NMAX )
       COMPLEX*16         A( NMAX*NMAX, NEED ), B( NMAX*NMAX, 5 ),
-     $                   DC( NMAX, 6 ), TAUA( NMAX ), TAUB( NMAX ),
-     $                   WORK( LWORK ), X( 5*NMAX )
+     $                   C( NCMAX*NCMAX, NCMAX*NCMAX ), DC( NMAX, 6 ),
+     $                   TAUA( NMAX ), TAUB( NMAX ), WORK( LWORK ),
+     $                   X( 5*NMAX )
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAMEN
@@ -831,9 +1006,10 @@
 *     .. External Subroutines ..
       EXTERNAL           ALAREQ, XLAENV, ZCHKBB, ZCHKBD, ZCHKBK, ZCHKBL,
      $                   ZCHKEC, ZCHKGG, ZCHKGK, ZCHKGL, ZCHKHB, ZCHKHS,
-     $                   ZCHKST, ZCKGLM, ZCKGQR, ZCKGSV, ZCKLSE, ZDRVBD,
-     $                   ZDRVES, ZDRVEV, ZDRVGG, ZDRVSG, ZDRVST, ZDRVSX,
-     $                   ZDRVVX, ZERRBD, ZERRED, ZERRGG, ZERRHS, ZERRST
+     $                   ZCHKST, ZCKGLM, ZCKGQR, ZCKGSV, ZCKLSE, ZDRGES,
+     $                   ZDRGEV, ZDRGSX, ZDRGVX, ZDRVBD, ZDRVES, ZDRVEV,
+     $                   ZDRVGG, ZDRVSG, ZDRVST, ZDRVSX, ZDRVVX, ZERRBD,
+     $                   ZERRED, ZERRGG, ZERRHS, ZERRST
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          LEN, MIN
@@ -872,7 +1048,7 @@
 *
 *     Read the first line and set the 3-character test path
 *
-      READ( NIN, FMT = '(A80)', END = 370 )LINE
+      READ( NIN, FMT = '(A80)', END = 380 )LINE
       PATH = LINE( 1: 3 )
       NEP = LSAMEN( 3, PATH, 'NEP' ) .OR. LSAMEN( 3, PATH, 'ZHS' )
       SEP = LSAMEN( 3, PATH, 'SEP' ) .OR. LSAMEN( 3, PATH, 'ZST' ) .OR.
@@ -883,6 +1059,10 @@
       ZVX = LSAMEN( 3, PATH, 'ZVX' )
       ZSX = LSAMEN( 3, PATH, 'ZSX' )
       ZGG = LSAMEN( 3, PATH, 'ZGG' )
+      ZGS = LSAMEN( 3, PATH, 'ZGS' )
+      ZGX = LSAMEN( 3, PATH, 'ZGX' )
+      ZGV = LSAMEN( 3, PATH, 'ZGV' )
+      ZXV = LSAMEN( 3, PATH, 'ZXV' )
       ZHB = LSAMEN( 3, PATH, 'ZHB' )
       ZBB = LSAMEN( 3, PATH, 'ZBB' )
       GLM = LSAMEN( 3, PATH, 'GLM' )
@@ -914,6 +1094,14 @@
          WRITE( NOUT, FMT = 9976 )
       ELSE IF( ZGG ) THEN
          WRITE( NOUT, FMT = 9975 )
+      ELSE IF( ZGS ) THEN
+         WRITE( NOUT, FMT = 9964 )
+      ELSE IF( ZGX ) THEN
+         WRITE( NOUT, FMT = 9965 )
+      ELSE IF( ZGV ) THEN
+         WRITE( NOUT, FMT = 9963 )
+      ELSE IF( ZXV ) THEN
+         WRITE( NOUT, FMT = 9962 )
       ELSE IF( ZHB ) THEN
          WRITE( NOUT, FMT = 9974 )
       ELSE IF( ZBB ) THEN
@@ -931,25 +1119,25 @@
 *        ZGEBAL:  Balancing
 *
          CALL ZCHKBL( NIN, NOUT )
-         GO TO 370
+         GO TO 380
       ELSE IF( ZBK ) THEN
 *
 *        ZGEBAK:  Back transformation
 *
          CALL ZCHKBK( NIN, NOUT )
-         GO TO 370
+         GO TO 380
       ELSE IF( ZGL ) THEN
 *
 *        ZGGBAL:  Balancing
 *
          CALL ZCHKGL( NIN, NOUT )
-         GO TO 370
+         GO TO 380
       ELSE IF( ZGK ) THEN
 *
 *        ZGGBAK:  Back transformation
 *
          CALL ZCHKGK( NIN, NOUT )
-         GO TO 370
+         GO TO 380
       ELSE IF( LSAMEN( 3, PATH, 'ZEC' ) ) THEN
 *
 *        ZEC:  Eigencondition estimation
@@ -957,10 +1145,10 @@
          READ( NIN, FMT = * )THRESH
          TSTERR = .TRUE.
          CALL ZCHKEC( THRESH, TSTERR, NIN, NOUT )
-         GO TO 370
+         GO TO 380
       ELSE
          WRITE( NOUT, FMT = 9992 )PATH
-         GO TO 370
+         GO TO 380
       END IF
       WRITE( NOUT, FMT = 9972 )
       WRITE( NOUT, FMT = 9984 )
@@ -968,7 +1156,7 @@
 *     Read the number of values of M, P, and N.
 *
       READ( NIN, FMT = * )NN
-      IF( NN.LT.1 ) THEN
+      IF( NN.LT.0 ) THEN
          WRITE( NOUT, FMT = 9989 )'   NN ', NN, 1
          NN = 0
          FATAL = .TRUE.
@@ -980,22 +1168,24 @@
 *
 *     Read the values of M
 *
-      READ( NIN, FMT = * )( MVAL( I ), I = 1, NN )
-      IF( SVD ) THEN
-         VNAME = '    M '
-      ELSE
-         VNAME = '    N '
-      END IF
-      DO 20 I = 1, NN
-         IF( MVAL( I ).LT.0 ) THEN
-            WRITE( NOUT, FMT = 9989 )VNAME, MVAL( I ), 0
-            FATAL = .TRUE.
-         ELSE IF( MVAL( I ).GT.NMAX ) THEN
-            WRITE( NOUT, FMT = 9988 )VNAME, MVAL( I ), NMAX
-            FATAL = .TRUE.
+      IF( .NOT.( ZGX .OR. ZXV ) ) THEN
+         READ( NIN, FMT = * )( MVAL( I ), I = 1, NN )
+         IF( SVD ) THEN
+            VNAME = '    M '
+         ELSE
+            VNAME = '    N '
          END IF
-   20 CONTINUE
-      WRITE( NOUT, FMT = 9983 )'M:    ', ( MVAL( I ), I = 1, NN )
+         DO 20 I = 1, NN
+            IF( MVAL( I ).LT.0 ) THEN
+               WRITE( NOUT, FMT = 9989 )VNAME, MVAL( I ), 0
+               FATAL = .TRUE.
+            ELSE IF( MVAL( I ).GT.NMAX ) THEN
+               WRITE( NOUT, FMT = 9988 )VNAME, MVAL( I ), NMAX
+               FATAL = .TRUE.
+            END IF
+   20    CONTINUE
+         WRITE( NOUT, FMT = 9983 )'M:    ', ( MVAL( I ), I = 1, NN )
+      END IF
 *
 *     Read the values of P
 *
@@ -1031,7 +1221,11 @@
             NVAL( I ) = MVAL( I )
    50    CONTINUE
       END IF
-      WRITE( NOUT, FMT = 9983 )'N:    ', ( NVAL( I ), I = 1, NN )
+      IF( .NOT.( ZGX .OR. ZXV ) ) THEN
+         WRITE( NOUT, FMT = 9983 )'N:    ', ( NVAL( I ), I = 1, NN )
+      ELSE
+         WRITE( NOUT, FMT = 9983 )'N:    ', NN
+      END IF
 *
 *     Read the number of values of K, followed by the values of K
 *
@@ -1050,7 +1244,8 @@
          WRITE( NOUT, FMT = 9983 )'K:    ', ( KVAL( I ), I = 1, NK )
       END IF
 *
-      IF( ZEV .OR. ZES .OR. ZVX .OR. ZSX ) THEN
+      IF( ZEV .OR. ZES .OR. ZVX .OR. ZSX .OR. ZGS .OR. ZGX .OR. ZGV .OR.
+     $    ZXV ) THEN
 *
 *        For the nonsymmetric driver routines, only one set of
 *        parameters is allowed.
@@ -1277,61 +1472,72 @@
 *     4-80.
 *
   190 CONTINUE
-      READ( NIN, FMT = '(A80)', END = 370 )LINE
-      C3 = LINE( 1: 3 )
-      LENP = LEN( LINE )
-      I = 3
-      ITMP = 0
-      I1 = 0
-  200 CONTINUE
-      I = I + 1
-      IF( I.GT.LENP ) THEN
-         IF( I1.GT.0 ) THEN
-            GO TO 230
-         ELSE
-            NTYPES = MAXT
-            GO TO 230
+*
+      IF( .NOT.( ZGX .OR. ZXV ) ) THEN
+*
+  200    CONTINUE
+         READ( NIN, FMT = '(A80)', END = 380 )LINE
+         C3 = LINE( 1: 3 )
+         LENP = LEN( LINE )
+         I = 3
+         ITMP = 0
+         I1 = 0
+  210    CONTINUE
+         I = I + 1
+         IF( I.GT.LENP ) THEN
+            IF( I1.GT.0 ) THEN
+               GO TO 240
+            ELSE
+               NTYPES = MAXT
+               GO TO 240
+            END IF
          END IF
-      END IF
-      IF( LINE( I: I ).NE.' ' .AND. LINE( I: I ).NE.',' ) THEN
-         I1 = I
-         C1 = LINE( I1: I1 )
+         IF( LINE( I: I ).NE.' ' .AND. LINE( I: I ).NE.',' ) THEN
+            I1 = I
+            C1 = LINE( I1: I1 )
 *
 *        Check that a valid integer was read
 *
-         DO 210 K = 1, 10
-            IF( C1.EQ.INTSTR( K: K ) ) THEN
-               IC = K - 1
-               GO TO 220
-            END IF
-  210    CONTINUE
-         WRITE( NOUT, FMT = 9991 )I, LINE
-         GO TO 190
-  220    CONTINUE
-         ITMP = 10*ITMP + IC
-         GO TO 200
-      ELSE IF( I1.GT.0 ) THEN
-         GO TO 230
-      ELSE
-         GO TO 200
-      END IF
-  230 CONTINUE
-      NTYPES = ITMP
+            DO 220 K = 1, 10
+               IF( C1.EQ.INTSTR( K: K ) ) THEN
+                  IC = K - 1
+                  GO TO 230
+               END IF
+  220       CONTINUE
+            WRITE( NOUT, FMT = 9991 )I, LINE
+            GO TO 200
+  230       CONTINUE
+            ITMP = 10*ITMP + IC
+            GO TO 210
+         ELSE IF( I1.GT.0 ) THEN
+            GO TO 240
+         ELSE
+            GO TO 210
+         END IF
+  240    CONTINUE
+         NTYPES = ITMP
 *
 *     Skip the tests if NTYPES is <= 0.
 *
-      IF( .NOT.( ZEV .OR. ZES .OR. ZVX .OR. ZSX ) .AND. NTYPES.LE.0 )
-     $     THEN
-         WRITE( NOUT, FMT = 9990 )C3
-         GO TO 190
+         IF( .NOT.( ZEV .OR. ZES .OR. ZVX .OR. ZSX .OR. ZGV .OR.
+     $       ZGS ) .AND. NTYPES.LE.0 ) THEN
+            WRITE( NOUT, FMT = 9990 )C3
+            GO TO 200
+         END IF
+*
+      ELSE
+         IF( ZGX )
+     $      C3 = 'ZGX'
+         IF( ZXV )
+     $      C3 = 'ZXV'
       END IF
 *
 *     Reset the random number seed.
 *
       IF( NEWSD.EQ.0 ) THEN
-         DO 240 K = 1, 4
+         DO 250 K = 1, 4
             ISEED( K ) = IOLDSD( K )
-  240    CONTINUE
+  250    CONTINUE
       END IF
 *
       IF( LSAMEN( 3, C3, 'ZHS' ) .OR. LSAMEN( 3, C3, 'NEP' ) ) THEN
@@ -1351,7 +1557,7 @@
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
          IF( TSTERR )
      $      CALL ZERRHS( 'ZHSEQR', NOUT )
-         DO 260 I = 1, NPARMS
+         DO 270 I = 1, NPARMS
             CALL XLAENV( 1, NBVAL( I ) )
             CALL XLAENV( 2, NBMIN( I ) )
             CALL XLAENV( 3, NXVAL( I ) )
@@ -1359,9 +1565,9 @@
             CALL XLAENV( 8, MXBVAL( I ) )
 *
             IF( NEWSD.EQ.0 ) THEN
-               DO 250 K = 1, 4
+               DO 260 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  250          CONTINUE
+  260          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9998 )C3, NBVAL( I ), NBMIN( I ),
      $         NXVAL( I ), NSVAL( I ), MXBVAL( I )
@@ -1374,7 +1580,7 @@
      $                   RESULT, INFO )
             IF( INFO.NE.0 )
      $         WRITE( NOUT, FMT = 9980 )'ZCHKHS', INFO
-  260    CONTINUE
+  270    CONTINUE
 *
       ELSE IF( LSAMEN( 3, C3, 'ZST' ) .OR. LSAMEN( 3, C3, 'SEP' ) ) THEN
 *
@@ -1386,20 +1592,21 @@
 *           NBMIN = minimum block size
 *           NX    = crossover point
 *
-         MAXTYP = 15
+         MAXTYP = 21
          NTYPES = MIN( MAXTYP, NTYPES )
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+         CALL XLAENV( 9, 25 )
          IF( TSTERR )
      $      CALL ZERRST( 'ZST', NOUT )
-         DO 280 I = 1, NPARMS
+         DO 290 I = 1, NPARMS
             CALL XLAENV( 1, NBVAL( I ) )
             CALL XLAENV( 2, NBMIN( I ) )
             CALL XLAENV( 3, NXVAL( I ) )
 *
             IF( NEWSD.EQ.0 ) THEN
-               DO 270 K = 1, 4
+               DO 280 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  270          CONTINUE
+  280          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9997 )C3, NBVAL( I ), NBMIN( I ),
      $         NXVAL( I )
@@ -1411,21 +1618,22 @@
      $                      DR( 1, 7 ), DR( 1, 8 ), DR( 1, 9 ),
      $                      DR( 1, 10 ), DR( 1, 11 ), A( 1, 3 ), NMAX,
      $                      A( 1, 4 ), A( 1, 5 ), DC( 1, 1 ), A( 1, 6 ),
-     $                      WORK, LWORK, RWORK, IWORK, RESULT, INFO )
+     $                      WORK, LWORK, RWORK, LWORK, IWORK, LIWORK,
+     $                      RESULT, INFO )
                IF( INFO.NE.0 )
      $            WRITE( NOUT, FMT = 9980 )'ZCHKST', INFO
             END IF
             IF( TSTDRV ) THEN
-               CALL ZDRVST( NN, NVAL, MAXTYP, DOTYPE, ISEED, THRESH,
-     $                      NOUT, A( 1, 1 ), NMAX, DR( 1, 3 ),
-     $                      DR( 1, 4 ), DR( 1, 5 ), DR( 1, 8 ),
-     $                      DR( 1, 9 ), DR( 1, 10 ), A( 1, 2 ), NMAX,
-     $                      A( 1, 3 ), DC( 1, 1 ), A( 1, 4 ), WORK,
-     $                      LWORK, RWORK, IWORK, RESULT, INFO )
+               CALL ZDRVST( NN, NVAL, 18, DOTYPE, ISEED, THRESH, NOUT,
+     $                      A( 1, 1 ), NMAX, DR( 1, 3 ), DR( 1, 4 ),
+     $                      DR( 1, 5 ), DR( 1, 8 ), DR( 1, 9 ),
+     $                      DR( 1, 10 ), A( 1, 2 ), NMAX, A( 1, 3 ),
+     $                      DC( 1, 1 ), A( 1, 4 ), WORK, LWORK, RWORK,
+     $                      LWORK, IWORK, LIWORK, RESULT, INFO )
                IF( INFO.NE.0 )
      $            WRITE( NOUT, FMT = 9980 )'ZDRVST', INFO
             END IF
-  280    CONTINUE
+  290    CONTINUE
 *
       ELSE IF( LSAMEN( 3, C3, 'ZSG' ) ) THEN
 *
@@ -1440,15 +1648,16 @@
          MAXTYP = 21
          NTYPES = MIN( MAXTYP, NTYPES )
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
-         DO 300 I = 1, NPARMS
+         CALL XLAENV( 9, 25 )
+         DO 310 I = 1, NPARMS
             CALL XLAENV( 1, NBVAL( I ) )
             CALL XLAENV( 2, NBMIN( I ) )
             CALL XLAENV( 3, NXVAL( I ) )
 *
             IF( NEWSD.EQ.0 ) THEN
-               DO 290 K = 1, 4
+               DO 300 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  290          CONTINUE
+  300          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9997 )C3, NBVAL( I ), NBMIN( I ),
      $         NXVAL( I )
@@ -1457,11 +1666,12 @@
      $                      NOUT, A( 1, 1 ), NMAX, A( 1, 2 ), NMAX,
      $                      DR( 1, 3 ), A( 1, 3 ), NMAX, A( 1, 4 ),
      $                      A( 1, 5 ), A( 1, 6 ), A( 1, 7 ), WORK,
-     $                      LWORK, RWORK, IWORK, RESULT, INFO )
+     $                      LWORK, RWORK, LWORK, IWORK, LIWORK, RESULT,
+     $                      INFO )
                IF( INFO.NE.0 )
      $            WRITE( NOUT, FMT = 9980 )'ZDRVSG', INFO
             END IF
-  300    CONTINUE
+  310    CONTINUE
 *
       ELSE IF( LSAMEN( 3, C3, 'ZBD' ) .OR. LSAMEN( 3, C3, 'SVD' ) ) THEN
 *
@@ -1477,23 +1687,24 @@
          MAXTYP = 16
          NTYPES = MIN( MAXTYP, NTYPES )
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+         CALL XLAENV( 9, 25 )
 *
 *        Test the error exits
 *
          IF( TSTERR .AND. TSTCHK )
-     $      CALL ZERRBD( 'ZBDSQR', NOUT )
+     $      CALL ZERRBD( 'ZBD', NOUT )
          IF( TSTERR .AND. TSTDRV )
-     $      CALL ZERRED( 'ZBDSQR', NOUT )
+     $      CALL ZERRED( 'ZBD', NOUT )
 *
-         DO 320 I = 1, NPARMS
+         DO 330 I = 1, NPARMS
             NRHS = NSVAL( I )
             CALL XLAENV( 1, NBVAL( I ) )
             CALL XLAENV( 2, NBMIN( I ) )
             CALL XLAENV( 3, NXVAL( I ) )
             IF( NEWSD.EQ.0 ) THEN
-               DO 310 K = 1, 4
+               DO 320 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  310          CONTINUE
+  320          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9995 )C3, NBVAL( I ), NBMIN( I ),
      $         NXVAL( I ), NRHS
@@ -1512,8 +1723,9 @@
      $                      THRESH, A( 1, 1 ), NMAX, A( 1, 2 ), NMAX,
      $                      A( 1, 3 ), NMAX, A( 1, 4 ), A( 1, 5 ),
      $                      A( 1, 6 ), DR( 1, 1 ), DR( 1, 2 ),
-     $                      DR( 1, 3 ), WORK, LWORK, RWORK, NOUT, INFO )
-  320    CONTINUE
+     $                      DR( 1, 3 ), WORK, LWORK, RWORK, IWORK, NOUT,
+     $                      INFO )
+  330    CONTINUE
 *
       ELSE IF( LSAMEN( 3, C3, 'ZEV' ) ) THEN
 *
@@ -1576,7 +1788,7 @@
 *
          MAXTYP = 21
          NTYPES = MIN( MAXTYP, NTYPES )
-         IF( NTYPES.LE.0 ) THEN
+         IF( NTYPES.LT.0 ) THEN
             WRITE( NOUT, FMT = 9990 )C3
          ELSE
             IF( TSTERR )
@@ -1604,7 +1816,7 @@
 *
          MAXTYP = 21
          NTYPES = MIN( MAXTYP, NTYPES )
-         IF( NTYPES.LE.0 ) THEN
+         IF( NTYPES.LT.0 ) THEN
             WRITE( NOUT, FMT = 9990 )C3
          ELSE
             IF( TSTERR )
@@ -1638,7 +1850,7 @@
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
          IF( TSTCHK .AND. TSTERR )
      $      CALL ZERRGG( C3, NOUT )
-         DO 340 I = 1, NPARMS
+         DO 350 I = 1, NPARMS
             CALL XLAENV( 1, NBVAL( I ) )
             CALL XLAENV( 2, NBMIN( I ) )
             CALL XLAENV( 4, NSVAL( I ) )
@@ -1646,9 +1858,9 @@
             CALL XLAENV( 5, NBCOL( I ) )
 *
             IF( NEWSD.EQ.0 ) THEN
-               DO 330 K = 1, 4
+               DO 340 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  330          CONTINUE
+  340          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9996 )C3, NBVAL( I ), NBMIN( I ),
      $         NSVAL( I ), MXBVAL( I ), NBCOL( I )
@@ -1677,7 +1889,116 @@
                IF( INFO.NE.0 )
      $            WRITE( NOUT, FMT = 9980 )'ZDRVGG', INFO
             END IF
-  340    CONTINUE
+  350    CONTINUE
+*
+      ELSE IF( LSAMEN( 3, C3, 'ZGS' ) ) THEN
+*
+*        -------------------------------------------------
+*        ZGS:  Generalized Nonsymmetric Eigenvalue Problem
+*              ZGGES (Schur form)
+*        -------------------------------------------------
+*
+         MAXTYP = 26
+         NTYPES = MIN( MAXTYP, NTYPES )
+         IF( NTYPES.LE.0 ) THEN
+            WRITE( NOUT, FMT = 9990 )C3
+         ELSE
+            IF( TSTERR )
+     $         CALL ZERRGG( C3, NOUT )
+            CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+            CALL ZDRGES( NN, NVAL, MAXTYP, DOTYPE, ISEED, THRESH, NOUT,
+     $                   A( 1, 1 ), NMAX, A( 1, 2 ), A( 1, 3 ),
+     $                   A( 1, 4 ), A( 1, 7 ), NMAX, A( 1, 8 ),
+     $                   DC( 1, 1 ), DC( 1, 2 ), WORK, LWORK, RWORK,
+     $                   RESULT, LOGWRK, INFO )
+*
+            IF( INFO.NE.0 )
+     $         WRITE( NOUT, FMT = 9980 )'ZDRGES', INFO
+         END IF
+         WRITE( NOUT, FMT = 9973 )
+         GO TO 10
+*
+      ELSE IF( ZGX ) THEN
+*
+*        -------------------------------------------------
+*        ZGX  Generalized Nonsymmetric Eigenvalue Problem
+*              ZGGESX (Schur form and condition numbers)
+*        -------------------------------------------------
+*
+         MAXTYP = 5
+         NTYPES = MAXTYP
+         IF( NN.LT.0 ) THEN
+            WRITE( NOUT, FMT = 9990 )C3
+         ELSE
+            IF( TSTERR )
+     $         CALL ZERRGG( C3, NOUT )
+            CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+            CALL ZDRGSX( NN, NCMAX, THRESH, NIN, NOUT, A( 1, 1 ), NMAX,
+     $                   A( 1, 2 ), A( 1, 3 ), A( 1, 4 ), A( 1, 5 ),
+     $                   A( 1, 6 ), DC( 1, 1 ), DC( 1, 2 ), C,
+     $                   NCMAX*NCMAX, S, WORK, LWORK, RWORK, IWORK,
+     $                   LIWORK, LOGWRK, INFO )
+            IF( INFO.NE.0 )
+     $         WRITE( NOUT, FMT = 9980 )'ZDRGSX', INFO
+         END IF
+         WRITE( NOUT, FMT = 9973 )
+         GO TO 10
+*
+      ELSE IF( LSAMEN( 3, C3, 'ZGV' ) ) THEN
+*
+*        -------------------------------------------------
+*        ZGV:  Generalized Nonsymmetric Eigenvalue Problem
+*              ZGGEV (Eigenvalue/vector form)
+*        -------------------------------------------------
+*
+         MAXTYP = 26
+         NTYPES = MIN( MAXTYP, NTYPES )
+         IF( NTYPES.LE.0 ) THEN
+            WRITE( NOUT, FMT = 9990 )C3
+         ELSE
+            IF( TSTERR )
+     $         CALL ZERRGG( C3, NOUT )
+            CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+            CALL ZDRGEV( NN, NVAL, MAXTYP, DOTYPE, ISEED, THRESH, NOUT,
+     $                   A( 1, 1 ), NMAX, A( 1, 2 ), A( 1, 3 ),
+     $                   A( 1, 4 ), A( 1, 7 ), NMAX, A( 1, 8 ),
+     $                   A( 1, 9 ), NMAX, DC( 1, 1 ), DC( 1, 2 ),
+     $                   DC( 1, 3 ), DC( 1, 4 ), WORK, LWORK, RWORK,
+     $                   RESULT, INFO )
+            IF( INFO.NE.0 )
+     $         WRITE( NOUT, FMT = 9980 )'ZDRGEV', INFO
+         END IF
+         WRITE( NOUT, FMT = 9973 )
+         GO TO 10
+*
+      ELSE IF( ZXV ) THEN
+*
+*        -------------------------------------------------
+*        ZXV:  Generalized Nonsymmetric Eigenvalue Problem
+*              ZGGEVX (eigenvalue/vector with condition numbers)
+*        -------------------------------------------------
+*
+         MAXTYP = 2
+         NTYPES = MAXTYP
+         IF( NN.LT.0 ) THEN
+            WRITE( NOUT, FMT = 9990 )C3
+         ELSE
+            IF( TSTERR )
+     $         CALL ZERRGG( C3, NOUT )
+            CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
+            CALL ZDRGVX( NN, THRESH, NIN, NOUT, A( 1, 1 ), NMAX,
+     $                   A( 1, 2 ), A( 1, 3 ), A( 1, 4 ), DC( 1, 1 ),
+     $                   DC( 1, 2 ), A( 1, 5 ), A( 1, 6 ), IWORK( 1 ),
+     $                   IWORK( 2 ), DR( 1, 1 ), DR( 1, 2 ), DR( 1, 3 ),
+     $                   DR( 1, 4 ), DR( 1, 5 ), DR( 1, 6 ), WORK,
+     $                   LWORK, RWORK, IWORK( 3 ), LIWORK-2, RESULT,
+     $                   LOGWRK, INFO )
+*
+            IF( INFO.NE.0 )
+     $         WRITE( NOUT, FMT = 9980 )'ZDRGVX', INFO
+         END IF
+         WRITE( NOUT, FMT = 9973 )
+         GO TO 10
 *
       ELSE IF( LSAMEN( 3, C3, 'ZHB' ) ) THEN
 *
@@ -1706,13 +2027,13 @@
          MAXTYP = 15
          NTYPES = MIN( MAXTYP, NTYPES )
          CALL ALAREQ( C3, NTYPES, DOTYPE, MAXTYP, NIN, NOUT )
-         DO 360 I = 1, NPARMS
+         DO 370 I = 1, NPARMS
             NRHS = NSVAL( I )
 *
             IF( NEWSD.EQ.0 ) THEN
-               DO 350 K = 1, 4
+               DO 360 K = 1, 4
                   ISEED( K ) = IOLDSD( K )
-  350          CONTINUE
+  360          CONTINUE
             END IF
             WRITE( NOUT, FMT = 9966 )C3, NRHS
             CALL ZCHKBB( NN, MVAL, NVAL, NK, KVAL, MAXTYP, DOTYPE, NRHS,
@@ -1723,7 +2044,7 @@
      $                   INFO )
             IF( INFO.NE.0 )
      $         WRITE( NOUT, FMT = 9980 )'ZCHKBB', INFO
-  360    CONTINUE
+  370    CONTINUE
 *
       ELSE IF( LSAMEN( 3, C3, 'GLM' ) ) THEN
 *
@@ -1789,8 +2110,9 @@
          WRITE( NOUT, FMT = * )
          WRITE( NOUT, FMT = 9992 )C3
       END IF
-      GO TO 190
-  370 CONTINUE
+      IF( .NOT.( ZGX .OR. ZXV ) )
+     $   GO TO 190
+  380 CONTINUE
       WRITE( NOUT, FMT = 9994 )
       S2 = DSECND( )
       WRITE( NOUT, FMT = 9993 )S2 - S1
@@ -1837,7 +2159,7 @@
  9974 FORMAT( ' Tests of ZHBTRD', / ' (reduction of a Hermitian band ',
      $      'matrix to real tridiagonal form)' )
  9973 FORMAT( / 1X, 71( '-' ) )
- 9972 FORMAT( / ' LAPACK VERSION 2.0, released September 30, 1994 ' )
+ 9972 FORMAT( / ' LAPACK VERSION 3.0, released June 30, 1999 ' )
  9971 FORMAT( / ' Tests of the Generalized Linear Regression Model ',
      $      'routines' )
  9970 FORMAT( / ' Tests of the Generalized QR and RQ routines' )
@@ -1847,6 +2169,14 @@
  9967 FORMAT( ' Tests of ZGBBRD', / ' (reduction of a general band ',
      $      'matrix to real bidiagonal form)' )
  9966 FORMAT( / / 1X, A3, ':  NRHS =', I4 )
+ 9965 FORMAT( / ' Tests of the Generalized Nonsymmetric Eigenvalue ',
+     $      'Problem Expert Driver ZGGESX' )
+ 9964 FORMAT( / ' Tests of the Generalized Nonsymmetric Eigenvalue ',
+     $      'Problem Driver ZGGES' )
+ 9963 FORMAT( / ' Tests of the Generalized Nonsymmetric Eigenvalue ',
+     $      'Problem Driver ZGGEV' )
+ 9962 FORMAT( / ' Tests of the Generalized Nonsymmetric Eigenvalue ',
+     $      'Problem Expert Driver ZGGEVX' )
 *
 *     End of ZCHKEE
 *
