@@ -1,11 +1,12 @@
       SUBROUTINE ZDRVBD( NSIZES, MM, NN, NTYPES, DOTYPE, ISEED, THRESH,
      $                   A, LDA, U, LDU, VT, LDVT, ASAV, USAV, VTSAV, S,
-     $                   SSAV, E, WORK, LWORK, RWORK, NOUNIT, INFO )
+     $                   SSAV, E, WORK, LWORK, RWORK, IWORK, NOUNIT,
+     $                   INFO )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDU, LDVT, LWORK, NOUNIT, NSIZES,
@@ -14,7 +15,7 @@
 *     ..
 *     .. Array Arguments ..
       LOGICAL            DOTYPE( * )
-      INTEGER            ISEED( 4 ), MM( * ), NN( * )
+      INTEGER            ISEED( 4 ), IWORK( * ), MM( * ), NN( * )
       DOUBLE PRECISION   E( * ), RWORK( * ), S( * ), SSAV( * )
       COMPLEX*16         A( LDA, * ), ASAV( LDA, * ), U( LDU, * ),
      $                   USAV( LDU, * ), VT( LDVT, * ),
@@ -24,12 +25,13 @@
 *  Purpose
 *  =======
 *
-*  ZDRVBD checks the singular value decomposition (SVD) driver ZGESVD.
-*  ZGESVD factors A = U diag(S) VT, where U and VT are unitary
-*  and diag(S) is diagonal with the entries of the array S on its
-*  diagonal. The entries of S are the singular values, nonnegative and
-*  stored in decreasing order.  U and VT can be optionally not computed,
-*  overwritten on A, or computed partially.
+*  ZDRVBD checks the singular value decomposition (SVD) driver ZGESVD
+*  and ZGESDD.
+*  ZGESVD and CGESDD factors A = U diag(S) VT, where U and VT are
+*  unitary and diag(S) is diagonal with the entries of the array S on
+*  its diagonal. The entries of S are the singular values, nonnegative
+*  and stored in decreasing order.  U and VT can be optionally not
+*  computed, overwritten on A, or computed partially.
 *
 *  A is M by N. Let MNMIN = min( M, N ). S has dimension MNMIN.
 *  U can be M by M or M by MNMIN. VT can be N by N or MNMIN by N.
@@ -39,7 +41,29 @@
 *  and each type of matrix, and for the minimal workspace as well as
 *  workspace adequate to permit blocking, an  M x N  matrix "A" will be
 *  generated and used to test the SVD routines.  For each matrix, A will
-*  be factored as A = U diag(S) VT and the following 6 tests computed:
+*  be factored as A = U diag(S) VT and the following 12 tests computed:
+*
+*  Test for ZGESVD:
+*
+*  (1)   | A - U diag(S) VT | / ( |A| max(M,N) ulp )
+*
+*  (2)   | I - U'U | / ( M ulp )
+*
+*  (3)   | I - VT VT' | / ( N ulp )
+*
+*  (4)   S contains MNMIN nonnegative values in decreasing order.
+*        (Return 0 if true, 1/ULP if false.)
+*
+*  (5)   | U - Upartial | / ( M ulp ) where Upartial is a partially
+*        computed U.
+*
+*  (6)   | VT - VTpartial | / ( N ulp ) where VTpartial is a partially
+*        computed VT.
+*
+*  (7)   | S - Spartial | / ( MNMIN ulp |S| ) where Spartial is the
+*        vector of singular values from the partial SVD
+*
+*  Test for ZGESDD:
 *
 *  (1)   | A - U diag(S) VT | / ( |A| max(M,N) ulp )
 *
@@ -189,6 +213,8 @@
 *  RWORK   (workspace) DOUBLE PRECISION array,
 *                      dimension ( 5*max(max(MM,NN)) )
 *
+*  IWORK   (workspace) INTEGER array, dimension at least 8*min(M,N)
+*
 *  RESULT  (output) DOUBLE PRECISION array, dimension (7)
 *          The values computed by the 7 tests described above.
 *          The values are currently limited to 1/ULP, to avoid
@@ -221,25 +247,25 @@
 *     ..
 *     .. Local Scalars ..
       LOGICAL            BADMM, BADNN
-      CHARACTER          JOBU, JOBVT
-      INTEGER            I, IINFO, IJU, IJVT, IWSPC, IWTMP, J, JSIZE,
-     $                   JTYPE, LSWORK, M, MINWRK, MMAX, MNMAX, MNMIN,
-     $                   MTYPES, N, NERRS, NFAIL, NMAX, NTEST, NTESTF,
-     $                   NTESTT
+      CHARACTER          JOBQ, JOBU, JOBVT
+      INTEGER            I, IINFO, IJQ, IJU, IJVT, IWSPC, IWTMP, J,
+     $                   JSIZE, JTYPE, LSWORK, M, MINWRK, MMAX, MNMAX,
+     $                   MNMIN, MTYPES, N, NERRS, NFAIL, NMAX, NTEST,
+     $                   NTESTF, NTESTT
       DOUBLE PRECISION   ANORM, DIF, DIV, OVFL, ULP, ULPINV, UNFL
 *     ..
 *     .. Local Arrays ..
       CHARACTER          CJOB( 4 )
       INTEGER            IOLDSD( 4 )
-      DOUBLE PRECISION   RESULT( 7 )
+      DOUBLE PRECISION   RESULT( 14 )
 *     ..
 *     .. External Functions ..
       DOUBLE PRECISION   DLAMCH
       EXTERNAL           DLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ALASVM, XERBLA, ZBDT01, ZGESVD, ZLACPY, ZLASET,
-     $                   ZLATMS, ZUNT01, ZUNT03
+      EXTERNAL           ALASVM, XERBLA, ZBDT01, ZGESDD, ZGESVD, ZLACPY,
+     $                   ZLASET, ZLATMS, ZUNT01, ZUNT03
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, DBLE, MAX, MIN
@@ -318,7 +344,7 @@
 *
       NERRS = 0
 *
-      DO 150 JSIZE = 1, NSIZES
+      DO 180 JSIZE = 1, NSIZES
          M = MM( JSIZE )
          N = NN( JSIZE )
          MNMIN = MIN( M, N )
@@ -329,9 +355,9 @@
             MTYPES = MIN( MAXTYP+1, NTYPES )
          END IF
 *
-         DO 140 JTYPE = 1, MTYPES
+         DO 170 JTYPE = 1, MTYPES
             IF( .NOT.DOTYPE( JTYPE ) )
-     $         GO TO 140
+     $         GO TO 170
             NTEST = 0
 *
             DO 20 J = 1, 4
@@ -386,15 +412,18 @@
 *
 *           Do for minimal and adequate (for blocking) workspace
 *
-            IWTMP = MAX( 3*MIN( M, N )+MAX( M, N ), 5*MIN( M, N )-4 )
-            DO 130 IWSPC = 1, 4
+            DO 160 IWSPC = 1, 4
+*
+*              Test for ZGESVD
+*
+               IWTMP = MAX( 3*MIN( M, N )+MAX( M, N ), 5*MIN( M, N )-4 )
                LSWORK = IWTMP + ( IWSPC-1 )*( LWORK-IWTMP ) / 3
                LSWORK = MIN( LSWORK, LWORK )
                LSWORK = MAX( LSWORK, 1 )
                IF( IWSPC.EQ.4 )
      $            LSWORK = LWORK
 *
-               DO 60 J = 1, 7
+               DO 60 J = 1, 14
                   RESULT( J ) = -ONE
    60          CONTINUE
 *
@@ -415,10 +444,12 @@
 *
                CALL ZBDT01( M, N, 0, ASAV, LDA, USAV, LDU, SSAV, E,
      $                      VTSAV, LDVT, WORK, RWORK, RESULT( 1 ) )
-               CALL ZUNT01( 'Columns', MNMIN, M, USAV, LDU, WORK, LWORK,
-     $                      RWORK, RESULT( 2 ) )
-               CALL ZUNT01( 'Rows', MNMIN, N, VTSAV, LDVT, WORK, LWORK,
-     $                      RWORK, RESULT( 3 ) )
+               IF( M.NE.0 .AND. N.NE.0 ) THEN
+                  CALL ZUNT01( 'Columns', MNMIN, M, USAV, LDU, WORK,
+     $                         LWORK, RWORK, RESULT( 2 ) )
+                  CALL ZUNT01( 'Rows', MNMIN, N, VTSAV, LDVT, WORK,
+     $                         LWORK, RWORK, RESULT( 3 ) )
+               END IF
                RESULT( 4 ) = 0
                DO 70 I = 1, MNMIN - 1
                   IF( SSAV( I ).LT.SSAV( I+1 ) )
@@ -502,16 +533,129 @@
    90             CONTINUE
   100          CONTINUE
 *
+*              Test for ZGESDD
+*
+               IWTMP = 2*MNMIN*MNMIN + 2*MNMIN + MAX( M, N )
+               LSWORK = IWTMP + ( IWSPC-1 )*( LWORK-IWTMP ) / 3
+               LSWORK = MIN( LSWORK, LWORK )
+               LSWORK = MAX( LSWORK, 1 )
+               IF( IWSPC.EQ.4 )
+     $            LSWORK = LWORK
+*
+*              Factorize A
+*
+               CALL ZLACPY( 'F', M, N, ASAV, LDA, A, LDA )
+               CALL ZGESDD( 'A', M, N, A, LDA, SSAV, USAV, LDU, VTSAV,
+     $                      LDVT, WORK, LSWORK, RWORK, IWORK, IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9995 )'GESDD', IINFO, M, N,
+     $               JTYPE, LSWORK, IOLDSD
+                  INFO = ABS( IINFO )
+                  RETURN
+               END IF
+*
+*              Do tests 1--4
+*
+               CALL ZBDT01( M, N, 0, ASAV, LDA, USAV, LDU, SSAV, E,
+     $                      VTSAV, LDVT, WORK, RWORK, RESULT( 8 ) )
+               IF( M.NE.0 .AND. N.NE.0 ) THEN
+                  CALL ZUNT01( 'Columns', MNMIN, M, USAV, LDU, WORK,
+     $                         LWORK, RWORK, RESULT( 9 ) )
+                  CALL ZUNT01( 'Rows', MNMIN, N, VTSAV, LDVT, WORK,
+     $                         LWORK, RWORK, RESULT( 10 ) )
+               END IF
+               RESULT( 11 ) = 0
+               DO 110 I = 1, MNMIN - 1
+                  IF( SSAV( I ).LT.SSAV( I+1 ) )
+     $               RESULT( 11 ) = ULPINV
+                  IF( SSAV( I ).LT.ZERO )
+     $               RESULT( 11 ) = ULPINV
+  110          CONTINUE
+               IF( MNMIN.GE.1 ) THEN
+                  IF( SSAV( MNMIN ).LT.ZERO )
+     $               RESULT( 11 ) = ULPINV
+               END IF
+*
+*              Do partial SVDs, comparing to SSAV, USAV, and VTSAV
+*
+               RESULT( 12 ) = ZERO
+               RESULT( 13 ) = ZERO
+               RESULT( 14 ) = ZERO
+               DO 130 IJQ = 0, 2
+                  JOBQ = CJOB( IJQ+1 )
+                  CALL ZLACPY( 'F', M, N, ASAV, LDA, A, LDA )
+                  CALL ZGESDD( JOBQ, M, N, A, LDA, S, U, LDU, VT, LDVT,
+     $                         WORK, LSWORK, RWORK, IWORK, IINFO )
+*
+*                 Compare U
+*
+                  DIF = ZERO
+                  IF( M.GT.0 .AND. N.GT.0 ) THEN
+                     IF( IJQ.EQ.1 ) THEN
+                        IF( M.GE.N ) THEN
+                           CALL ZUNT03( 'C', M, MNMIN, M, MNMIN, USAV,
+     $                                  LDU, A, LDA, WORK, LWORK, RWORK,
+     $                                  DIF, IINFO )
+                        ELSE
+                           CALL ZUNT03( 'C', M, MNMIN, M, MNMIN, USAV,
+     $                                  LDU, U, LDU, WORK, LWORK, RWORK,
+     $                                  DIF, IINFO )
+                        END IF
+                     ELSE IF( IJQ.EQ.2 ) THEN
+                        CALL ZUNT03( 'C', M, MNMIN, M, MNMIN, USAV, LDU,
+     $                               U, LDU, WORK, LWORK, RWORK, DIF,
+     $                               IINFO )
+                     END IF
+                  END IF
+                  RESULT( 12 ) = MAX( RESULT( 12 ), DIF )
+*
+*                 Compare VT
+*
+                  DIF = ZERO
+                  IF( M.GT.0 .AND. N.GT.0 ) THEN
+                     IF( IJQ.EQ.1 ) THEN
+                        IF( M.GE.N ) THEN
+                           CALL ZUNT03( 'R', N, MNMIN, N, MNMIN, VTSAV,
+     $                                  LDVT, VT, LDVT, WORK, LWORK,
+     $                                  RWORK, DIF, IINFO )
+                        ELSE
+                           CALL ZUNT03( 'R', N, MNMIN, N, MNMIN, VTSAV,
+     $                                  LDVT, A, LDA, WORK, LWORK,
+     $                                  RWORK, DIF, IINFO )
+                        END IF
+                     ELSE IF( IJQ.EQ.2 ) THEN
+                        CALL ZUNT03( 'R', N, MNMIN, N, MNMIN, VTSAV,
+     $                               LDVT, VT, LDVT, WORK, LWORK, RWORK,
+     $                               DIF, IINFO )
+                     END IF
+                  END IF
+                  RESULT( 13 ) = MAX( RESULT( 13 ), DIF )
+*
+*                 Compare S
+*
+                  DIF = ZERO
+                  DIV = MAX( DBLE( MNMIN )*ULP*S( 1 ),
+     $                  DLAMCH( 'Safe minimum' ) )
+                  DO 120 I = 1, MNMIN - 1
+                     IF( SSAV( I ).LT.SSAV( I+1 ) )
+     $                  DIF = ULPINV
+                     IF( SSAV( I ).LT.ZERO )
+     $                  DIF = ULPINV
+                     DIF = MAX( DIF, ABS( SSAV( I )-S( I ) ) / DIV )
+  120             CONTINUE
+                  RESULT( 14 ) = MAX( RESULT( 14 ), DIF )
+  130          CONTINUE
+*
 *              End of Loop -- Check for RESULT(j) > THRESH
 *
                NTEST = 0
                NFAIL = 0
-               DO 110 J = 1, 7
+               DO 140 J = 1, 14
                   IF( RESULT( J ).GE.ZERO )
      $               NTEST = NTEST + 1
                   IF( RESULT( J ).GE.THRESH )
      $               NFAIL = NFAIL + 1
-  110          CONTINUE
+  140          CONTINUE
 *
                IF( NFAIL.GT.0 )
      $            NTESTF = NTESTF + 1
@@ -521,20 +665,20 @@
                   NTESTF = 2
                END IF
 *
-               DO 120 J = 1, 7
+               DO 150 J = 1, 14
                   IF( RESULT( J ).GE.THRESH ) THEN
                      WRITE( NOUNIT, FMT = 9997 )M, N, JTYPE, IWSPC,
      $                  IOLDSD, J, RESULT( J )
                   END IF
-  120          CONTINUE
+  150          CONTINUE
 *
                NERRS = NERRS + NFAIL
                NTESTT = NTESTT + NTEST
 *
-  130       CONTINUE
+  160       CONTINUE
 *
-  140    CONTINUE
-  150 CONTINUE
+  170    CONTINUE
+  180 CONTINUE
 *
 *     Summary
 *
@@ -550,14 +694,24 @@
      $      / 19X, ' S is an array, and Upartial, VTpartial, and',
      $      / 19X, ' Spartial are partially computed U, VT and S),', / )
  9998 FORMAT( ' Tests performed with Test Threshold = ', F8.2,
-     $      / / ' 1 = | A - U diag(S) VT | / ( |A| max(M,N) ulp ) ',
+     $      / ' ZGESVD: ', /
+     $      ' 1 = | A - U diag(S) VT | / ( |A| max(M,N) ulp ) ',
      $      / ' 2 = | I - U**T U | / ( M ulp ) ',
      $      / ' 3 = | I - VT VT**T | / ( N ulp ) ',
      $      / ' 4 = 0 if S contains min(M,N) nonnegative values in',
      $      ' decreasing order, else 1/ulp',
      $      / ' 5 = | U - Upartial | / ( M ulp )',
      $      / ' 6 = | VT - VTpartial | / ( N ulp )',
-     $      / ' 7 = | S - Spartial | / ( min(M,N) ulp |S| )', / / )
+     $      / ' 7 = | S - Spartial | / ( min(M,N) ulp |S| )',
+     $      / ' ZGESDD: ', /
+     $      ' 8 = | A - U diag(S) VT | / ( |A| max(M,N) ulp ) ',
+     $      / ' 9 = | I - U**T U | / ( M ulp ) ',
+     $      / '10 = | I - VT VT**T | / ( N ulp ) ',
+     $      / '11 = 0 if S contains min(M,N) nonnegative values in',
+     $      ' decreasing order, else 1/ulp',
+     $      / '12 = | U - Upartial | / ( M ulp )',
+     $      / '13 = | VT - VTpartial | / ( N ulp )',
+     $      / '14 = | S - Spartial | / ( min(M,N) ulp |S| )', / / )
  9997 FORMAT( ' M=', I5, ', N=', I5, ', type ', I1, ', IWS=', I1,
      $      ', seed=', 4( I4, ',' ), ' test(', I1, ')=', G11.4 )
  9996 FORMAT( ' ZDRVBD: ', A, ' returned INFO=', I6, '.', / 9X, 'M=',
