@@ -1,15 +1,16 @@
       SUBROUTINE ZDRVST( NSIZES, NN, NTYPES, DOTYPE, ISEED, THRESH,
      $                   NOUNIT, A, LDA, D1, D2, D3, WA1, WA2, WA3, U,
-     $                   LDU, V, TAU, Z, WORK, NWORK, RWORK, IWORK,
-     $                   RESULT, INFO )
+     $                   LDU, V, TAU, Z, WORK, LWORK, RWORK, LRWORK,
+     $                   IWORK, LIWORK, RESULT, INFO )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
-      INTEGER            INFO, LDA, LDU, NOUNIT, NSIZES, NTYPES, NWORK
+      INTEGER            INFO, LDA, LDU, LIWORK, LRWORK, LWORK, NOUNIT,
+     $                   NSIZES, NTYPES
       DOUBLE PRECISION   THRESH
 *     ..
 *     .. Array Arguments ..
@@ -27,25 +28,41 @@
 *       ZDRVST  checks the Hermitian eigenvalue problem drivers.
 *
 *               ZHEEVD computes all eigenvalues and, optionally,
-*               eigenvectors of a complex Hermitian matrix.
+*               eigenvectors of a complex Hermitian matrix,
+*               using a divide-and-conquer algorithm.
 *
 *               ZHEEVX computes selected eigenvalues and, optionally,
 *               eigenvectors of a complex Hermitian matrix.
 *
+*               ZHEEVR computes selected eigenvalues and, optionally,
+*               eigenvectors of a complex Hermitian matrix
+*               using the Relatively Robust Representation where it can.
+*
 *               ZHPEVD computes all eigenvalues and, optionally,
 *               eigenvectors of a complex Hermitian matrix in packed
-*               storage.
+*               storage, using a divide-and-conquer algorithm.
 *
 *               ZHPEVX computes selected eigenvalues and, optionally,
 *               eigenvectors of a complex Hermitian matrix in packed
 *               storage.
 *
 *               ZHBEVD computes all eigenvalues and, optionally,
-*               eigenvectors of a complex Hermitian band matrix.
+*               eigenvectors of a complex Hermitian band matrix,
+*               using a divide-and-conquer algorithm.
 *
 *               ZHBEVX computes selected eigenvalues and, optionally,
 *               eigenvectors of a complex Hermitian band matrix.
 *
+*               ZHEEV computes all eigenvalues and, optionally,
+*               eigenvectors of a complex Hermitian matrix.
+*
+*               ZHPEV computes all eigenvalues and, optionally,
+*               eigenvectors of a complex Hermitian matrix in packed
+*               storage.
+*
+*               ZHBEV computes all eigenvalues and, optionally,
+*               eigenvectors of a complex Hermitian band matrix.
+*
 *       When ZDRVST is called, a number of matrix "sizes" ("n's") and a
 *       number of matrix "types" are specified.  For each size ("n")
 *       and each type of matrix, one matrix will be generated and used
@@ -165,7 +182,7 @@
 *          (e.g., if a routine returns IINFO not equal to 0.)
 *          Not modified.
 *
-*  A       DOUBLE PRECISION array, dimension (LDA , max(NN))
+*  A       COMPLEX*16 array, dimension (LDA , max(NN))
 *          Used to hold the matrix whose eigenvalues are to be
 *          computed.  On exit, A contains the last matrix actually
 *          used.
@@ -223,11 +240,11 @@
 *          ZHEEVX, ZHPEVD, CHPEVX, ZHBEVD, and CHBEVX.
 *          Modified.
 *
-*  WORK  - COMPLEX*16 array of dimension ( NWORK )
+*  WORK  - COMPLEX*16 array of dimension ( LWORK )
 *           Workspace.
 *           Modified.
 *
-*  NWORK - INTEGER
+*  LWORK - INTEGER
 *           The number of entries in WORK.  This must be at least
 *           2*max( NN(j), 2 )**2.
 *           Not modified.
@@ -236,11 +253,17 @@
 *           Workspace.
 *           Modified.
 *
+*  LRWORK - INTEGER
+*           The number of entries in RWORK.
+*
 *  IWORK   INTEGER array, dimension (6*max(NN))
 *          Workspace.
 *          Modified.
 *
-*  RESULT  DOUBLE PRECISION array, dimension (42)
+*  LIWORK - INTEGER
+*           The number of entries in IWORK.
+*
+*  RESULT  DOUBLE PRECISION array, dimension (??)
 *          The values computed by the tests described above.
 *          The values are currently limited to 1/ulp, to avoid
 *          overflow.
@@ -254,7 +277,7 @@
 *           -5: THRESH < 0
 *           -9: LDA < 1 or LDA < NMAX, where NMAX is max( NN(j) ).
 *          -16: LDU < 1 or LDU < NMAX.
-*          -21: NWORK too small.
+*          -21: LWORK too small.
 *          If  DLATMR, SLATMS, ZHETRD, DORGC3, ZSTEQR, DSTERF,
 *              or DORMC2 returns an error code, the
 *              absolute value of it is returned.
@@ -323,9 +346,10 @@
       EXTERNAL           DLAMCH, DLARND, DSXT1
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ALASVM, DLABAD, DLAFTS, XERBLA, ZHBEVD, ZHBEVX,
-     $                   ZHEEVD, ZHEEVX, ZHET21, ZHET22, ZHPEVD, ZHPEVX,
-     $                   ZLACPY, ZLASET, ZLATMR, ZLATMS
+      EXTERNAL           ALASVM, DLABAD, DLAFTS, XERBLA, ZHBEV, ZHBEVD,
+     $                   ZHBEVX, ZHEEV, ZHEEVD, ZHEEVR, ZHEEVX, ZHET21,
+     $                   ZHET22, ZHPEV, ZHPEVD, ZHPEVX, ZLACPY, ZLASET,
+     $                   ZLATMR, ZLATMS
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, DBLE, INT, LOG, MAX, MIN, SQRT
@@ -364,7 +388,7 @@
          INFO = -9
       ELSE IF( LDU.LT.NMAX ) THEN
          INFO = -16
-      ELSE IF( 2*MAX( 2, NMAX )**2.GT.NWORK ) THEN
+      ELSE IF( 2*MAX( 2, NMAX )**2.GT.LWORK ) THEN
          INFO = -22
       END IF
 *
@@ -398,7 +422,7 @@
       NERRS = 0
       NMATS = 0
 *
-      DO 960 JSIZE = 1, NSIZES
+      DO 1220 JSIZE = 1, NSIZES
          N = NN( JSIZE )
          IF( N.GT.0 ) THEN
             LGN = INT( LOG( DBLE( N ) ) / LOG( TWO ) )
@@ -408,11 +432,11 @@
      $         LGN = LGN + 1
             LWEDC = MAX( 2*N+N*N, 2*N*N )
             LRWEDC = 1 + 4*N + 2*N*LGN + 3*N**2
-            LIWEDC = 2 + 5*N
+            LIWEDC = 3 + 5*N
          ELSE
             LWEDC = 2
             LRWEDC = 8
-            LIWEDC = 7
+            LIWEDC = 8
          END IF
          ANINV = ONE / DBLE( MAX( 1, N ) )
 *
@@ -422,9 +446,9 @@
             MTYPES = MIN( MAXTYP+1, NTYPES )
          END IF
 *
-         DO 950 JTYPE = 1, MTYPES
+         DO 1210 JTYPE = 1, MTYPES
             IF( .NOT.DOTYPE( JTYPE ) )
-     $         GO TO 950
+     $         GO TO 1210
             NMATS = NMATS + 1
             NTEST = 0
 *
@@ -526,7 +550,7 @@
 *
 *              Hermitian banded, eigenvalues specified
 *
-               IHBW = ( N-1 )*DLARND( 1, ISEED3 )
+               IHBW = INT( ( N-1 )*DLARND( 1, ISEED3 ) )
                CALL ZLATMS( N, N, 'S', ISEED, 'H', RWORK, IMODE, COND,
      $                      ANORM, IHBW, IHBW, 'Z', U, LDU, WORK,
      $                      IINFO )
@@ -561,8 +585,8 @@
                IL = 1
                IU = N
             ELSE
-               IL = 1 + ( N-1 )*DLARND( 1, ISEED2 )
-               IU = 1 + ( N-1 )*DLARND( 1, ISEED2 )
+               IL = 1 + INT( ( N-1 )*DLARND( 1, ISEED2 ) )
+               IU = 1 + INT( ( N-1 )*DLARND( 1, ISEED2 ) )
                IF( IL.GT.IU ) THEN
                   ITEMP = IL
                   IL = IU
@@ -573,7 +597,7 @@
 *           Perform tests storing upper or lower triangular
 *           part of matrix.
 *
-            DO 940 IUPLO = 0, 1
+            DO 1200 IUPLO = 0, 1
                IF( IUPLO.EQ.0 ) THEN
                   UPLO = 'L'
                ELSE
@@ -662,7 +686,7 @@
                END IF
 *
                CALL ZHEEVX( 'V', 'A', UPLO, N, A, LDU, VL, VU, IL, IU,
-     $                      ABSTOL, M, WA1, Z, LDU, WORK, NWORK, RWORK,
+     $                      ABSTOL, M, WA1, Z, LDU, WORK, LWORK, RWORK,
      $                      IWORK, IWORK( 5*N+1 ), IINFO )
                IF( IINFO.NE.0 ) THEN
                   WRITE( NOUNIT, FMT = 9999 )'ZHEEVX(V,A,' // UPLO //
@@ -687,7 +711,7 @@
 *
                NTEST = NTEST + 2
                CALL ZHEEVX( 'N', 'A', UPLO, N, A, LDU, VL, VU, IL, IU,
-     $                      ABSTOL, M2, WA2, Z, LDU, WORK, NWORK, RWORK,
+     $                      ABSTOL, M2, WA2, Z, LDU, WORK, LWORK, RWORK,
      $                      IWORK, IWORK( 5*N+1 ), IINFO )
                IF( IINFO.NE.0 ) THEN
                   WRITE( NOUNIT, FMT = 9999 )'ZHEEVX(N,A,' // UPLO //
@@ -718,7 +742,7 @@
                NTEST = NTEST + 1
 *
                CALL ZHEEVX( 'V', 'I', UPLO, N, A, LDU, VL, VU, IL, IU,
-     $                      ABSTOL, M2, WA2, Z, LDU, WORK, NWORK, RWORK,
+     $                      ABSTOL, M2, WA2, Z, LDU, WORK, LWORK, RWORK,
      $                      IWORK, IWORK( 5*N+1 ), IINFO )
                IF( IINFO.NE.0 ) THEN
                   WRITE( NOUNIT, FMT = 9999 )'ZHEEVX(V,I,' // UPLO //
@@ -742,7 +766,7 @@
                NTEST = NTEST + 2
 *
                CALL ZHEEVX( 'N', 'I', UPLO, N, A, LDU, VL, VU, IL, IU,
-     $                      ABSTOL, M3, WA3, Z, LDU, WORK, NWORK, RWORK,
+     $                      ABSTOL, M3, WA3, Z, LDU, WORK, LWORK, RWORK,
      $                      IWORK, IWORK( 5*N+1 ), IINFO )
                IF( IINFO.NE.0 ) THEN
                   WRITE( NOUNIT, FMT = 9999 )'ZHEEVX(N,I,' // UPLO //
@@ -774,7 +798,7 @@
                NTEST = NTEST + 1
 *
                CALL ZHEEVX( 'V', 'V', UPLO, N, A, LDU, VL, VU, IL, IU,
-     $                      ABSTOL, M2, WA2, Z, LDU, WORK, NWORK, RWORK,
+     $                      ABSTOL, M2, WA2, Z, LDU, WORK, LWORK, RWORK,
      $                      IWORK, IWORK( 5*N+1 ), IINFO )
                IF( IINFO.NE.0 ) THEN
                   WRITE( NOUNIT, FMT = 9999 )'ZHEEVX(V,V,' // UPLO //
@@ -798,7 +822,7 @@
                NTEST = NTEST + 2
 *
                CALL ZHEEVX( 'N', 'V', UPLO, N, A, LDU, VL, VU, IL, IU,
-     $                      ABSTOL, M3, WA3, Z, LDU, WORK, NWORK, RWORK,
+     $                      ABSTOL, M3, WA3, Z, LDU, WORK, LWORK, RWORK,
      $                      IWORK, IWORK( 5*N+1 ), IINFO )
                IF( IINFO.NE.0 ) THEN
                   WRITE( NOUNIT, FMT = 9999 )'ZHEEVX(N,V,' // UPLO //
@@ -1569,7 +1593,431 @@
 *
   930          CONTINUE
 *
-  940       CONTINUE
+*              Call ZHEEV
+*
+               CALL ZLACPY( ' ', N, N, A, LDA, V, LDU )
+*
+               NTEST = NTEST + 1
+               CALL ZHEEV( 'V', UPLO, N, A, LDU, D1, WORK, LWORK, RWORK,
+     $                     IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'ZHEEV(V,' // UPLO // ')',
+     $               IINFO, N, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     RESULT( NTEST+1 ) = ULPINV
+                     RESULT( NTEST+2 ) = ULPINV
+                     GO TO 950
+                  END IF
+               END IF
+*
+*              Do tests 37 and 38
+*
+               CALL ZHET21( 1, UPLO, N, 0, V, LDU, D1, D2, A, LDU, Z,
+     $                      LDU, TAU, WORK, RWORK, RESULT( NTEST ) )
+*
+               CALL ZLACPY( ' ', N, N, V, LDU, A, LDA )
+*
+               NTEST = NTEST + 2
+               CALL ZHEEV( 'N', UPLO, N, A, LDU, D3, WORK, LWORK, RWORK,
+     $                     IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'ZHEEV(N,' // UPLO // ')',
+     $               IINFO, N, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     GO TO 950
+                  END IF
+               END IF
+*
+*              Do test 39
+*
+               TEMP1 = ZERO
+               TEMP2 = ZERO
+               DO 940 J = 1, N
+                  TEMP1 = MAX( TEMP1, ABS( D1( J ) ), ABS( D3( J ) ) )
+                  TEMP2 = MAX( TEMP2, ABS( D1( J )-D3( J ) ) )
+  940          CONTINUE
+               RESULT( NTEST ) = TEMP2 / MAX( UNFL,
+     $                           ULP*MAX( TEMP1, TEMP2 ) )
+*
+  950          CONTINUE
+*
+               CALL ZLACPY( ' ', N, N, V, LDU, A, LDA )
+*
+*              Call ZHPEV
+*
+*              Load array WORK with the upper or lower triangular
+*              part of the matrix in packed form.
+*
+               IF( IUPLO.EQ.1 ) THEN
+                  INDX = 1
+                  DO 970 J = 1, N
+                     DO 960 I = 1, J
+                        WORK( INDX ) = A( I, J )
+                        INDX = INDX + 1
+  960                CONTINUE
+  970             CONTINUE
+               ELSE
+                  INDX = 1
+                  DO 990 J = 1, N
+                     DO 980 I = J, N
+                        WORK( INDX ) = A( I, J )
+                        INDX = INDX + 1
+  980                CONTINUE
+  990             CONTINUE
+               END IF
+*
+               NTEST = NTEST + 1
+               INDWRK = N*( N+1 ) / 2 + 1
+               CALL ZHPEV( 'V', UPLO, N, WORK, D1, Z, LDU,
+     $                     WORK( INDWRK ), RWORK, IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'ZHPEV(V,' // UPLO // ')',
+     $               IINFO, N, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     RESULT( NTEST+1 ) = ULPINV
+                     RESULT( NTEST+2 ) = ULPINV
+                     GO TO 1050
+                  END IF
+               END IF
+*
+*              Do tests 40 and 41.
+*
+               CALL ZHET21( 1, UPLO, N, 0, A, LDA, D1, D2, Z, LDU, V,
+     $                      LDU, TAU, WORK, RWORK, RESULT( NTEST ) )
+*
+               IF( IUPLO.EQ.1 ) THEN
+                  INDX = 1
+                  DO 1010 J = 1, N
+                     DO 1000 I = 1, J
+                        WORK( INDX ) = A( I, J )
+                        INDX = INDX + 1
+ 1000                CONTINUE
+ 1010             CONTINUE
+               ELSE
+                  INDX = 1
+                  DO 1030 J = 1, N
+                     DO 1020 I = J, N
+                        WORK( INDX ) = A( I, J )
+                        INDX = INDX + 1
+ 1020                CONTINUE
+ 1030             CONTINUE
+               END IF
+*
+               NTEST = NTEST + 2
+               INDWRK = N*( N+1 ) / 2 + 1
+               CALL ZHPEV( 'N', UPLO, N, WORK, D3, Z, LDU,
+     $                     WORK( INDWRK ), RWORK, IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'ZHPEV(N,' // UPLO // ')',
+     $               IINFO, N, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     GO TO 1050
+                  END IF
+               END IF
+*
+*              Do test 42
+*
+               TEMP1 = ZERO
+               TEMP2 = ZERO
+               DO 1040 J = 1, N
+                  TEMP1 = MAX( TEMP1, ABS( D1( J ) ), ABS( D3( J ) ) )
+                  TEMP2 = MAX( TEMP2, ABS( D1( J )-D3( J ) ) )
+ 1040          CONTINUE
+               RESULT( NTEST ) = TEMP2 / MAX( UNFL,
+     $                           ULP*MAX( TEMP1, TEMP2 ) )
+*
+ 1050          CONTINUE
+*
+*              Call ZHBEV
+*
+               IF( JTYPE.LE.7 ) THEN
+                  KD = 0
+               ELSE IF( JTYPE.GE.8 .AND. JTYPE.LE.15 ) THEN
+                  KD = MAX( N-1, 0 )
+               ELSE
+                  KD = IHBW
+               END IF
+*
+*              Load array V with the upper or lower triangular part
+*              of the matrix in band form.
+*
+               IF( IUPLO.EQ.1 ) THEN
+                  DO 1070 J = 1, N
+                     DO 1060 I = MAX( 1, J-KD ), J
+                        V( KD+1+I-J, J ) = A( I, J )
+ 1060                CONTINUE
+ 1070             CONTINUE
+               ELSE
+                  DO 1090 J = 1, N
+                     DO 1080 I = J, MIN( N, J+KD )
+                        V( 1+I-J, J ) = A( I, J )
+ 1080                CONTINUE
+ 1090             CONTINUE
+               END IF
+*
+               NTEST = NTEST + 1
+               CALL ZHBEV( 'V', UPLO, N, KD, V, LDU, D1, Z, LDU, WORK,
+     $                     RWORK, IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9998 )'ZHBEV(V,' // UPLO // ')',
+     $               IINFO, N, KD, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     RESULT( NTEST+1 ) = ULPINV
+                     RESULT( NTEST+2 ) = ULPINV
+                     GO TO 1140
+                  END IF
+               END IF
+*
+*              Do tests 43 and 44.
+*
+               CALL ZHET21( 1, UPLO, N, 0, A, LDA, D1, D2, Z, LDU, V,
+     $                      LDU, TAU, WORK, RWORK, RESULT( NTEST ) )
+*
+               IF( IUPLO.EQ.1 ) THEN
+                  DO 1110 J = 1, N
+                     DO 1100 I = MAX( 1, J-KD ), J
+                        V( KD+1+I-J, J ) = A( I, J )
+ 1100                CONTINUE
+ 1110             CONTINUE
+               ELSE
+                  DO 1130 J = 1, N
+                     DO 1120 I = J, MIN( N, J+KD )
+                        V( 1+I-J, J ) = A( I, J )
+ 1120                CONTINUE
+ 1130             CONTINUE
+               END IF
+*
+               NTEST = NTEST + 2
+               CALL ZHBEV( 'N', UPLO, N, KD, V, LDU, D3, Z, LDU, WORK,
+     $                     RWORK, IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9998 )'ZHBEV(N,' // UPLO // ')',
+     $               IINFO, N, KD, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     GO TO 1140
+                  END IF
+               END IF
+*
+ 1140          CONTINUE
+*
+*              Do test 45.
+*
+               TEMP1 = ZERO
+               TEMP2 = ZERO
+               DO 1150 J = 1, N
+                  TEMP1 = MAX( TEMP1, ABS( D1( J ) ), ABS( D3( J ) ) )
+                  TEMP2 = MAX( TEMP2, ABS( D1( J )-D3( J ) ) )
+ 1150          CONTINUE
+               RESULT( NTEST ) = TEMP2 / MAX( UNFL,
+     $                           ULP*MAX( TEMP1, TEMP2 ) )
+*
+               CALL ZLACPY( ' ', N, N, A, LDA, V, LDU )
+               NTEST = NTEST + 1
+               CALL ZHEEVR( 'V', 'A', UPLO, N, A, LDU, VL, VU, IL, IU,
+     $                      ABSTOL, M, WA1, Z, LDU, IWORK, WORK, LWORK,
+     $                      RWORK, LRWORK, IWORK( 2*N+1 ), LIWORK-2*N,
+     $                      IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'ZHEEVR(V,A,' // UPLO //
+     $               ')', IINFO, N, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     RESULT( NTEST+1 ) = ULPINV
+                     RESULT( NTEST+2 ) = ULPINV
+                     GO TO 1170
+                  END IF
+               END IF
+*
+*              Do tests 45 and 46 (or ... )
+*
+               CALL ZLACPY( ' ', N, N, V, LDU, A, LDA )
+*
+               CALL ZHET21( 1, UPLO, N, 0, A, LDU, WA1, D2, Z, LDU, V,
+     $                      LDU, TAU, WORK, RWORK, RESULT( NTEST ) )
+*
+               NTEST = NTEST + 2
+               CALL ZHEEVR( 'N', 'A', UPLO, N, A, LDU, VL, VU, IL, IU,
+     $                      ABSTOL, M2, WA2, Z, LDU, IWORK, WORK, LWORK,
+     $                      RWORK, LRWORK, IWORK( 2*N+1 ), LIWORK-2*N,
+     $                      IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'ZHEEVR(N,A,' // UPLO //
+     $               ')', IINFO, N, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     GO TO 1170
+                  END IF
+               END IF
+*
+*              Do test 47 (or ... )
+*
+               TEMP1 = ZERO
+               TEMP2 = ZERO
+               DO 1160 J = 1, N
+                  TEMP1 = MAX( TEMP1, ABS( WA1( J ) ), ABS( WA2( J ) ) )
+                  TEMP2 = MAX( TEMP2, ABS( WA1( J )-WA2( J ) ) )
+ 1160          CONTINUE
+               RESULT( NTEST ) = TEMP2 / MAX( UNFL,
+     $                           ULP*MAX( TEMP1, TEMP2 ) )
+*
+ 1170          CONTINUE
+*
+               NTEST = NTEST + 1
+               CALL ZLACPY( ' ', N, N, V, LDU, A, LDA )
+               CALL ZHEEVR( 'V', 'I', UPLO, N, A, LDU, VL, VU, IL, IU,
+     $                      ABSTOL, M2, WA2, Z, LDU, IWORK, WORK, LWORK,
+     $                      RWORK, LRWORK, IWORK( 2*N+1 ), LIWORK-2*N,
+     $                      IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'ZHEEVR(V,I,' // UPLO //
+     $               ')', IINFO, N, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     RESULT( NTEST+1 ) = ULPINV
+                     RESULT( NTEST+2 ) = ULPINV
+                     GO TO 1180
+                  END IF
+               END IF
+*
+*              Do tests 48 and 49 (or +??)
+*
+               CALL ZLACPY( ' ', N, N, V, LDU, A, LDA )
+*
+               CALL ZHET22( 1, UPLO, N, M2, 0, A, LDU, WA2, D2, Z, LDU,
+     $                      V, LDU, TAU, WORK, RWORK, RESULT( NTEST ) )
+*
+               NTEST = NTEST + 2
+               CALL ZLACPY( ' ', N, N, V, LDU, A, LDA )
+               CALL ZHEEVR( 'N', 'I', UPLO, N, A, LDU, VL, VU, IL, IU,
+     $                      ABSTOL, M3, WA3, Z, LDU, IWORK, WORK, LWORK,
+     $                      RWORK, LRWORK, IWORK( 2*N+1 ), LIWORK-2*N,
+     $                      IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'ZHEEVR(N,I,' // UPLO //
+     $               ')', IINFO, N, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     GO TO 1180
+                  END IF
+               END IF
+*
+*              Do test 50 (or +??)
+*
+               TEMP1 = DSXT1( 1, WA2, M2, WA3, M3, ABSTOL, ULP, UNFL )
+               TEMP2 = DSXT1( 1, WA3, M3, WA2, M2, ABSTOL, ULP, UNFL )
+               RESULT( NTEST ) = ( TEMP1+TEMP2 ) /
+     $                           MAX( UNFL, ULP*TEMP3 )
+ 1180          CONTINUE
+*
+               NTEST = NTEST + 1
+               CALL ZLACPY( ' ', N, N, V, LDU, A, LDA )
+               CALL ZHEEVR( 'V', 'V', UPLO, N, A, LDU, VL, VU, IL, IU,
+     $                      ABSTOL, M2, WA2, Z, LDU, IWORK, WORK, LWORK,
+     $                      RWORK, LRWORK, IWORK( 2*N+1 ), LIWORK-2*N,
+     $                      IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'ZHEEVR(V,V,' // UPLO //
+     $               ')', IINFO, N, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     RESULT( NTEST+1 ) = ULPINV
+                     RESULT( NTEST+2 ) = ULPINV
+                     GO TO 1190
+                  END IF
+               END IF
+*
+*              Do tests 51 and 52 (or +??)
+*
+               CALL ZLACPY( ' ', N, N, V, LDU, A, LDA )
+*
+               CALL ZHET22( 1, UPLO, N, M2, 0, A, LDU, WA2, D2, Z, LDU,
+     $                      V, LDU, TAU, WORK, RWORK, RESULT( NTEST ) )
+*
+               NTEST = NTEST + 2
+               CALL ZLACPY( ' ', N, N, V, LDU, A, LDA )
+               CALL ZHEEVR( 'N', 'V', UPLO, N, A, LDU, VL, VU, IL, IU,
+     $                      ABSTOL, M3, WA3, Z, LDU, IWORK, WORK, LWORK,
+     $                      RWORK, LRWORK, IWORK( 2*N+1 ), LIWORK-2*N,
+     $                      IINFO )
+               IF( IINFO.NE.0 ) THEN
+                  WRITE( NOUNIT, FMT = 9999 )'ZHEEVR(N,V,' // UPLO //
+     $               ')', IINFO, N, JTYPE, IOLDSD
+                  INFO = ABS( IINFO )
+                  IF( IINFO.LT.0 ) THEN
+                     RETURN
+                  ELSE
+                     RESULT( NTEST ) = ULPINV
+                     GO TO 1190
+                  END IF
+               END IF
+*
+               IF( M3.EQ.0 .AND. N.GT.0 ) THEN
+                  RESULT( NTEST ) = ULPINV
+                  GO TO 1190
+               END IF
+*
+*              Do test 52 (or +??)
+*
+               TEMP1 = DSXT1( 1, WA2, M2, WA3, M3, ABSTOL, ULP, UNFL )
+               TEMP2 = DSXT1( 1, WA3, M3, WA2, M2, ABSTOL, ULP, UNFL )
+               IF( N.GT.0 ) THEN
+                  TEMP3 = MAX( ABS( WA1( 1 ) ), ABS( WA1( N ) ) )
+               ELSE
+                  TEMP3 = ZERO
+               END IF
+               RESULT( NTEST ) = ( TEMP1+TEMP2 ) /
+     $                           MAX( UNFL, TEMP3*ULP )
+*
+               CALL ZLACPY( ' ', N, N, V, LDU, A, LDA )
+*
+*
+*
+*
+*              Load array V with the upper or lower triangular part
+*              of the matrix in band form.
+*
+ 1190          CONTINUE
+*
+ 1200       CONTINUE
 *
 *           End of Loop -- Check for RESULT(j) > THRESH
 *
@@ -1577,8 +2025,8 @@
             CALL DLAFTS( 'ZST', N, N, JTYPE, NTEST, RESULT, IOLDSD,
      $                   THRESH, NOUNIT, NERRS )
 *
-  950    CONTINUE
-  960 CONTINUE
+ 1210    CONTINUE
+ 1220 CONTINUE
 *
 *     Summary
 *
