@@ -1,9 +1,9 @@
       SUBROUTINE ZGET37( RMAX, LMAX, NINFO, KNT, NIN )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     February 29, 1992
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       INTEGER            KNT, NIN
@@ -41,9 +41,9 @@
 *          If ZTRSNA returns INFO nonzero on example i, LMAX(3)=i
 *
 *  NINFO   (output) INTEGER array, dimension (3)
-*          NINFO(1) = 1 if ZGEHRD returned INFO nonzero
-*          NINFO(2) = 1 if ZHSEQR returned INFO nonzero
-*          NINFO(3) = 1 if ZTRSNA returned INFO nonzero
+*          NINFO(1) = No. of times ZGEHRD returned INFO nonzero
+*          NINFO(2) = No. of times ZHSEQR returned INFO nonzero
+*          NINFO(3) = No. of times ZTRSNA returned INFO nonzero
 *
 *  KNT     (output) INTEGER
 *          Total number of examples tested.
@@ -147,7 +147,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 1 ) = KNT
             NINFO( 1 ) = NINFO( 1 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 60 J = 1, N - 2
             DO 50 I = J + 2, N
@@ -162,7 +162,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 2 ) = KNT
             NINFO( 2 ) = NINFO( 2 ) + 1
-            RETURN
+            GO TO 260
          END IF
 *
 *        Compute eigenvectors
@@ -180,7 +180,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
 *
 *        Sort eigenvalues and condition numbers lexicographically
@@ -259,7 +259,8 @@
             END IF
             IF( VMAX.GT.RMAX( 2 ) ) THEN
                RMAX( 2 ) = VMAX
-               LMAX( 2 ) = KNT
+               IF( NINFO( 2 ).EQ.0 )
+     $            LMAX( 2 ) = KNT
             END IF
   120    CONTINUE
 *
@@ -292,7 +293,8 @@
             END IF
             IF( VMAX.GT.RMAX( 2 ) ) THEN
                RMAX( 2 ) = VMAX
-               LMAX( 2 ) = KNT
+               IF( NINFO( 2 ).EQ.0 )
+     $            LMAX( 2 ) = KNT
             END IF
   130    CONTINUE
 *
@@ -316,7 +318,8 @@
             END IF
             IF( VMAX.GT.RMAX( 3 ) ) THEN
                RMAX( 3 ) = VMAX
-               LMAX( 3 ) = KNT
+               IF( NINFO( 3 ).EQ.0 )
+     $            LMAX( 3 ) = KNT
             END IF
   140    CONTINUE
 *
@@ -339,7 +342,8 @@
             END IF
             IF( VMAX.GT.RMAX( 3 ) ) THEN
                RMAX( 3 ) = VMAX
-               LMAX( 3 ) = KNT
+               IF( NINFO( 3 ).EQ.0 )
+     $            LMAX( 3 ) = KNT
             END IF
   150    CONTINUE
 *
@@ -354,7 +358,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 160 I = 1, N
             IF( STMP( I ).NE.S( I ) )
@@ -372,7 +376,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 170 I = 1, N
             IF( STMP( I ).NE.DUM( 1 ) )
@@ -393,7 +397,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 190 I = 1, N
             IF( SEPTMP( I ).NE.SEP( I ) )
@@ -411,7 +415,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 200 I = 1, N
             IF( STMP( I ).NE.S( I ) )
@@ -429,7 +433,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 210 I = 1, N
             IF( STMP( I ).NE.DUM( 1 ) )
@@ -439,7 +443,8 @@
   210    CONTINUE
          IF( VMAX.GT.RMAX( 1 ) ) THEN
             RMAX( 1 ) = VMAX
-            LMAX( 1 ) = KNT
+            IF( NINFO( 1 ).EQ.0 )
+     $         LMAX( 1 ) = KNT
          END IF
 *
 *        Select second and next to last eigenvalues
@@ -472,7 +477,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 230 I = 1, ICMP
             J = LCMP( I )
@@ -491,7 +496,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 240 I = 1, ICMP
             J = LCMP( I )
@@ -510,7 +515,7 @@
          IF( INFO.NE.0 ) THEN
             LMAX( 3 ) = KNT
             NINFO( 3 ) = NINFO( 3 ) + 1
-            RETURN
+            GO TO 260
          END IF
          DO 250 I = 1, ICMP
             J = LCMP( I )
@@ -521,7 +526,8 @@
   250    CONTINUE
          IF( VMAX.GT.RMAX( 1 ) ) THEN
             RMAX( 1 ) = VMAX
-            LMAX( 1 ) = KNT
+            IF( NINFO( 1 ).EQ.0 )
+     $         LMAX( 1 ) = KNT
          END IF
   260 CONTINUE
       GO TO 10
