@@ -1,20 +1,21 @@
-      SUBROUTINE CCHKGB( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NRHS,
-     $                   THRESH, TSTERR, A, LA, AFAC, LAFAC, B, X, XACT,
-     $                   WORK, RWORK, IWORK, NOUT )
+      SUBROUTINE CCHKGB( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NNS,
+     $                   NSVAL, THRESH, TSTERR, A, LA, AFAC, LAFAC, B,
+     $                   X, XACT, WORK, RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
-      INTEGER            LA, LAFAC, NM, NN, NNB, NOUT, NRHS
+      INTEGER            LA, LAFAC, NM, NN, NNB, NNS, NOUT
       REAL               THRESH
 *     ..
 *     .. Array Arguments ..
       LOGICAL            DOTYPE( * )
-      INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NVAL( * )
+      INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NSVAL( * ),
+     $                   NVAL( * )
       REAL               RWORK( * )
       COMPLEX            A( * ), AFAC( * ), B( * ), WORK( * ), X( * ),
      $                   XACT( * )
@@ -51,9 +52,11 @@
 *  NBVAL   (input) INTEGER array, dimension (NBVAL)
 *          The values of the blocksize NB.
 *
-*  NRHS    (input) INTEGER
-*          The number of right hand side vectors to be generated for
-*          each linear system.
+*  NNS     (input) INTEGER
+*          The number of values of NRHS contained in the vector NSVAL.
+*
+*  NSVAL   (input) INTEGER array, dimension (NNS)
+*          The values of the number of right hand sides NRHS.
 *
 *  THRESH  (input) REAL
 *          The threshold value for the test ratios.  A result is
@@ -67,29 +70,29 @@
 *
 *  LA      (input) INTEGER
 *          The length of the array A.  LA >= (KLMAX+KUMAX+1)*NMAX
-*          where KLMAX is the largest entry in local array KLVAL,
-*                KUMAX is the largest entry in local array KUVAL, and
-*                NMAX is the largest entry in input array NVAL.
+*          where KLMAX is the largest entry in the local array KLVAL,
+*                KUMAX is the largest entry in the local array KUVAL and
+*                NMAX is the largest entry in the input array NVAL.
 *
 *  AFAC    (workspace) COMPLEX array, dimension (LAFAC)
 *
 *  LAFAC   (input) INTEGER
 *          The length of the array AFAC. LAFAC >= (2*KLMAX+KUMAX+1)*NMAX
-*          where KLMAX is the largest entry in local array KLVAL,
-*                KUMAX is the largest entry in local array KUVAL, and
-*                NMAX is the largest entry in input array NVAL.
+*          where KLMAX is the largest entry in the local array KLVAL,
+*                KUMAX is the largest entry in the local array KUVAL and
+*                NMAX is the largest entry in the input array NVAL.
 *
-*  B       (workspace) COMPLEX array, dimension (NMAX*NRHS)
+*  B       (workspace) COMPLEX array, dimension (NMAX*NSMAX)
 *
-*  X       (workspace) COMPLEX array, dimension (NMAX*NRHS)
+*  X       (workspace) COMPLEX array, dimension (NMAX*NSMAX)
 *
-*  XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS)
+*  XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX)
 *
 *  WORK    (workspace) COMPLEX array, dimension
-*                      (NMAX*max(3,NRHS,NMAX))
+*                      (NMAX*max(3,NSMAX,NMAX))
 *
 *  RWORK   (workspace) REAL array, dimension
-*                      (max(NMAX,2*NRHS))
+*                      (max(NMAX,2*NSMAX))
 *
 *  IWORK   (workspace) INTEGER array, dimension (NMAX)
 *
@@ -111,9 +114,9 @@
       CHARACTER          DIST, NORM, TRANS, TYPE, XTYPE
       CHARACTER*3        PATH
       INTEGER            I, I1, I2, IKL, IKU, IM, IMAT, IN, INB, INFO,
-     $                   IOFF, ITRAN, IZERO, J, K, K1, KL, KOFF, KU,
+     $                   IOFF, IRHS, ITRAN, IZERO, J, K, KL, KOFF, KU,
      $                   LDA, LDAFAC, LDB, M, MODE, N, NB, NERRS, NFAIL,
-     $                   NIMAT, NKL, NKU, NRUN, NT
+     $                   NIMAT, NKL, NKU, NRHS, NRUN
       REAL               AINVNM, ANORM, ANORMI, ANORMO, CNDNUM, RCOND,
      $                   RCONDC, RCONDI, RCONDO
 *     ..
@@ -153,7 +156,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'C'
+      PATH( 1: 1 ) = 'Complex precision'
       PATH( 2: 3 ) = 'GB'
       NRUN = 0
       NFAIL = 0
@@ -175,7 +178,7 @@
 *
 *     Do for each value of M in MVAL
 *
-      DO 130 IM = 1, NM
+      DO 160 IM = 1, NM
          M = MVAL( IM )
 *
 *        Set values to use for the lower bandwidth.
@@ -189,7 +192,7 @@
 *
 *        Do for each value of N in NVAL
 *
-         DO 120 IN = 1, NN
+         DO 150 IN = 1, NN
             N = NVAL( IN )
             XTYPE = 'N'
 *
@@ -214,14 +217,14 @@
             IF( M.LE.0 .OR. N.LE.0 )
      $         NIMAT = 1
 *
-            DO 110 IKL = 1, NKL
+            DO 140 IKL = 1, NKL
 *
 *              Do for KL = 0, (5*M+1)/4, (3M-1)/4, and (M+1)/4. This
 *              order makes it easier to skip redundant values for small
 *              values of M.
 *
                KL = KLVAL( IKL )
-               DO 100 IKU = 1, NKU
+               DO 130 IKU = 1, NKU
 *
 *                 Do for KU = 0, (5*N+1)/4, (3N-1)/4, and (N+1)/4. This
 *                 order makes it easier to skip redundant values for
@@ -247,22 +250,22 @@
      $                     N*( 2*KL+KU+1 )
                         NERRS = NERRS + 1
                      END IF
-                     GO TO 100
+                     GO TO 130
                   END IF
 *
-                  DO 90 IMAT = 1, NIMAT
+                  DO 120 IMAT = 1, NIMAT
 *
 *                    Do the tests only if DOTYPE( IMAT ) is true.
 *
                      IF( .NOT.DOTYPE( IMAT ) )
-     $                  GO TO 90
+     $                  GO TO 120
 *
 *                    Skip types 2, 3, or 4 if the matrix size is too
 *                    small.
 *
                      ZEROT = IMAT.GE.2 .AND. IMAT.LE.4
                      IF( ZEROT .AND. N.LT.IMAT-1 )
-     $                  GO TO 90
+     $                  GO TO 120
 *
                      IF( .NOT.ZEROT .OR. .NOT.DOTYPE( 1 ) ) THEN
 *
@@ -287,7 +290,7 @@
                            CALL ALAERH( PATH, 'CLATMS', INFO, 0, ' ', M,
      $                                  N, KL, KU, -1, IMAT, NFAIL,
      $                                  NERRS, NOUT )
-                           GO TO 90
+                           GO TO 120
                         END IF
                      ELSE IF( IZERO.GT.0 ) THEN
 *
@@ -341,7 +344,7 @@
 *
 *                    Do for each blocksize in NBVAL
 *
-                     DO 80 INB = 1, NNB
+                     DO 110 INB = 1, NNB
                         NB = NBVAL( INB )
                         CALL XLAENV( 1, NB )
 *
@@ -368,7 +371,6 @@
 *
                         CALL CGBT01( M, N, KL, KU, A, LDA, AFAC, LDAFAC,
      $                               IWORK, WORK, RESULT( 1 ) )
-                        NT = 1
 *
 *                       Print information about the tests so far that
 *                       did not pass the threshold.
@@ -386,7 +388,7 @@
 *                       first block size or if M .ne. N.
 *
                         IF( INB.GT.1 .OR. M.NE.N )
-     $                     GO TO 80
+     $                     GO TO 110
 *
                         ANORMO = CLANGB( 'O', N, KL, KU, A, LDA, RWORK )
                         ANORMI = CLANGB( 'I', N, KL, KU, A, LDA, RWORK )
@@ -433,21 +435,24 @@
                            RCONDI = ZERO
                         END IF
 *
-                        DO 70 ITRAN = 1, NTRAN
-                           TRANS = TRANSS( ITRAN )
-                           IF( ITRAN.EQ.1 ) THEN
-                              ANORM = ANORMO
-                              RCONDC = RCONDO
-                              NORM = 'O'
-                           ELSE
-                              ANORM = ANORMI
-                              RCONDC = RCONDI
-                              NORM = 'I'
-                           END IF
-                           IF( TRFCON ) THEN
-                              K1 = 7
-                           ELSE
-                              K1 = 2
+*                       Skip the solve tests if the matrix is singular.
+*
+                        IF( TRFCON )
+     $                     GO TO 90
+*
+                        DO 80 IRHS = 1, NNS
+                           NRHS = NSVAL( IRHS )
+                           XTYPE = 'N'
+*
+                           DO 70 ITRAN = 1, NTRAN
+                              TRANS = TRANSS( ITRAN )
+                              IF( ITRAN.EQ.1 ) THEN
+                                 RCONDC = RCONDO
+                                 NORM = 'O'
+                              ELSE
+                                 RCONDC = RCONDI
+                                 NORM = 'I'
+                              END IF
 *
 *+    TEST 2:
 *                             Solve and compute residual for A * X = B.
@@ -509,55 +514,70 @@
      $                                     LDA, B, LDB, X, LDB, XACT,
      $                                     LDB, RWORK, RWORK( NRHS+1 ),
      $                                     RESULT( 5 ) )
-                              NT = 6
-                           END IF
+*
+*                             Print information about the tests that did
+*                             not pass the threshold.
+*
+                              DO 60 K = 2, 6
+                                 IF( RESULT( K ).GE.THRESH ) THEN
+                                    IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                                 CALL ALAHD( NOUT, PATH )
+                                    WRITE( NOUT, FMT = 9996 )TRANS, N,
+     $                                 KL, KU, NRHS, IMAT, K,
+     $                                 RESULT( K )
+                                    NFAIL = NFAIL + 1
+                                 END IF
+   60                         CONTINUE
+                              NRUN = NRUN + 5
+   70                      CONTINUE
+   80                   CONTINUE
 *
 *+    TEST 7:
 *                          Get an estimate of RCOND = 1/CNDNUM.
 *
-                           IF( ITRAN.LE.2 ) THEN
-                              SRNAMT = 'CGBCON'
-                              CALL CGBCON( NORM, N, KL, KU, AFAC,
-     $                                     LDAFAC, IWORK, ANORM, RCOND,
-     $                                     WORK, RWORK, INFO )
+   90                   CONTINUE
+                        DO 100 ITRAN = 1, 2
+                           IF( ITRAN.EQ.1 ) THEN
+                              ANORM = ANORMO
+                              RCONDC = RCONDO
+                              NORM = 'O'
+                           ELSE
+                              ANORM = ANORMI
+                              RCONDC = RCONDI
+                              NORM = 'I'
+                           END IF
+                           SRNAMT = 'CGBCON'
+                           CALL CGBCON( NORM, N, KL, KU, AFAC, LDAFAC,
+     $                                  IWORK, ANORM, RCOND, WORK,
+     $                                  RWORK, INFO )
 *
 *                             Check error code from CGBCON.
 *
-                              IF( INFO.NE.0 )
-     $                           CALL ALAERH( PATH, 'CGBCON', INFO, 0,
-     $                                        NORM, N, N, KL, KU, -1,
-     $                                        IMAT, NFAIL, NERRS, NOUT )
+                           IF( INFO.NE.0 )
+     $                        CALL ALAERH( PATH, 'CGBCON', INFO, 0,
+     $                                     NORM, N, N, KL, KU, -1, IMAT,
+     $                                     NFAIL, NERRS, NOUT )
 *
-                              RESULT( 7 ) = SGET06( RCOND, RCONDC )
-                              NT = 7
-                           END IF
+                           RESULT( 7 ) = SGET06( RCOND, RCONDC )
 *
 *                          Print information about the tests that did
 *                          not pass the threshold.
 *
-                           DO 60 K = K1, NT
-                              IF( RESULT( K ).GE.THRESH ) THEN
-                                 IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
-     $                              CALL ALAHD( NOUT, PATH )
-                                 IF( K.LT.7 ) THEN
-                                    WRITE( NOUT, FMT = 9996 )TRANS, N,
-     $                                 KL, KU, IMAT, K, RESULT( K )
-                                 ELSE
-                                    WRITE( NOUT, FMT = 9995 )NORM, N,
-     $                                 KL, KU, IMAT, K, RESULT( K )
-                                 END IF
-                                 NFAIL = NFAIL + 1
-                              END IF
-   60                      CONTINUE
-                           NRUN = NRUN + NT - K1 + 1
-   70                   CONTINUE
-   80                CONTINUE
-*
-   90             CONTINUE
-  100          CONTINUE
-  110       CONTINUE
-  120    CONTINUE
-  130 CONTINUE
+                           IF( RESULT( 7 ).GE.THRESH ) THEN
+                              IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                           CALL ALAHD( NOUT, PATH )
+                              WRITE( NOUT, FMT = 9995 )NORM, N, KL, KU,
+     $                           IMAT, 7, RESULT( 7 )
+                              NFAIL = NFAIL + 1
+                           END IF
+                           NRUN = NRUN + 1
+  100                   CONTINUE
+  110                CONTINUE
+  120             CONTINUE
+  130          CONTINUE
+  140       CONTINUE
+  150    CONTINUE
+  160 CONTINUE
 *
 *     Print a summary of the results.
 *
