@@ -1,20 +1,21 @@
-      SUBROUTINE CCHKGE( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NRHS,
-     $                   THRESH, TSTERR, NMAX, A, AFAC, AINV, B, X,
-     $                   XACT, WORK, RWORK, IWORK, NOUT )
+      SUBROUTINE CCHKGE( DOTYPE, NM, MVAL, NN, NVAL, NNB, NBVAL, NNS,
+     $                   NSVAL, THRESH, TSTERR, NMAX, A, AFAC, AINV, B,
+     $                   X, XACT, WORK, RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
-      INTEGER            NM, NMAX, NN, NNB, NOUT, NRHS
+      INTEGER            NM, NMAX, NN, NNB, NNS, NOUT
       REAL               THRESH
 *     ..
 *     .. Array Arguments ..
       LOGICAL            DOTYPE( * )
-      INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NVAL( * )
+      INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NSVAL( * ),
+     $                   NVAL( * )
       REAL               RWORK( * )
       COMPLEX            A( * ), AFAC( * ), AINV( * ), B( * ),
      $                   WORK( * ), X( * ), XACT( * )
@@ -51,6 +52,12 @@
 *  NBVAL   (input) INTEGER array, dimension (NBVAL)
 *          The values of the blocksize NB.
 *
+*  NNS     (input) INTEGER
+*          The number of values of NRHS contained in the vector NSVAL.
+*
+*  NSVAL   (input) INTEGER array, dimension (NNS)
+*          The values of the number of right hand sides NRHS.
+*
 *  NRHS    (input) INTEGER
 *          The number of right hand side vectors to be generated for
 *          each linear system.
@@ -73,17 +80,18 @@
 *
 *  AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX)
 *
-*  B       (workspace) COMPLEX array, dimension (NMAX*NRHS)
+*  B       (workspace) COMPLEX array, dimension (NMAX*NSMAX)
+*          where NSMAX is the largest entry in NSVAL.
 *
-*  X       (workspace) COMPLEX array, dimension (NMAX*NRHS)
+*  X       (workspace) COMPLEX array, dimension (NMAX*NSMAX)
 *
-*  XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS)
+*  XACT    (workspace) COMPLEX array, dimension (NMAX*NSMAX)
 *
 *  WORK    (workspace) COMPLEX array, dimension
-*                      (NMAX*max(3,NRHS))
+*                      (NMAX*max(3,NSMAX))
 *
 *  RWORK   (workspace) REAL array, dimension
-*                      (max(2*NMAX,2*NRHS+NWORK))
+*                      (max(2*NMAX,2*NSMAX+NWORK))
 *
 *  IWORK   (workspace) INTEGER array, dimension (NMAX)
 *
@@ -106,9 +114,9 @@
       LOGICAL            TRFCON, ZEROT
       CHARACTER          DIST, NORM, TRANS, TYPE, XTYPE
       CHARACTER*3        PATH
-      INTEGER            I, IM, IMAT, IN, INB, INFO, IOFF, ITRAN, IZERO,
-     $                   K, K1, KL, KU, LDA, LWORK, M, MODE, N, NB,
-     $                   NERRS, NFAIL, NIMAT, NRUN, NT
+      INTEGER            I, IM, IMAT, IN, INB, INFO, IOFF, IRHS, ITRAN,
+     $                   IZERO, K, KL, KU, LDA, LWORK, M, MODE, N, NB,
+     $                   NERRS, NFAIL, NIMAT, NRHS, NRUN, NT
       REAL               AINVNM, ANORM, ANORMI, ANORMO, CNDNUM, DUMMY,
      $                   RCOND, RCONDC, RCONDI, RCONDO
 *     ..
@@ -147,7 +155,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'C'
+      PATH( 1: 1 ) = 'Complex precision'
       PATH( 2: 3 ) = 'GE'
       NRUN = 0
       NFAIL = 0
@@ -165,31 +173,31 @@
 *
 *     Do for each value of M in MVAL
 *
-      DO 90 IM = 1, NM
+      DO 120 IM = 1, NM
          M = MVAL( IM )
          LDA = MAX( 1, M )
 *
 *        Do for each value of N in NVAL
 *
-         DO 80 IN = 1, NN
+         DO 110 IN = 1, NN
             N = NVAL( IN )
             XTYPE = 'N'
             NIMAT = NTYPES
             IF( M.LE.0 .OR. N.LE.0 )
      $         NIMAT = 1
 *
-            DO 70 IMAT = 1, NIMAT
+            DO 100 IMAT = 1, NIMAT
 *
 *              Do the tests only if DOTYPE( IMAT ) is true.
 *
                IF( .NOT.DOTYPE( IMAT ) )
-     $            GO TO 70
+     $            GO TO 100
 *
 *              Skip types 5, 6, or 7 if the matrix size is too small.
 *
                ZEROT = IMAT.GE.5 .AND. IMAT.LE.7
                IF( ZEROT .AND. N.LT.IMAT-4 )
-     $            GO TO 70
+     $            GO TO 100
 *
 *              Set up parameters with CLATB4 and generate a test matrix
 *              with CLATMS.
@@ -207,7 +215,7 @@
                IF( INFO.NE.0 ) THEN
                   CALL ALAERH( PATH, 'CLATMS', INFO, 0, ' ', M, N, -1,
      $                         -1, -1, IMAT, NFAIL, NERRS, NOUT )
-                  GO TO 70
+                  GO TO 100
                END IF
 *
 *              For types 5-7, zero one or more columns of the matrix to
@@ -242,7 +250,7 @@
 *
 *              Do for each blocksize in NBVAL
 *
-               DO 60 INB = 1, NNB
+               DO 90 INB = 1, NNB
                   NB = NBVAL( INB )
                   CALL XLAENV( 1, NB )
 *
@@ -275,6 +283,7 @@
                   IF( M.EQ.N .AND. INFO.EQ.0 ) THEN
                      CALL CLACPY( 'Full', N, N, AFAC, LDA, AINV, LDA )
                      SRNAMT = 'CGETRI'
+                     NRHS = NSVAL( 1 )
                      LWORK = NMAX*MAX( 3, NRHS )
                      CALL CGETRI( N, AINV, LDA, IWORK, WORK, LWORK,
      $                            INFO )
@@ -330,26 +339,25 @@
                   NRUN = NRUN + NT
 *
 *                 Skip the remaining tests if this is not the first
-*                 block size or if M .ne. N.
+*                 block size or if M .ne. N.  Skip the solve tests if
+*                 the matrix is singular.
 *
                   IF( INB.GT.1 .OR. M.NE.N )
-     $               GO TO 60
+     $               GO TO 90
+                  IF( TRFCON )
+     $               GO TO 70
 *
-                  DO 50 ITRAN = 1, NTRAN
-                     TRANS = TRANSS( ITRAN )
-                     IF( ITRAN.EQ.1 ) THEN
-                        ANORM = ANORMO
-                        RCONDC = RCONDO
-                        NORM = 'O'
-                     ELSE
-                        ANORM = ANORMI
-                        RCONDC = RCONDI
-                        NORM = 'I'
-                     END IF
-                     IF( TRFCON ) THEN
-                        K1 = 8
-                     ELSE
-                        K1 = 3
+                  DO 60 IRHS = 1, NNS
+                     NRHS = NSVAL( IRHS )
+                     XTYPE = 'N'
+*
+                     DO 50 ITRAN = 1, NTRAN
+                        TRANS = TRANSS( ITRAN )
+                        IF( ITRAN.EQ.1 ) THEN
+                           RCONDC = RCONDO
+                        ELSE
+                           RCONDC = RCONDI
+                        END IF
 *
 *+    TEST 3
 *                       Solve and compute residual for A * X = B.
@@ -405,56 +413,71 @@
                         CALL CGET07( TRANS, N, NRHS, A, LDA, B, LDA, X,
      $                               LDA, XACT, LDA, RWORK,
      $                               RWORK( NRHS+1 ), RESULT( 6 ) )
-                        NT = 7
-                     END IF
+*
+*                       Print information about the tests that did not
+*                       pass the threshold.
+*
+                        DO 40 K = 3, 7
+                           IF( RESULT( K ).GE.THRESH ) THEN
+                              IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                           CALL ALAHD( NOUT, PATH )
+                              WRITE( NOUT, FMT = 9998 )TRANS, N, NRHS,
+     $                           IMAT, K, RESULT( K )
+                              NFAIL = NFAIL + 1
+                           END IF
+   40                   CONTINUE
+                        NRUN = NRUN + 5
+   50                CONTINUE
+   60             CONTINUE
 *
 *+    TEST 8
 *                    Get an estimate of RCOND = 1/CNDNUM.
 *
-                     IF( ITRAN.LE.2 ) THEN
-                        SRNAMT = 'CGECON'
-                        CALL CGECON( NORM, N, AFAC, LDA, ANORM, RCOND,
-     $                               WORK, RWORK, INFO )
+   70             CONTINUE
+                  DO 80 ITRAN = 1, 2
+                     IF( ITRAN.EQ.1 ) THEN
+                        ANORM = ANORMO
+                        RCONDC = RCONDO
+                        NORM = 'O'
+                     ELSE
+                        ANORM = ANORMI
+                        RCONDC = RCONDI
+                        NORM = 'I'
+                     END IF
+                     SRNAMT = 'CGECON'
+                     CALL CGECON( NORM, N, AFAC, LDA, ANORM, RCOND,
+     $                            WORK, RWORK, INFO )
 *
 *                       Check error code from CGECON.
 *
-                        IF( INFO.NE.0 )
-     $                     CALL ALAERH( PATH, 'CGECON', INFO, 0, NORM,
-     $                                  N, N, -1, -1, -1, IMAT, NFAIL,
-     $                                  NERRS, NOUT )
+                     IF( INFO.NE.0 )
+     $                  CALL ALAERH( PATH, 'CGECON', INFO, 0, NORM, N,
+     $                               N, -1, -1, -1, IMAT, NFAIL, NERRS,
+     $                               NOUT )
 *
 *                       This line is needed on a Sun SPARCstation.
 *
-                        DUMMY = RCOND
+                     DUMMY = RCOND
 *
-                        RESULT( 8 ) = SGET06( RCOND, RCONDC )
-                        NT = 8
-                     END IF
+                     RESULT( 8 ) = SGET06( RCOND, RCONDC )
 *
 *                    Print information about the tests that did not pass
 *                    the threshold.
 *
-                     DO 40 K = K1, NT
-                        IF( RESULT( K ).GE.THRESH ) THEN
-                           IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
-     $                        CALL ALAHD( NOUT, PATH )
-                           IF( K.LT.8 ) THEN
-                              WRITE( NOUT, FMT = 9998 )TRANS, N, NB,
-     $                           IMAT, K, RESULT( K )
-                           ELSE
-                              WRITE( NOUT, FMT = 9997 )NORM, N, NB,
-     $                           IMAT, K, RESULT( K )
-                           END IF
-                           NFAIL = NFAIL + 1
-                        END IF
-   40                CONTINUE
-                     NRUN = NRUN + NT - K1 + 1
-   50             CONTINUE
-   60          CONTINUE
-   70       CONTINUE
+                     IF( RESULT( 8 ).GE.THRESH ) THEN
+                        IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                     CALL ALAHD( NOUT, PATH )
+                        WRITE( NOUT, FMT = 9997 )NORM, N, NB, IMAT, 8,
+     $                     RESULT( 8 )
+                        NFAIL = NFAIL + 1
+                     END IF
+                     NRUN = NRUN + 1
+   80             CONTINUE
+   90          CONTINUE
+  100       CONTINUE
 *
-   80    CONTINUE
-   90 CONTINUE
+  110    CONTINUE
+  120 CONTINUE
 *
 *     Print a summary of the results.
 *
