@@ -1,12 +1,12 @@
       SUBROUTINE CDRVLS( DOTYPE, NM, MVAL, NN, NVAL, NNS, NSVAL, NNB,
      $                   NBVAL, NXVAL, THRESH, TSTERR, A, COPYA, B,
-     $                   COPYB, S, COPYS, TAU, WORK, RWORK, IWORK,
+     $                   COPYB, C, S, COPYS, WORK, RWORK, IWORK,
      $                   NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -18,15 +18,15 @@
       INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NSVAL( * ),
      $                   NVAL( * ), NXVAL( * )
       REAL               COPYS( * ), RWORK( * ), S( * )
-      COMPLEX            A( * ), B( * ), COPYA( * ), COPYB( * ),
-     $                   TAU( * ), WORK( * )
+      COMPLEX            A( * ), B( * ), C( * ), COPYA( * ), COPYB( * ),
+     $                   WORK( * )
 *     ..
 *
 *  Purpose
 *  =======
 *
-*  CDRVLS tests the least squares driver routines CGELS, CGELSX, and
-*  CGELSS.
+*  CDRVLS tests the least squares driver routines CGELS, CGELSX, CGELSS,
+*  CGELSY and CGELSD.
 *
 *  Arguments
 *  =========
@@ -35,6 +35,18 @@
 *          The matrix types to be used for testing.  Matrices of type j
 *          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
 *          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*          The matrix of type j is generated as follows:
+*          j=1: A = U*D*V where U and V are random unitary matrices
+*               and D has random entries (> 0.1) taken from a uniform
+*               distribution (0,1). A is full rank.
+*          j=2: The same of 1, but A is scaled up.
+*          j=3: The same of 1, but A is scaled down.
+*          j=4: A = U*D*V where U and V are random unitary matrices
+*               and D has 3*min(M,N)/4 random entries (> 0.1) taken
+*               from a uniform distribution (0,1) and the remaining
+*               entries set to 0. A is rank-deficient.
+*          j=5: The same of 4, but A is scaled up.
+*          j=6: The same of 5, but A is scaled down.
 *
 *  NM      (input) INTEGER
 *          The number of values of M contained in the vector MVAL.
@@ -79,11 +91,13 @@
 *
 *  COPYA   (workspace) COMPLEX array, dimension (MMAX*NMAX)
 *
-*  B       (workspace) COMPLEX array, dimension (MMAX*NMAX)
-*          where MMAX is the maximum value of M in MVAL and NMAX is the
-*          maximum value of N in NVAL.
+*  B       (workspace) COMPLEX array, dimension (MMAX*NSMAX)
+*          where MMAX is the maximum value of M in MVAL and NSMAX is the
+*          maximum value of NRHS in NSVAL.
 *
-*  COPYB   (workspace) COMPLEX array, dimension (MMAX*NMAX)
+*  COPYB   (workspace) COMPLEX array, dimension (MMAX*NSMAX)
+*
+*  C       (workspace) COMPLEX array, dimension (MMAX*NSMAX)
 *
 *  S       (workspace) REAL array, dimension
 *                      (min(MMAX,NMAX))
@@ -91,10 +105,8 @@
 *  COPYS   (workspace) REAL array, dimension
 *                      (min(MMAX,NMAX))
 *
-*  TAU     (workspace) COMPLEX array, dimension (MMAX)
-*
 *  WORK    (workspace) COMPLEX array, dimension
-*                      (MMAX*NMAX + 4*NMAX + MMAX)
+*                      (MMAX*NMAX + 4*NMAX + MMAX).
 *
 *  RWORK   (workspace) REAL array, dimension (5*NMAX-1)
 *
@@ -107,9 +119,9 @@
 *
 *     .. Parameters ..
       INTEGER            NTESTS
-      PARAMETER          ( NTESTS = 10 )
+      PARAMETER          ( NTESTS = 18 )
       REAL               ONE, ZERO
-      PARAMETER          ( ONE = 1.0E0, ZERO = 0.0E0 )
+      PARAMETER          ( ONE = 1.0E+0, ZERO = 0.0E+0 )
       COMPLEX            CONE, CZERO
       PARAMETER          ( CONE = ( 1.0E+0, 0.0E+0 ),
      $                   CZERO = ( 0.0E+0, 0.0E+0 ) )
@@ -119,7 +131,7 @@
       CHARACTER*3        PATH
       INTEGER            CRANK, I, IM, IN, INB, INFO, INS, IRANK,
      $                   ISCALE, ITRAN, ITYPE, J, K, LDA, LDB, LDWORK,
-     $                   LW, LWORK, M, MNMIN, N, NB, NCOLS, NERRS,
+     $                   LWLSY, LWORK, M, MNMIN, N, NB, NCOLS, NERRS,
      $                   NFAIL, NRHS, NROWS, NRUN, RANK
       REAL               EPS, NORMA, NORMB, RCOND
 *     ..
@@ -128,13 +140,14 @@
       REAL               RESULT( NTESTS )
 *     ..
 *     .. External Functions ..
-      REAL               CQRT12, CQRT14, CQRT17, SASUM, SCNRM2, SLAMCH
-      EXTERNAL           CQRT12, CQRT14, CQRT17, SASUM, SCNRM2, SLAMCH
+      REAL               CQRT12, CQRT14, CQRT17, SASUM, SLAMCH
+      EXTERNAL           CQRT12, CQRT14, CQRT17, SASUM, SLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ALAERH, ALAHD, ALASVM, CERRLS, CGELS, CGELSS,
-     $                   CGELSX, CGEMM, CLACPY, CLARNV, CQRT13, CQRT15,
-     $                   CQRT16, CSSCAL, SAXPY, XLAENV
+      EXTERNAL           ALAERH, ALAHD, ALASVM, CERRLS, CGELS, CGELSD,
+     $                   CGELSS, CGELSX, CGELSY, CGEMM, CLACPY, CLARNV,
+     $                   CQRT13, CQRT15, CQRT16, CSSCAL, SAXPY, SLASRT,
+     $                   XLAENV
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          MAX, MIN, REAL, SQRT
@@ -155,7 +168,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'C'
+      PATH( 1: 1 ) = 'Complex precision'
       PATH( 2: 3 ) = 'LS'
       NRUN = 0
       NFAIL = 0
@@ -173,25 +186,32 @@
 *
       IF( TSTERR )
      $   CALL CERRLS( PATH, NOUT )
+*
+*     Print the header if NM = 0 or NN = 0 and THRESH = 0.
+*
+      IF( ( NM.EQ.0 .OR. NN.EQ.0 ) .AND. THRESH.EQ.ZERO )
+     $   CALL ALAHD( NOUT, PATH )
       INFOT = 0
 *
-      DO 130 IM = 1, NM
+      DO 140 IM = 1, NM
          M = MVAL( IM )
          LDA = MAX( 1, M )
 *
-         DO 120 IN = 1, NN
+         DO 130 IN = 1, NN
             N = NVAL( IN )
             MNMIN = MIN( M, N )
             LDB = MAX( 1, M, N )
 *
-            DO 110 INS = 1, NNS
+            DO 120 INS = 1, NNS
                NRHS = NSVAL( INS )
-               LWORK = MAX( 1, ( M+NRHS )*( N+2 ),
+               LWORK = MAX( 1, ( M+NRHS )*( N+2 ), ( N+NRHS )*( M+2 ),
      $                 M*N+4*MNMIN+MAX( M, N ), 2*N+M )
 *
-               DO 100 IRANK = 1, 2
-                  DO 90 ISCALE = 1, 3
+               DO 110 IRANK = 1, 2
+                  DO 100 ISCALE = 1, 3
                      ITYPE = ( IRANK-1 )*3 + ISCALE
+                     IF( .NOT.DOTYPE( ITYPE ) )
+     $                  GO TO 100
 *
                      IF( IRANK.EQ.1 ) THEN
 *
@@ -201,12 +221,12 @@
 *
                         CALL CQRT13( ISCALE, M, N, COPYA, LDA, NORMA,
      $                               ISEED )
-                        DO 50 INB = 1, NNB
+                        DO 40 INB = 1, NNB
                            NB = NBVAL( INB )
                            CALL XLAENV( 1, NB )
                            CALL XLAENV( 3, NXVAL( INB ) )
 *
-                           DO 40 ITRAN = 1, 2
+                           DO 30 ITRAN = 1, 2
                               IF( ITRAN.EQ.1 ) THEN
                                  TRANS = 'N'
                                  NROWS = M
@@ -216,9 +236,6 @@
                                  NROWS = N
                                  NCOLS = M
                               END IF
-                              LW = MAX( 1, ( NROWS+NRHS )*( NCOLS+2 ),
-     $                             MNMIN+MAX( M, N, NRHS )*
-     $                             MAX( 1, NB ) )
                               LDWORK = MAX( 1, NCOLS )
 *
 *                             Set up a consistent rhs
@@ -226,13 +243,9 @@
                               IF( NCOLS.GT.0 ) THEN
                                  CALL CLARNV( 2, ISEED, NCOLS*NRHS,
      $                                        WORK )
-                                 DO 20 J = 1, NRHS
-                                    CALL CSSCAL( NCOLS,
-     $                                           ONE / SCNRM2( NCOLS,
-     $                                           WORK( ( J-1 )*NCOLS+
-     $                                           1 ), 1 ), WORK( ( J-
-     $                                           1 )*NCOLS+1 ), 1 )
-   20                            CONTINUE
+                                 CALL CSSCAL( NCOLS*NRHS,
+     $                                        ONE / REAL( NCOLS ), WORK,
+     $                                        1 )
                               END IF
                               CALL CGEMM( TRANS, 'No transpose', NROWS,
      $                                    NRHS, NCOLS, CONE, COPYA, LDA,
@@ -250,7 +263,7 @@
                               END IF
                               SRNAMT = 'CGELS '
                               CALL CGELS( TRANS, M, N, NRHS, A, LDA, B,
-     $                                    LDB, WORK, LW, INFO )
+     $                                    LDB, WORK, LWORK, INFO )
 *
                               IF( INFO.NE.0 )
      $                           CALL ALAERH( PATH, 'CGELS ', INFO, 0,
@@ -263,10 +276,10 @@
                               LDWORK = MAX( 1, NROWS )
                               IF( NROWS.GT.0 .AND. NRHS.GT.0 )
      $                           CALL CLACPY( 'Full', NROWS, NRHS,
-     $                                        COPYB, LDB, WORK, LDWORK )
+     $                                        COPYB, LDB, C, LDB )
                               CALL CQRT16( TRANS, M, N, NRHS, COPYA,
-     $                                     LDA, B, LDB, WORK, LDWORK,
-     $                                     RWORK, RESULT( 1 ) )
+     $                                     LDA, B, LDB, C, LDB, RWORK,
+     $                                     RESULT( 1 ) )
 *
                               IF( ( ITRAN.EQ.1 .AND. M.GE.N ) .OR.
      $                            ( ITRAN.EQ.2 .AND. M.LT.N ) ) THEN
@@ -275,20 +288,21 @@
 *
                                  RESULT( 2 ) = CQRT17( TRANS, 1, M, N,
      $                                         NRHS, COPYA, LDA, B, LDB,
-     $                                         COPYB, LDB, WORK, LW )
+     $                                         COPYB, LDB, C, WORK,
+     $                                         LWORK )
                               ELSE
 *
 *                                Solving overdetermined system
 *
                                  RESULT( 2 ) = CQRT14( TRANS, M, N,
      $                                         NRHS, COPYA, LDA, B, LDB,
-     $                                         WORK, LW )
+     $                                         WORK, LWORK )
                               END IF
 *
 *                             Print information about the tests that
 *                             did not pass the threshold.
 *
-                              DO 30 K = 1, 2
+                              DO 20 K = 1, 2
                                  IF( RESULT( K ).GE.THRESH ) THEN
                                     IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                                 CALL ALAHD( NOUT, PATH )
@@ -297,10 +311,10 @@
      $                                 RESULT( K )
                                     NFAIL = NFAIL + 1
                                  END IF
-   30                         CONTINUE
+   20                         CONTINUE
                               NRUN = NRUN + 2
-   40                      CONTINUE
-   50                   CONTINUE
+   30                      CONTINUE
+   40                   CONTINUE
                      END IF
 *
 *                    Generate a matrix of scaling type ISCALE and rank
@@ -312,71 +326,158 @@
 *
 *                    workspace used: MAX(M+MIN(M,N),NRHS*MIN(M,N),2*N+M)
 *
-                     DO 60 J = 1, N
+                     DO 50 J = 1, N
                         IWORK( J ) = 0
-   60                CONTINUE
+   50                CONTINUE
                      LDWORK = MAX( 1, M )
 *
-                     DO 80 INB = 1, NNB
+*                    Test CGELSX
+*
+*                    CGELSX:  Compute the minimum-norm solution X
+*                    to min( norm( A * X - B ) )
+*                    using a complete orthogonal factorization.
+*
+                     CALL CLACPY( 'Full', M, N, COPYA, LDA, A, LDA )
+                     CALL CLACPY( 'Full', M, NRHS, COPYB, LDB, B, LDB )
+*
+                     SRNAMT = 'CGELSX'
+                     CALL CGELSX( M, N, NRHS, A, LDA, B, LDB, IWORK,
+     $                            RCOND, CRANK, WORK, RWORK, INFO )
+*
+                     IF( INFO.NE.0 )
+     $                  CALL ALAERH( PATH, 'CGELSX', INFO, 0, ' ', M, N,
+     $                               NRHS, -1, NB, ITYPE, NFAIL, NERRS,
+     $                               NOUT )
+*
+*                    workspace used: MAX( MNMIN+3*N, 2*MNMIN+NRHS )
+*
+*                    Test 3:  Compute relative error in svd
+*                             workspace: M*N + 4*MIN(M,N) + MAX(M,N)
+*
+                     RESULT( 3 ) = CQRT12( CRANK, CRANK, A, LDA, COPYS,
+     $                             WORK, LWORK, RWORK )
+*
+*                    Test 4:  Compute error in solution
+*                             workspace:  M*NRHS + M
+*
+                     CALL CLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
+     $                            LDWORK )
+                     CALL CQRT16( 'No transpose', M, N, NRHS, COPYA,
+     $                            LDA, B, LDB, WORK, LDWORK, RWORK,
+     $                            RESULT( 4 ) )
+*
+*                    Test 5:  Check norm of r'*A
+*                             workspace: NRHS*(M+N)
+*
+                     RESULT( 5 ) = ZERO
+                     IF( M.GT.CRANK )
+     $                  RESULT( 5 ) = CQRT17( 'No transpose', 1, M, N,
+     $                                NRHS, COPYA, LDA, B, LDB, COPYB,
+     $                                LDB, C, WORK, LWORK )
+*
+*                    Test 6:  Check if x is in the rowspace of A
+*                             workspace: (M+NRHS)*(N+2)
+*
+                     RESULT( 6 ) = ZERO
+*
+                     IF( N.GT.CRANK )
+     $                  RESULT( 6 ) = CQRT14( 'No transpose', M, N,
+     $                                NRHS, COPYA, LDA, B, LDB, WORK,
+     $                                LWORK )
+*
+*                    Print information about the tests that did not
+*                    pass the threshold.
+*
+                     DO 60 K = 3, 6
+                        IF( RESULT( K ).GE.THRESH ) THEN
+                           IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                        CALL ALAHD( NOUT, PATH )
+                           WRITE( NOUT, FMT = 9998 )M, N, NRHS, 0,
+     $                        ITYPE, K, RESULT( K )
+                           NFAIL = NFAIL + 1
+                        END IF
+   60                CONTINUE
+                     NRUN = NRUN + 4
+*
+*                    Loop for testing different block sizes.
+*
+                     DO 90 INB = 1, NNB
                         NB = NBVAL( INB )
                         CALL XLAENV( 1, NB )
                         CALL XLAENV( 3, NXVAL( INB ) )
+*
+*                       Test CGELSY
+*
+*                       CGELSY:  Compute the minimum-norm solution
+*                       X to min( norm( A * X - B ) )
+*                       using the rank-revealing orthogonal
+*                       factorization.
 *
                         CALL CLACPY( 'Full', M, N, COPYA, LDA, A, LDA )
                         CALL CLACPY( 'Full', M, NRHS, COPYB, LDB, B,
      $                               LDB )
 *
-*                       CGELSX:  Compute the minimum-norm solution X to
-*                          min( norm( A * X - B ) )
-*                       using a complete orthogonal factorization.
+*                       Initialize vector IWORK.
 *
-                        SRNAMT = 'CGELSX'
-                        CALL CGELSX( M, N, NRHS, A, LDA, B, LDB, IWORK,
-     $                               RCOND, CRANK, WORK, RWORK, INFO )
+                        DO 70 J = 1, N
+                           IWORK( J ) = 0
+   70                   CONTINUE
 *
+*                       Set LWLSY to the adequate value.
+*
+                        LWLSY = MNMIN + MAX( 2*MNMIN, NB*( N+1 ),
+     $                          MNMIN+NB*NRHS )
+                        LWLSY = MAX( 1, LWLSY )
+*
+                        SRNAMT = 'CGELSY'
+                        CALL CGELSY( M, N, NRHS, A, LDA, B, LDB, IWORK,
+     $                               RCOND, CRANK, WORK, LWLSY, RWORK,
+     $                               INFO )
                         IF( INFO.NE.0 )
-     $                     CALL ALAERH( PATH, 'CGELSX', INFO, 0, ' ', M,
+     $                     CALL ALAERH( PATH, 'CGELSY', INFO, 0, ' ', M,
      $                                  N, NRHS, -1, NB, ITYPE, NFAIL,
      $                                  NERRS, NOUT )
 *
-*                       workspace used: MAX( MNMIN+3*N, 2*MNMIN+NRHS )
+*                       workspace used: 2*MNMIN+NB*NB+NB*MAX(N,NRHS)
 *
-*                       Test 3:  Compute relative error in svd
+*                       Test 7:  Compute relative error in svd
 *                                workspace: M*N + 4*MIN(M,N) + MAX(M,N)
 *
-                        RESULT( 3 ) = CQRT12( CRANK, CRANK, A, LDA,
+                        RESULT( 7 ) = CQRT12( CRANK, CRANK, A, LDA,
      $                                COPYS, WORK, LWORK, RWORK )
 *
-*                       Test 4:  Compute error in solution
+*                       Test 8:  Compute error in solution
 *                                workspace:  M*NRHS + M
 *
                         CALL CLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
      $                               LDWORK )
                         CALL CQRT16( 'No transpose', M, N, NRHS, COPYA,
      $                               LDA, B, LDB, WORK, LDWORK, RWORK,
-     $                               RESULT( 4 ) )
+     $                               RESULT( 8 ) )
 *
-*                       Test 5:  Check norm of r'*A
+*                       Test 9:  Check norm of r'*A
 *                                workspace: NRHS*(M+N)
 *
-                        RESULT( 5 ) = ZERO
+                        RESULT( 9 ) = ZERO
                         IF( M.GT.CRANK )
-     $                     RESULT( 5 ) = CQRT17( 'No transpose', 1, M,
+     $                     RESULT( 9 ) = CQRT17( 'No transpose', 1, M,
      $                                   N, NRHS, COPYA, LDA, B, LDB,
-     $                                   COPYB, LDB, WORK, LWORK )
+     $                                   COPYB, LDB, C, WORK, LWORK )
 *
-*                       Test 6:  Check if x is in the rowspace of A
+*                       Test 10:  Check if x is in the rowspace of A
 *                                workspace: (M+NRHS)*(N+2)
 *
-                        RESULT( 6 ) = ZERO
+                        RESULT( 10 ) = ZERO
 *
                         IF( N.GT.CRANK )
-     $                     RESULT( 6 ) = CQRT14( 'No transpose', M, N,
-     $                                   NRHS, COPYA, LDA, B, LDB, WORK,
-     $                                   LWORK )
+     $                     RESULT( 10 ) = CQRT14( 'No transpose', M, N,
+     $                                    NRHS, COPYA, LDA, B, LDB,
+     $                                    WORK, LWORK )
 *
-*                       CGELSS:  Compute the minimum-norm solution X to
-*                          min( norm( A * X - B ) )
+*                       Test CGELSS
+*
+*                       CGELSS:  Compute the minimum-norm solution
+*                       X to min( norm( A * X - B ) )
 *                       using the SVD.
 *
                         CALL CLACPY( 'Full', M, N, COPYA, LDA, A, LDA )
@@ -395,45 +496,102 @@
 *                       workspace used: 3*min(m,n) +
 *                                       max(2*min(m,n),nrhs,max(m,n))
 *
-*                       Test 7:  Compute relative error in svd
+*                       Test 11:  Compute relative error in svd
 *
                         IF( RANK.GT.0 ) THEN
                            CALL SAXPY( MNMIN, -ONE, COPYS, 1, S, 1 )
-                           RESULT( 7 ) = SASUM( MNMIN, S, 1 ) /
-     $                                   SASUM( MNMIN, COPYS, 1 ) /
-     $                                   ( EPS*REAL( MNMIN ) )
+                           RESULT( 11 ) = SASUM( MNMIN, S, 1 ) /
+     $                                    SASUM( MNMIN, COPYS, 1 ) /
+     $                                    ( EPS*REAL( MNMIN ) )
                         ELSE
-                           RESULT( 7 ) = ZERO
+                           RESULT( 11 ) = ZERO
                         END IF
 *
-*                       Test 8:  Compute error in solution
+*                       Test 12:  Compute error in solution
 *
                         CALL CLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
      $                               LDWORK )
                         CALL CQRT16( 'No transpose', M, N, NRHS, COPYA,
      $                               LDA, B, LDB, WORK, LDWORK, RWORK,
-     $                               RESULT( 8 ) )
+     $                               RESULT( 12 ) )
 *
-*                       Test 9:  Check norm of r'*A
+*                       Test 13:  Check norm of r'*A
 *
-                        RESULT( 9 ) = ZERO
+                        RESULT( 13 ) = ZERO
                         IF( M.GT.CRANK )
-     $                     RESULT( 9 ) = CQRT17( 'No transpose', 1, M,
-     $                                   N, NRHS, COPYA, LDA, B, LDB,
-     $                                   COPYB, LDB, WORK, LWORK )
+     $                     RESULT( 13 ) = CQRT17( 'No transpose', 1, M,
+     $                                    N, NRHS, COPYA, LDA, B, LDB,
+     $                                    COPYB, LDB, C, WORK, LWORK )
 *
-*                       Test 10:  Check if x is in the rowspace of A
+*                       Test 14:  Check if x is in the rowspace of A
 *
-                        RESULT( 10 ) = ZERO
+                        RESULT( 14 ) = ZERO
                         IF( N.GT.CRANK )
-     $                     RESULT( 10 ) = CQRT14( 'No transpose', M, N,
+     $                     RESULT( 14 ) = CQRT14( 'No transpose', M, N,
+     $                                    NRHS, COPYA, LDA, B, LDB,
+     $                                    WORK, LWORK )
+*
+*                       Test CGELSD
+*
+*                       CGELSD:  Compute the minimum-norm solution X
+*                       to min( norm( A * X - B ) ) using a
+*                       divide and conquer SVD.
+*
+                        CALL XLAENV( 9, 25 )
+*
+                        CALL CLACPY( 'Full', M, N, COPYA, LDA, A, LDA )
+                        CALL CLACPY( 'Full', M, NRHS, COPYB, LDB, B,
+     $                               LDB )
+*
+                        SRNAMT = 'CGELSD'
+                        CALL CGELSD( M, N, NRHS, A, LDA, B, LDB, S,
+     $                               RCOND, CRANK, WORK, LWORK, RWORK,
+     $                               IWORK, INFO )
+                        IF( INFO.NE.0 )
+     $                     CALL ALAERH( PATH, 'CGELSD', INFO, 0, ' ', M,
+     $                                  N, NRHS, -1, NB, ITYPE, NFAIL,
+     $                                  NERRS, NOUT )
+*
+*                       Test 15:  Compute relative error in svd
+*
+                        IF( RANK.GT.0 ) THEN
+                           CALL SLASRT( 'D', MNMIN, S, INFO )
+                           CALL SAXPY( MNMIN, -ONE, COPYS, 1, S, 1 )
+                           RESULT( 15 ) = SASUM( MNMIN, S, 1 ) /
+     $                                    SASUM( MNMIN, COPYS, 1 ) /
+     $                                    ( EPS*REAL( MNMIN ) )
+                        ELSE
+                           RESULT( 15 ) = ZERO
+                        END IF
+*
+*                       Test 16:  Compute error in solution
+*
+                        CALL CLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
+     $                               LDWORK )
+                        CALL CQRT16( 'No transpose', M, N, NRHS, COPYA,
+     $                               LDA, B, LDB, WORK, LDWORK, RWORK,
+     $                               RESULT( 16 ) )
+*
+*                       Test 17:  Check norm of r'*A
+*
+                        RESULT( 17 ) = ZERO
+                        IF( M.GT.CRANK )
+     $                     RESULT( 17 ) = CQRT17( 'No transpose', 1, M,
+     $                                    N, NRHS, COPYA, LDA, B, LDB,
+     $                                    COPYB, LDB, C, WORK, LWORK )
+*
+*                       Test 18:  Check if x is in the rowspace of A
+*
+                        RESULT( 18 ) = ZERO
+                        IF( N.GT.CRANK )
+     $                     RESULT( 18 ) = CQRT14( 'No transpose', M, N,
      $                                    NRHS, COPYA, LDA, B, LDB,
      $                                    WORK, LWORK )
 *
 *                       Print information about the tests that did not
 *                       pass the threshold.
 *
-                        DO 70 K = 3, 10
+                        DO 80 K = 7, NTESTS
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALAHD( NOUT, PATH )
@@ -441,15 +599,15 @@
      $                           ITYPE, K, RESULT( K )
                               NFAIL = NFAIL + 1
                            END IF
-   70                   CONTINUE
-                        NRUN = NRUN + 8
+   80                   CONTINUE
+                        NRUN = NRUN + 12
 *
-   80                CONTINUE
-   90             CONTINUE
-  100          CONTINUE
-  110       CONTINUE
-  120    CONTINUE
-  130 CONTINUE
+   90                CONTINUE
+  100             CONTINUE
+  110          CONTINUE
+  120       CONTINUE
+  130    CONTINUE
+  140 CONTINUE
 *
 *     Print a summary of the results.
 *
@@ -459,6 +617,7 @@
      $      ', NB=', I4, ', type', I2, ', test(', I2, ')=', G12.5 )
  9998 FORMAT( ' M=', I5, ', N=', I5, ', NRHS=', I4, ', NB=', I4,
      $      ', type', I2, ', test(', I2, ')=', G12.5 )
+      RETURN
 *
 *     End of CDRVLS
 *
