@@ -2,10 +2,10 @@
      $                   A, AFAC, ASAV, B, BSAV, X, XACT, S, WORK,
      $                   RWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -136,7 +136,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'C'
+      PATH( 1: 1 ) = 'Complex precision'
       PATH( 2: 3 ) = 'PB'
       NRUN = 0
       NFAIL = 0
@@ -161,7 +161,7 @@
 *
 *     Do for each value of N in NVAL
 *
-      DO 120 IN = 1, NN
+      DO 110 IN = 1, NN
          N = NVAL( IN )
          LDA = MAX( N, 1 )
          XTYPE = 'N'
@@ -177,7 +177,7 @@
          KDVAL( 3 ) = ( 3*N-1 ) / 4
          KDVAL( 4 ) = ( N+1 ) / 4
 *
-         DO 110 IKD = 1, NKD
+         DO 100 IKD = 1, NKD
 *
 *           Do for KD = 0, (5*N+1)/4, (3N-1)/4, and (N+1)/4. This order
 *           makes it easier to skip redundant values for small values
@@ -188,7 +188,7 @@
 *
 *           Do first for UPLO = 'U', then for UPLO = 'L'
 *
-            DO 100 IUPLO = 1, 2
+            DO 90 IUPLO = 1, 2
                KOFF = 1
                IF( IUPLO.EQ.1 ) THEN
                   UPLO = 'U'
@@ -199,18 +199,18 @@
                   PACKIT = 'B'
                END IF
 *
-               DO 90 IMAT = 1, NIMAT
+               DO 80 IMAT = 1, NIMAT
 *
 *                 Do the tests only if DOTYPE( IMAT ) is true.
 *
                   IF( .NOT.DOTYPE( IMAT ) )
-     $               GO TO 90
+     $               GO TO 80
 *
 *                 Skip types 2, 3, or 4 if the matrix size is too small.
 *
                   ZEROT = IMAT.GE.2 .AND. IMAT.LE.4
                   IF( ZEROT .AND. N.LT.IMAT-1 )
-     $               GO TO 90
+     $               GO TO 80
 *
                   IF( .NOT.ZEROT .OR. .NOT.DOTYPE( 1 ) ) THEN
 *
@@ -231,7 +231,7 @@
                         CALL ALAERH( PATH, 'CLATMS', INFO, 0, UPLO, N,
      $                               N, -1, -1, -1, IMAT, NFAIL, NERRS,
      $                               NOUT )
-                        GO TO 90
+                        GO TO 80
                      END IF
                   ELSE IF( IZERO.GT.0 ) THEN
 *
@@ -311,7 +311,7 @@
 *
                   CALL CLACPY( 'Full', KD+1, N, A, LDAB, ASAV, LDAB )
 *
-                  DO 80 IEQUED = 1, 2
+                  DO 70 IEQUED = 1, 2
                      EQUED = EQUEDS( IEQUED )
                      IF( IEQUED.EQ.1 ) THEN
                         NFACT = 3
@@ -319,7 +319,7 @@
                         NFACT = 1
                      END IF
 *
-                     DO 70 IFACT = 1, NFACT
+                     DO 60 IFACT = 1, NFACT
                         FACT = FACTS( IFACT )
                         PREFAC = LSAME( FACT, 'F' )
                         NOFACT = LSAME( FACT, 'N' )
@@ -327,7 +327,7 @@
 *
                         IF( ZEROT ) THEN
                            IF( PREFAC )
-     $                        GO TO 70
+     $                        GO TO 60
                            RCONDC = ZERO
 *
                         ELSE IF( .NOT.LSAME( FACT, 'N' ) ) THEN
@@ -389,7 +389,6 @@
                               RCONDC = ( ONE / ANORM ) / AINVNM
                            END IF
                         END IF
-   30                   CONTINUE
 *
 *                       Restore the matrix A.
 *
@@ -429,9 +428,9 @@
                               CALL ALAERH( PATH, 'CPBSV ', INFO, IZERO,
      $                                     UPLO, N, N, KD, KD, NRHS,
      $                                     IMAT, NFAIL, NERRS, NOUT )
-                              GO TO 50
+                              GO TO 40
                            ELSE IF( INFO.NE.0 ) THEN
-                              GO TO 50
+                              GO TO 40
                            END IF
 *
 *                          Reconstruct matrix from factors and compute
@@ -457,7 +456,7 @@
 *                          Print information about the tests that did
 *                          not pass the threshold.
 *
-                           DO 40 K = 1, NT
+                           DO 30 K = 1, NT
                               IF( RESULT( K ).GE.THRESH ) THEN
                                  IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                              CALL ALADHD( NOUT, PATH )
@@ -465,9 +464,9 @@
      $                              UPLO, N, KD, IMAT, K, RESULT( K )
                                  NFAIL = NFAIL + 1
                               END IF
-   40                      CONTINUE
+   30                      CONTINUE
                            NRUN = NRUN + NT
-   50                      CONTINUE
+   40                      CONTINUE
                         END IF
 *
 *                       --- Test CPBSVX ---
@@ -501,7 +500,7 @@
                            CALL ALAERH( PATH, 'CPBSVX', INFO, IZERO,
      $                                  FACT // UPLO, N, N, KD, KD,
      $                                  NRHS, IMAT, NFAIL, NERRS, NOUT )
-                           GO TO 70
+                           GO TO 60
                         END IF
 *
                         IF( INFO.EQ.0 ) THEN
@@ -556,7 +555,7 @@
 *                       Print information about the tests that did not
 *                       pass the threshold.
 *
-                        DO 60 K = K1, 6
+                        DO 50 K = K1, 6
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALADHD( NOUT, PATH )
@@ -571,14 +570,14 @@
                               END IF
                               NFAIL = NFAIL + 1
                            END IF
-   60                   CONTINUE
+   50                   CONTINUE
                         NRUN = NRUN + 7 - K1
-   70                CONTINUE
-   80             CONTINUE
-   90          CONTINUE
-  100       CONTINUE
-  110    CONTINUE
-  120 CONTINUE
+   60                CONTINUE
+   70             CONTINUE
+   80          CONTINUE
+   90       CONTINUE
+  100    CONTINUE
+  110 CONTINUE
 *
 *     Print a summary of the results.
 *
