@@ -1,11 +1,11 @@
       SUBROUTINE DDRVLS( DOTYPE, NM, MVAL, NN, NVAL, NNS, NSVAL, NNB,
      $                   NBVAL, NXVAL, THRESH, TSTERR, A, COPYA, B,
-     $                   COPYB, S, COPYS, TAU, WORK, IWORK, NOUT )
+     $                   COPYB, C, S, COPYS, WORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -16,15 +16,15 @@
       LOGICAL            DOTYPE( * )
       INTEGER            IWORK( * ), MVAL( * ), NBVAL( * ), NSVAL( * ),
      $                   NVAL( * ), NXVAL( * )
-      DOUBLE PRECISION   A( * ), B( * ), COPYA( * ), COPYB( * ),
-     $                   COPYS( * ), S( * ), TAU( * ), WORK( * )
+      DOUBLE PRECISION   A( * ), B( * ), C( * ), COPYA( * ), COPYB( * ),
+     $                   COPYS( * ), S( * ), WORK( * )
 *     ..
 *
 *  Purpose
 *  =======
 *
-*  DDRVLS tests the least squares driver routines DGELS, SGELSX, and
-*  DGELSS.
+*  DDRVLS tests the least squares driver routines DGELS, SGELSS, SGELSX,
+*  DGELSY and SGELSD.
 *
 *  Arguments
 *  =========
@@ -33,6 +33,18 @@
 *          The matrix types to be used for testing.  Matrices of type j
 *          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
 *          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*          The matrix of type j is generated as follows:
+*          j=1: A = U*D*V where U and V are random orthogonal matrices
+*               and D has random entries (> 0.1) taken from a uniform
+*               distribution (0,1). A is full rank.
+*          j=2: The same of 1, but A is scaled up.
+*          j=3: The same of 1, but A is scaled down.
+*          j=4: A = U*D*V where U and V are random orthogonal matrices
+*               and D has 3*min(M,N)/4 random entries (> 0.1) taken
+*               from a uniform distribution (0,1) and the remaining
+*               entries set to 0. A is rank-deficient.
+*          j=5: The same of 4, but A is scaled up.
+*          j=6: The same of 5, but A is scaled down.
 *
 *  NM      (input) INTEGER
 *          The number of values of M contained in the vector MVAL.
@@ -77,11 +89,13 @@
 *
 *  COPYA   (workspace) DOUBLE PRECISION array, dimension (MMAX*NMAX)
 *
-*  B       (workspace) DOUBLE PRECISION array, dimension (MMAX*NMAX)
-*          where MMAX is the maximum value of M in MVAL and NMAX is the
-*          maximum value of N in NVAL.
+*  B       (workspace) DOUBLE PRECISION array, dimension (MMAX*NSMAX)
+*          where MMAX is the maximum value of M in MVAL and NSMAX is the
+*          maximum value of NRHS in NSVAL.
 *
-*  COPYB   (workspace) DOUBLE PRECISION array, dimension (MMAX*NMAX)
+*  COPYB   (workspace) DOUBLE PRECISION array, dimension (MMAX*NSMAX)
+*
+*  C       (workspace) DOUBLE PRECISION array, dimension (MMAX*NSMAX)
 *
 *  S       (workspace) DOUBLE PRECISION array, dimension
 *                      (min(MMAX,NMAX))
@@ -89,10 +103,8 @@
 *  COPYS   (workspace) DOUBLE PRECISION array, dimension
 *                      (min(MMAX,NMAX))
 *
-*  TAU     (workspace) DOUBLE PRECISION array, dimension (MMAX)
-*
-*  WORK    (workspace) DOUBLE PRECISION array, dimension
-*                      (MMAX*NMAX + 4*NMAX + MMAX)
+*  WORK    (workspace) DOUBLE PRECISION array,
+*                      dimension (MMAX*NMAX + 4*NMAX + MMAX).
 *
 *  IWORK   (workspace) INTEGER array, dimension (NMAX)
 *
@@ -103,7 +115,7 @@
 *
 *     .. Parameters ..
       INTEGER            NTESTS
-      PARAMETER          ( NTESTS = 10 )
+      PARAMETER          ( NTESTS = 18 )
       DOUBLE PRECISION   ONE, ZERO
       PARAMETER          ( ONE = 1.0D+0, ZERO = 0.0D+0 )
 *     ..
@@ -112,8 +124,8 @@
       CHARACTER*3        PATH
       INTEGER            CRANK, I, IM, IN, INB, INFO, INS, IRANK,
      $                   ISCALE, ITRAN, ITYPE, J, K, LDA, LDB, LDWORK,
-     $                   LW, LWORK, M, MNMIN, N, NB, NCOLS, NERRS,
-     $                   NFAIL, NRHS, NROWS, NRUN, RANK
+     $                   LW, LWLSY, LWORK, M, MNMIN, N, NB, NCOLS,
+     $                   NERRS, NFAIL, NRHS, NROWS, NRUN, RANK
       DOUBLE PRECISION   EPS, NORMA, NORMB, RCOND
 *     ..
 *     .. Local Arrays ..
@@ -121,13 +133,14 @@
       DOUBLE PRECISION   RESULT( NTESTS )
 *     ..
 *     .. External Functions ..
-      DOUBLE PRECISION   DASUM, DLAMCH, DNRM2, DQRT12, DQRT14, DQRT17
-      EXTERNAL           DASUM, DLAMCH, DNRM2, DQRT12, DQRT14, DQRT17
+      DOUBLE PRECISION   DASUM, DLAMCH, DQRT12, DQRT14, DQRT17
+      EXTERNAL           DASUM, DLAMCH, DQRT12, DQRT14, DQRT17
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ALAERH, ALAHD, ALASVM, DAXPY, DERRLS, DGELS,
-     $                   DGELSS, DGELSX, DGEMM, DLACPY, DLARNV, DQRT13,
-     $                   DQRT15, DQRT16, DSCAL, XLAENV
+     $                   DGELSD, DGELSS, DGELSX, DGELSY, DGEMM, DLACPY,
+     $                   DLARNV, DLASRT, DQRT13, DQRT15, DQRT16, DSCAL,
+     $                   XLAENV
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          DBLE, MAX, MIN, SQRT
@@ -148,7 +161,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'D'
+      PATH( 1: 1 ) = 'Double precision'
       PATH( 2: 3 ) = 'LS'
       NRUN = 0
       NFAIL = 0
@@ -166,27 +179,34 @@
 *
       IF( TSTERR )
      $   CALL DERRLS( PATH, NOUT )
-      INFOT = 0
 *
-      DO 130 IM = 1, NM
+*     Print the header if NM = 0 or NN = 0 and THRESH = 0.
+*
+      IF( ( NM.EQ.0 .OR. NN.EQ.0 ) .AND. THRESH.EQ.ZERO )
+     $   CALL ALAHD( NOUT, PATH )
+      INFOT = 0
+      CALL XLAENV( 2, 2 )
+*
+      DO 150 IM = 1, NM
          M = MVAL( IM )
          LDA = MAX( 1, M )
 *
-         DO 120 IN = 1, NN
+         DO 140 IN = 1, NN
             N = NVAL( IN )
             MNMIN = MIN( M, N )
             LDB = MAX( 1, M, N )
 *
-            DO 110 INS = 1, NNS
+            DO 130 INS = 1, NNS
                NRHS = NSVAL( INS )
-               LWORK = MAX( 1, ( M+NRHS )*( N+2 ),
-     $                 M*N+4*MNMIN+MAX( M, N ), 2*N+M, 5*MNMIN-1 )
+               LWORK = MAX( 1, ( M+NRHS )*( N+2 ), ( N+NRHS )*( M+2 ),
+     $                 M*N+4*MNMIN+MAX( M, N ),
+     $                 80*MNMIN+MNMIN*MNMIN*2+MNMIN*NRHS )
 *
-               DO 100 IRANK = 1, 2
-                  DO 90 ISCALE = 1, 3
+               DO 120 IRANK = 1, 2
+                  DO 110 ISCALE = 1, 3
                      ITYPE = ( IRANK-1 )*3 + ISCALE
                      IF( .NOT.DOTYPE( ITYPE ) )
-     $                  GO TO 90
+     $                  GO TO 110
 *
                      IF( IRANK.EQ.1 ) THEN
 *
@@ -196,12 +216,12 @@
 *
                         CALL DQRT13( ISCALE, M, N, COPYA, LDA, NORMA,
      $                               ISEED )
-                        DO 50 INB = 1, NNB
+                        DO 40 INB = 1, NNB
                            NB = NBVAL( INB )
                            CALL XLAENV( 1, NB )
                            CALL XLAENV( 3, NXVAL( INB ) )
 *
-                           DO 40 ITRAN = 1, 2
+                           DO 30 ITRAN = 1, 2
                               IF( ITRAN.EQ.1 ) THEN
                                  TRANS = 'N'
                                  NROWS = M
@@ -221,13 +241,9 @@
                               IF( NCOLS.GT.0 ) THEN
                                  CALL DLARNV( 2, ISEED, NCOLS*NRHS,
      $                                        WORK )
-                                 DO 20 J = 1, NRHS
-                                    CALL DSCAL( NCOLS,
-     $                                          ONE / DNRM2( NCOLS,
-     $                                          WORK( ( J-1 )*NCOLS+1 ),
-     $                                          1 ), WORK( ( J-1 )*
-     $                                          NCOLS+1 ), 1 )
-   20                            CONTINUE
+                                 CALL DSCAL( NCOLS*NRHS,
+     $                                       ONE / DBLE( NCOLS ), WORK,
+     $                                       1 )
                               END IF
                               CALL DGEMM( TRANS, 'No transpose', NROWS,
      $                                    NRHS, NCOLS, ONE, COPYA, LDA,
@@ -245,7 +261,7 @@
                               END IF
                               SRNAMT = 'DGELS '
                               CALL DGELS( TRANS, M, N, NRHS, A, LDA, B,
-     $                                    LDB, WORK, LW, INFO )
+     $                                    LDB, WORK, LWORK, INFO )
                               IF( INFO.NE.0 )
      $                           CALL ALAERH( PATH, 'DGELS ', INFO, 0,
      $                                        TRANS, M, N, NRHS, -1, NB,
@@ -257,10 +273,9 @@
                               LDWORK = MAX( 1, NROWS )
                               IF( NROWS.GT.0 .AND. NRHS.GT.0 )
      $                           CALL DLACPY( 'Full', NROWS, NRHS,
-     $                                        COPYB, LDB, WORK, LDWORK )
+     $                                        COPYB, LDB, C, LDB )
                               CALL DQRT16( TRANS, M, N, NRHS, COPYA,
-     $                                     LDA, B, LDB, WORK, LDWORK,
-     $                                     WORK( NROWS*NRHS+1 ),
+     $                                     LDA, B, LDB, C, LDB, WORK,
      $                                     RESULT( 1 ) )
 *
                               IF( ( ITRAN.EQ.1 .AND. M.GE.N ) .OR.
@@ -270,20 +285,21 @@
 *
                                  RESULT( 2 ) = DQRT17( TRANS, 1, M, N,
      $                                         NRHS, COPYA, LDA, B, LDB,
-     $                                         COPYB, LDB, WORK, LW )
+     $                                         COPYB, LDB, C, WORK,
+     $                                         LWORK )
                               ELSE
 *
 *                                Solving overdetermined system
 *
                                  RESULT( 2 ) = DQRT14( TRANS, M, N,
      $                                         NRHS, COPYA, LDA, B, LDB,
-     $                                         WORK, LW )
+     $                                         WORK, LWORK )
                               END IF
 *
 *                             Print information about the tests that
 *                             did not pass the threshold.
 *
-                              DO 30 K = 1, 2
+                              DO 20 K = 1, 2
                                  IF( RESULT( K ).GE.THRESH ) THEN
                                     IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                                 CALL ALAHD( NOUT, PATH )
@@ -292,10 +308,10 @@
      $                                 RESULT( K )
                                     NFAIL = NFAIL + 1
                                  END IF
-   30                         CONTINUE
+   20                         CONTINUE
                               NRUN = NRUN + 2
-   40                      CONTINUE
-   50                   CONTINUE
+   30                      CONTINUE
+   40                   CONTINUE
                      END IF
 *
 *                    Generate a matrix of scaling type ISCALE and rank
@@ -307,70 +323,157 @@
 *
 *                    workspace used: MAX(M+MIN(M,N),NRHS*MIN(M,N),2*N+M)
 *
-                     DO 60 J = 1, N
+*                    Initialize vector IWORK.
+*
+                     DO 50 J = 1, N
                         IWORK( J ) = 0
-   60                CONTINUE
+   50                CONTINUE
                      LDWORK = MAX( 1, M )
 *
-                     DO 80 INB = 1, NNB
+*                    Test DGELSX
+*
+*                    DGELSX:  Compute the minimum-norm solution X
+*                    to min( norm( A * X - B ) )
+*                    using a complete orthogonal factorization.
+*
+                     CALL DLACPY( 'Full', M, N, COPYA, LDA, A, LDA )
+                     CALL DLACPY( 'Full', M, NRHS, COPYB, LDB, B, LDB )
+*
+                     SRNAMT = 'DGELSX'
+                     CALL DGELSX( M, N, NRHS, A, LDA, B, LDB, IWORK,
+     $                            RCOND, CRANK, WORK, INFO )
+                     IF( INFO.NE.0 )
+     $                  CALL ALAERH( PATH, 'DGELSX', INFO, 0, ' ', M, N,
+     $                               NRHS, -1, NB, ITYPE, NFAIL, NERRS,
+     $                               NOUT )
+*
+*                    workspace used: MAX( MNMIN+3*N, 2*MNMIN+NRHS )
+*
+*                    Test 3:  Compute relative error in svd
+*                             workspace: M*N + 4*MIN(M,N) + MAX(M,N)
+*
+                     RESULT( 3 ) = DQRT12( CRANK, CRANK, A, LDA, COPYS,
+     $                             WORK, LWORK )
+*
+*                    Test 4:  Compute error in solution
+*                             workspace:  M*NRHS + M
+*
+                     CALL DLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
+     $                            LDWORK )
+                     CALL DQRT16( 'No transpose', M, N, NRHS, COPYA,
+     $                            LDA, B, LDB, WORK, LDWORK,
+     $                            WORK( M*NRHS+1 ), RESULT( 4 ) )
+*
+*                    Test 5:  Check norm of r'*A
+*                             workspace: NRHS*(M+N)
+*
+                     RESULT( 5 ) = ZERO
+                     IF( M.GT.CRANK )
+     $                  RESULT( 5 ) = DQRT17( 'No transpose', 1, M, N,
+     $                                NRHS, COPYA, LDA, B, LDB, COPYB,
+     $                                LDB, C, WORK, LWORK )
+*
+*                    Test 6:  Check if x is in the rowspace of A
+*                             workspace: (M+NRHS)*(N+2)
+*
+                     RESULT( 6 ) = ZERO
+*
+                     IF( N.GT.CRANK )
+     $                  RESULT( 6 ) = DQRT14( 'No transpose', M, N,
+     $                                NRHS, COPYA, LDA, B, LDB, WORK,
+     $                                LWORK )
+*
+*                    Print information about the tests that did not
+*                    pass the threshold.
+*
+                     DO 60 K = 3, 6
+                        IF( RESULT( K ).GE.THRESH ) THEN
+                           IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                        CALL ALAHD( NOUT, PATH )
+                           WRITE( NOUT, FMT = 9998 )M, N, NRHS, NB,
+     $                        ITYPE, K, RESULT( K )
+                           NFAIL = NFAIL + 1
+                        END IF
+   60                CONTINUE
+                     NRUN = NRUN + 4
+*
+*
+*                    Loop for testing different block sizes.
+*
+                     DO 100 INB = 1, NNB
                         NB = NBVAL( INB )
                         CALL XLAENV( 1, NB )
                         CALL XLAENV( 3, NXVAL( INB ) )
+*
+*                       Test DGELSY
+*
+*                       DGELSY:  Compute the minimum-norm solution X
+*                       to min( norm( A * X - B ) )
+*                       using the rank-revealing orthogonal
+*                       factorization.
+*
+*                       Initialize vector IWORK.
+*
+                        DO 70 J = 1, N
+                           IWORK( J ) = 0
+   70                   CONTINUE
+*
+*                       Set LWLSY to the adequate value.
+*
+                        LWLSY = MAX( 1, MNMIN+2*N+NB*( N+1 ),
+     $                          2*MNMIN+NB*NRHS )
 *
                         CALL DLACPY( 'Full', M, N, COPYA, LDA, A, LDA )
                         CALL DLACPY( 'Full', M, NRHS, COPYB, LDB, B,
      $                               LDB )
 *
-*                       DGELSX:  Compute the minimum-norm solution X to
-*                          min( norm( A * X - B ) )
-*                       using a complete orthogonal factorization.
-*
-                        SRNAMT = 'DGELSX'
-                        CALL DGELSX( M, N, NRHS, A, LDA, B, LDB, IWORK,
-     $                               RCOND, CRANK, WORK, INFO )
+                        SRNAMT = 'DGELSY'
+                        CALL DGELSY( M, N, NRHS, A, LDA, B, LDB, IWORK,
+     $                               RCOND, CRANK, WORK, LWLSY, INFO )
                         IF( INFO.NE.0 )
-     $                     CALL ALAERH( PATH, 'DGELSX', INFO, 0, ' ', M,
+     $                     CALL ALAERH( PATH, 'DGELSY', INFO, 0, ' ', M,
      $                                  N, NRHS, -1, NB, ITYPE, NFAIL,
      $                                  NERRS, NOUT )
 *
-*                       workspace used: MAX( MNMIN+3*N, 2*MNMIN+NRHS )
 *
-*                       Test 3:  Compute relative error in svd
+*                       Test 7:  Compute relative error in svd
 *                                workspace: M*N + 4*MIN(M,N) + MAX(M,N)
 *
-                        RESULT( 3 ) = DQRT12( CRANK, CRANK, A, LDA,
+                        RESULT( 7 ) = DQRT12( CRANK, CRANK, A, LDA,
      $                                COPYS, WORK, LWORK )
 *
-*                       Test 4:  Compute error in solution
+*                       Test 8:  Compute error in solution
 *                                workspace:  M*NRHS + M
 *
                         CALL DLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
      $                               LDWORK )
                         CALL DQRT16( 'No transpose', M, N, NRHS, COPYA,
      $                               LDA, B, LDB, WORK, LDWORK,
-     $                               WORK( M*NRHS+1 ), RESULT( 4 ) )
+     $                               WORK( M*NRHS+1 ), RESULT( 8 ) )
 *
-*                       Test 5:  Check norm of r'*A
+*                       Test 9:  Check norm of r'*A
 *                                workspace: NRHS*(M+N)
 *
-                        RESULT( 5 ) = ZERO
+                        RESULT( 9 ) = ZERO
                         IF( M.GT.CRANK )
-     $                     RESULT( 5 ) = DQRT17( 'No transpose', 1, M,
+     $                     RESULT( 9 ) = DQRT17( 'No transpose', 1, M,
      $                                   N, NRHS, COPYA, LDA, B, LDB,
-     $                                   COPYB, LDB, WORK, LWORK )
+     $                                   COPYB, LDB, C, WORK, LWORK )
 *
-*                       Test 6:  Check if x is in the rowspace of A
+*                       Test 10:  Check if x is in the rowspace of A
 *                                workspace: (M+NRHS)*(N+2)
 *
-                        RESULT( 6 ) = ZERO
+                        RESULT( 10 ) = ZERO
 *
                         IF( N.GT.CRANK )
-     $                     RESULT( 6 ) = DQRT14( 'No transpose', M, N,
-     $                                   NRHS, COPYA, LDA, B, LDB, WORK,
-     $                                   LWORK )
+     $                     RESULT( 10 ) = DQRT14( 'No transpose', M, N,
+     $                                    NRHS, COPYA, LDA, B, LDB,
+     $                                    WORK, LWORK )
 *
-*                       DGELSS:  Compute the minimum-norm solution X to
-*                          min( norm( A * X - B ) )
+*                       Test DGELSS
+*
+*                       DGELSS:  Compute the minimum-norm solution X
+*                       to min( norm( A * X - B ) )
 *                       using the SVD.
 *
                         CALL DLACPY( 'Full', M, N, COPYA, LDA, A, LDA )
@@ -387,45 +490,108 @@
 *                       workspace used: 3*min(m,n) +
 *                                       max(2*min(m,n),nrhs,max(m,n))
 *
-*                       Test 7:  Compute relative error in svd
+*                       Test 11:  Compute relative error in svd
 *
                         IF( RANK.GT.0 ) THEN
                            CALL DAXPY( MNMIN, -ONE, COPYS, 1, S, 1 )
-                           RESULT( 7 ) = DASUM( MNMIN, S, 1 ) /
-     $                                   DASUM( MNMIN, COPYS, 1 ) /
-     $                                   ( EPS*DBLE( MNMIN ) )
+                           RESULT( 11 ) = DASUM( MNMIN, S, 1 ) /
+     $                                    DASUM( MNMIN, COPYS, 1 ) /
+     $                                    ( EPS*DBLE( MNMIN ) )
                         ELSE
-                           RESULT( 7 ) = ZERO
+                           RESULT( 11 ) = ZERO
                         END IF
 *
-*                       Test 8:  Compute error in solution
+*                       Test 12:  Compute error in solution
 *
                         CALL DLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
      $                               LDWORK )
                         CALL DQRT16( 'No transpose', M, N, NRHS, COPYA,
      $                               LDA, B, LDB, WORK, LDWORK,
-     $                               WORK( M*NRHS+1 ), RESULT( 8 ) )
+     $                               WORK( M*NRHS+1 ), RESULT( 12 ) )
 *
-*                       Test 9:  Check norm of r'*A
+*                       Test 13:  Check norm of r'*A
 *
-                        RESULT( 9 ) = ZERO
+                        RESULT( 13 ) = ZERO
                         IF( M.GT.CRANK )
-     $                     RESULT( 9 ) = DQRT17( 'No transpose', 1, M,
-     $                                   N, NRHS, COPYA, LDA, B, LDB,
-     $                                   COPYB, LDB, WORK, LWORK )
+     $                     RESULT( 13 ) = DQRT17( 'No transpose', 1, M,
+     $                                    N, NRHS, COPYA, LDA, B, LDB,
+     $                                    COPYB, LDB, C, WORK, LWORK )
 *
-*                       Test 10:  Check if x is in the rowspace of A
+*                       Test 14:  Check if x is in the rowspace of A
 *
-                        RESULT( 10 ) = ZERO
+                        RESULT( 14 ) = ZERO
                         IF( N.GT.CRANK )
-     $                     RESULT( 10 ) = DQRT14( 'No transpose', M, N,
+     $                     RESULT( 14 ) = DQRT14( 'No transpose', M, N,
+     $                                    NRHS, COPYA, LDA, B, LDB,
+     $                                    WORK, LWORK )
+*
+*                       Test DGELSD
+*
+*                       DGELSD:  Compute the minimum-norm solution X
+*                       to min( norm( A * X - B ) ) using a
+*                       divide and conquer SVD.
+*
+                        CALL XLAENV( 9, 25 )
+*
+*                       Initialize vector IWORK.
+*
+                        DO 80 J = 1, N
+                           IWORK( J ) = 0
+   80                   CONTINUE
+*
+                        CALL DLACPY( 'Full', M, N, COPYA, LDA, A, LDA )
+                        CALL DLACPY( 'Full', M, NRHS, COPYB, LDB, B,
+     $                               LDB )
+*
+                        SRNAMT = 'DGELSD'
+                        CALL DGELSD( M, N, NRHS, A, LDA, B, LDB, S,
+     $                               RCOND, CRANK, WORK, LWORK, IWORK,
+     $                               INFO )
+                        IF( INFO.NE.0 )
+     $                     CALL ALAERH( PATH, 'DGELSD', INFO, 0, ' ', M,
+     $                                  N, NRHS, -1, NB, ITYPE, NFAIL,
+     $                                  NERRS, NOUT )
+*
+*                       Test 15:  Compute relative error in svd
+*
+                        IF( RANK.GT.0 ) THEN
+                           CALL DLASRT( 'D', MNMIN, S, INFO )
+                           CALL DAXPY( MNMIN, -ONE, COPYS, 1, S, 1 )
+                           RESULT( 15 ) = DASUM( MNMIN, S, 1 ) /
+     $                                    DASUM( MNMIN, COPYS, 1 ) /
+     $                                    ( EPS*DBLE( MNMIN ) )
+                        ELSE
+                           RESULT( 15 ) = ZERO
+                        END IF
+*
+*                       Test 16:  Compute error in solution
+*
+                        CALL DLACPY( 'Full', M, NRHS, COPYB, LDB, WORK,
+     $                               LDWORK )
+                        CALL DQRT16( 'No transpose', M, N, NRHS, COPYA,
+     $                               LDA, B, LDB, WORK, LDWORK,
+     $                               WORK( M*NRHS+1 ), RESULT( 16 ) )
+*
+*                       Test 17:  Check norm of r'*A
+*
+                        RESULT( 17 ) = ZERO
+                        IF( M.GT.CRANK )
+     $                     RESULT( 17 ) = DQRT17( 'No transpose', 1, M,
+     $                                    N, NRHS, COPYA, LDA, B, LDB,
+     $                                    COPYB, LDB, C, WORK, LWORK )
+*
+*                       Test 18:  Check if x is in the rowspace of A
+*
+                        RESULT( 18 ) = ZERO
+                        IF( N.GT.CRANK )
+     $                     RESULT( 18 ) = DQRT14( 'No transpose', M, N,
      $                                    NRHS, COPYA, LDA, B, LDB,
      $                                    WORK, LWORK )
 *
 *                       Print information about the tests that did not
 *                       pass the threshold.
 *
-                        DO 70 K = 3, 10
+                        DO 90 K = 7, NTESTS
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALAHD( NOUT, PATH )
@@ -433,15 +599,15 @@
      $                           ITYPE, K, RESULT( K )
                               NFAIL = NFAIL + 1
                            END IF
-   70                   CONTINUE
-                        NRUN = NRUN + 8
+   90                   CONTINUE
+                        NRUN = NRUN + 12
 *
-   80                CONTINUE
-   90             CONTINUE
-  100          CONTINUE
-  110       CONTINUE
-  120    CONTINUE
-  130 CONTINUE
+  100                CONTINUE
+  110             CONTINUE
+  120          CONTINUE
+  130       CONTINUE
+  140    CONTINUE
+  150 CONTINUE
 *
 *     Print a summary of the results.
 *
@@ -451,6 +617,7 @@
      $      ', NB=', I4, ', type', I2, ', test(', I2, ')=', G12.5 )
  9998 FORMAT( ' M=', I5, ', N=', I5, ', NRHS=', I4, ', NB=', I4,
      $      ', type', I2, ', test(', I2, ')=', G12.5 )
+      RETURN
 *
 *     End of DDRVLS
 *
