@@ -2,10 +2,10 @@
      $                   A, AFAC, ASAV, B, BSAV, X, XACT, S, WORK,
      $                   RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -139,7 +139,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'D'
+      PATH( 1: 1 ) = 'Double precision'
       PATH( 2: 3 ) = 'PO'
       NRUN = 0
       NFAIL = 0
@@ -163,7 +163,7 @@
 *
 *     Do for each value of N in NVAL
 *
-      DO 140 IN = 1, NN
+      DO 130 IN = 1, NN
          N = NVAL( IN )
          LDA = MAX( N, 1 )
          XTYPE = 'N'
@@ -171,22 +171,22 @@
          IF( N.LE.0 )
      $      NIMAT = 1
 *
-         DO 130 IMAT = 1, NIMAT
+         DO 120 IMAT = 1, NIMAT
 *
 *           Do the tests only if DOTYPE( IMAT ) is true.
 *
             IF( .NOT.DOTYPE( IMAT ) )
-     $         GO TO 130
+     $         GO TO 120
 *
 *           Skip types 3, 4, or 5 if the matrix size is too small.
 *
             ZEROT = IMAT.GE.3 .AND. IMAT.LE.5
             IF( ZEROT .AND. N.LT.IMAT-2 )
-     $         GO TO 130
+     $         GO TO 120
 *
 *           Do first for UPLO = 'U', then for UPLO = 'L'
 *
-            DO 120 IUPLO = 1, 2
+            DO 110 IUPLO = 1, 2
                UPLO = UPLOS( IUPLO )
 *
 *              Set up parameters with DLATB4 and generate a test matrix
@@ -205,7 +205,7 @@
                IF( INFO.NE.0 ) THEN
                   CALL ALAERH( PATH, 'DLATMS', INFO, 0, UPLO, N, N, -1,
      $                         -1, -1, IMAT, NFAIL, NERRS, NOUT )
-                  GO TO 120
+                  GO TO 110
                END IF
 *
 *              For types 3-5, zero one row and column of the matrix to
@@ -251,7 +251,7 @@
 *
                CALL DLACPY( UPLO, N, N, A, LDA, ASAV, LDA )
 *
-               DO 110 IEQUED = 1, 2
+               DO 100 IEQUED = 1, 2
                   EQUED = EQUEDS( IEQUED )
                   IF( IEQUED.EQ.1 ) THEN
                      NFACT = 3
@@ -259,7 +259,7 @@
                      NFACT = 1
                   END IF
 *
-                  DO 100 IFACT = 1, NFACT
+                  DO 90 IFACT = 1, NFACT
                      FACT = FACTS( IFACT )
                      PREFAC = LSAME( FACT, 'F' )
                      NOFACT = LSAME( FACT, 'N' )
@@ -267,7 +267,7 @@
 *
                      IF( ZEROT ) THEN
                         IF( PREFAC )
-     $                     GO TO 100
+     $                     GO TO 90
                         RCONDC = ZERO
 *
                      ELSE IF( .NOT.LSAME( FACT, 'N' ) ) THEN
@@ -324,7 +324,6 @@
                            RCONDC = ( ONE / ANORM ) / AINVNM
                         END IF
                      END IF
-   60                CONTINUE
 *
 *                    Restore the matrix A.
 *
@@ -359,9 +358,9 @@
                            CALL ALAERH( PATH, 'DPOSV ', INFO, IZERO,
      $                                  UPLO, N, N, -1, -1, NRHS, IMAT,
      $                                  NFAIL, NERRS, NOUT )
-                           GO TO 80
+                           GO TO 70
                         ELSE IF( INFO.NE.0 ) THEN
-                           GO TO 80
+                           GO TO 70
                         END IF
 *
 *                       Reconstruct matrix from factors and compute
@@ -386,7 +385,7 @@
 *                       Print information about the tests that did not
 *                       pass the threshold.
 *
-                        DO 70 K = 1, NT
+                        DO 60 K = 1, NT
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALADHD( NOUT, PATH )
@@ -394,9 +393,9 @@
      $                           N, IMAT, K, RESULT( K )
                               NFAIL = NFAIL + 1
                            END IF
-   70                   CONTINUE
+   60                   CONTINUE
                         NRUN = NRUN + NT
-   80                   CONTINUE
+   70                   CONTINUE
                      END IF
 *
 *                    --- Test DPOSVX ---
@@ -428,7 +427,7 @@
                         CALL ALAERH( PATH, 'DPOSVX', INFO, IZERO,
      $                               FACT // UPLO, N, N, -1, -1, NRHS,
      $                               IMAT, NFAIL, NERRS, NOUT )
-                        GO TO 100
+                        GO TO 90
                      END IF
 *
                      IF( INFO.EQ.0 ) THEN
@@ -481,7 +480,7 @@
 *                    Print information about the tests that did not pass
 *                    the threshold.
 *
-                     DO 90 K = K1, 6
+                     DO 80 K = K1, 6
                         IF( RESULT( K ).GE.THRESH ) THEN
                            IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                        CALL ALADHD( NOUT, PATH )
@@ -494,13 +493,13 @@
                            END IF
                            NFAIL = NFAIL + 1
                         END IF
-   90                CONTINUE
+   80                CONTINUE
                      NRUN = NRUN + 7 - K1
-  100             CONTINUE
-  110          CONTINUE
-  120       CONTINUE
-  130    CONTINUE
-  140 CONTINUE
+   90             CONTINUE
+  100          CONTINUE
+  110       CONTINUE
+  120    CONTINUE
+  130 CONTINUE
 *
 *     Print a summary of the results.
 *
