@@ -2,10 +2,10 @@
      $                   A, AFAC, ASAV, B, BSAV, X, XACT, S, WORK,
      $                   RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
+*  -- LAPACK test routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -142,7 +142,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'S'
+      PATH( 1: 1 ) = 'Single precision'
       PATH( 2: 3 ) = 'GE'
       NRUN = 0
       NFAIL = 0
@@ -166,7 +166,7 @@
 *
 *     Do for each value of N in NVAL
 *
-      DO 100 IN = 1, NN
+      DO 90 IN = 1, NN
          N = NVAL( IN )
          LDA = MAX( N, 1 )
          XTYPE = 'N'
@@ -174,18 +174,18 @@
          IF( N.LE.0 )
      $      NIMAT = 1
 *
-         DO 90 IMAT = 1, NIMAT
+         DO 80 IMAT = 1, NIMAT
 *
 *           Do the tests only if DOTYPE( IMAT ) is true.
 *
             IF( .NOT.DOTYPE( IMAT ) )
-     $         GO TO 90
+     $         GO TO 80
 *
 *           Skip types 5, 6, or 7 if the matrix size is too small.
 *
             ZEROT = IMAT.GE.5 .AND. IMAT.LE.7
             IF( ZEROT .AND. N.LT.IMAT-4 )
-     $         GO TO 90
+     $         GO TO 80
 *
 *           Set up parameters with SLATB4 and generate a test matrix
 *           with SLATMS.
@@ -204,7 +204,7 @@
             IF( INFO.NE.0 ) THEN
                CALL ALAERH( PATH, 'SLATMS', INFO, 0, ' ', N, N, -1, -1,
      $                      -1, IMAT, NFAIL, NERRS, NOUT )
-               GO TO 90
+               GO TO 80
             END IF
 *
 *           For types 5-7, zero one or more columns of the matrix to
@@ -235,7 +235,7 @@
 *
             CALL SLACPY( 'Full', N, N, A, LDA, ASAV, LDA )
 *
-            DO 80 IEQUED = 1, 4
+            DO 70 IEQUED = 1, 4
                EQUED = EQUEDS( IEQUED )
                IF( IEQUED.EQ.1 ) THEN
                   NFACT = 3
@@ -243,7 +243,7 @@
                   NFACT = 1
                END IF
 *
-               DO 70 IFACT = 1, NFACT
+               DO 60 IFACT = 1, NFACT
                   FACT = FACTS( IFACT )
                   PREFAC = LSAME( FACT, 'F' )
                   NOFACT = LSAME( FACT, 'N' )
@@ -251,7 +251,7 @@
 *
                   IF( ZEROT ) THEN
                      IF( PREFAC )
-     $                  GO TO 70
+     $                  GO TO 60
                      RCONDO = ZERO
                      RCONDI = ZERO
 *
@@ -330,9 +330,8 @@
                         RCONDI = ( ONE / ANORMI ) / AINVNM
                      END IF
                   END IF
-   30             CONTINUE
 *
-                  DO 60 ITRAN = 1, NTRAN
+                  DO 50 ITRAN = 1, NTRAN
 *
 *                    Do for each value of TRANS.
 *
@@ -403,7 +402,7 @@
 *                       Print information about the tests that did not
 *                       pass the threshold.
 *
-                        DO 40 K = 1, NT
+                        DO 30 K = 1, NT
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALADHD( NOUT, PATH )
@@ -411,7 +410,7 @@
      $                           IMAT, K, RESULT( K )
                               NFAIL = NFAIL + 1
                            END IF
-   40                   CONTINUE
+   30                   CONTINUE
                         NRUN = NRUN + NT
                      END IF
 *
@@ -531,7 +530,7 @@
 *                    the threshold.
 *
                      IF( .NOT.TRFCON ) THEN
-                        DO 50 K = K1, NTESTS
+                        DO 40 K = K1, NTESTS
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALADHD( NOUT, PATH )
@@ -545,7 +544,7 @@
                               END IF
                               NFAIL = NFAIL + 1
                            END IF
-   50                   CONTINUE
+   40                   CONTINUE
                         NRUN = NRUN + 7 - K1
                      ELSE
                         IF( RESULT( 1 ).GE.THRESH .AND. .NOT.PREFAC )
@@ -591,11 +590,11 @@
 *
                      END IF
 *
-   60             CONTINUE
-   70          CONTINUE
-   80       CONTINUE
-   90    CONTINUE
-  100 CONTINUE
+   50             CONTINUE
+   60          CONTINUE
+   70       CONTINUE
+   80    CONTINUE
+   90 CONTINUE
 *
 *     Print a summary of the results.
 *
