@@ -2,10 +2,10 @@
      $                   ALPHAR, ALPHAI, BETA, Q, LDQ, Z, LDZ, WORK,
      $                   LWORK, INFO )
 *
-*  -- LAPACK routine (instrumented to count operations, version 2.0) --
+*  -- LAPACK routine (instrumented to count operations, version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       CHARACTER          COMPQ, COMPZ, JOB
@@ -99,7 +99,8 @@
 *  ILO     (input) INTEGER
 *  IHI     (input) INTEGER
 *          It is assumed that A is already upper triangular in rows and
-*          columns 1:ILO-1 and IHI+1:N.  ILO >= 1 and IHI <= N.
+*          columns 1:ILO-1 and IHI+1:N.
+*          1 <= ILO <= IHI <= N, if N > 0; ILO=1 and IHI=0, if N=0.
 *
 *  A       (input/output) DOUBLE PRECISION array, dimension (LDA, N)
 *          On entry, the N-by-N upper Hessenberg matrix A.  Elements
@@ -184,13 +185,17 @@
 *          The leading dimension of the array Z.  LDZ >= 1.
 *          If COMPZ='V' or 'I', then LDZ >= N.
 *
-*  WORK    (workspace) DOUBLE PRECISION array, dimension (LWORK)
-*          On exit, if INFO is not negative, WORK(1) returns the optimal
-*          LWORK.
+*  WORK    (workspace/output) DOUBLE PRECISION array, dimension (LWORK)
+*          On exit, if INFO >= 0, WORK(1) returns the optimal LWORK.
 *
 *  LWORK   (input) INTEGER
 *          The dimension of the array WORK.  LWORK >= max(1,N).
 *
+*          If LWORK = -1, then a workspace query is assumed; the routine
+*          only calculates the optimal size of the WORK array, returns
+*          this value as the first entry of the WORK array, and no error
+*          message related to LWORK is issued by XERBLA.
+*
 *  INFO    (output) INTEGER
 *          = 0: successful exit
 *          < 0: if INFO = -i, the i-th argument had an illegal value
@@ -220,7 +225,8 @@
      $                   SAFETY = 1.0D+2 )
 *     ..
 *     .. Local Scalars ..
-      LOGICAL            ILAZR2, ILAZRO, ILPIVT, ILQ, ILSCHR, ILZ
+      LOGICAL            ILAZR2, ILAZRO, ILPIVT, ILQ, ILSCHR, ILZ,
+     $                   LQUERY
       INTEGER            ICOMPQ, ICOMPZ, IFIRST, IFRSTM, IITER, ILAST,
      $                   ILASTM, IN, ISCHUR, ISTART, J, JC, JCH, JITER,
      $                   JR, MAXIT, NQ, NZ
@@ -299,6 +305,8 @@
 *     Check Argument Values
 *
       INFO = 0
+      WORK( 1 ) = MAX( 1, N )
+      LQUERY = ( LWORK.EQ.-1 )
       IF( ISCHUR.EQ.0 ) THEN
          INFO = -1
       ELSE IF( ICOMPQ.EQ.0 ) THEN
@@ -319,12 +327,14 @@
          INFO = -15
       ELSE IF( LDZ.LT.1 .OR. ( ILZ .AND. LDZ.LT.N ) ) THEN
          INFO = -17
-      ELSE IF( LWORK.LT.MAX( 1, N ) ) THEN
+      ELSE IF( LWORK.LT.MAX( 1, N ) .AND. .NOT.LQUERY ) THEN
          INFO = -19
       END IF
       IF( INFO.NE.0 ) THEN
          CALL XERBLA( 'DHGEQZ', -INFO )
          RETURN
+      ELSE IF( LQUERY ) THEN
+         RETURN
       END IF
 *
 *     Quick return if possible
@@ -471,15 +481,21 @@
 *
                ILAZR2 = .FALSE.
                IF( .NOT.ILAZRO ) THEN
-                  IF( ABS( A( J, J-1 ) )*( ASCALE*ABS( A( J+1,
-     $                J ) ) ).LE.ABS( A( J, J ) )*( ASCALE*ATOL ) )
-     $                ILAZR2 = .TRUE.
+                  TEMP = ABS( A( J, J-1 ) )
+                  TEMP2 = ABS( A( J, J ) )
+                  TEMPR = MAX( TEMP, TEMP2 )
+                  IF( TEMPR.LT.ONE .AND. TEMPR.NE.ZERO ) THEN
+                     TEMP = TEMP / TEMPR
+                     TEMP2 = TEMP2 / TEMPR
+                  END IF
+                  IF( TEMP*( ASCALE*ABS( A( J+1, J ) ) ).LE.TEMP2*
+     $                ( ASCALE*ATOL ) )ILAZR2 = .TRUE.
                END IF
 *
 *              If both tests pass (1 & 2), i.e., the leading diagonal
-*              entry of B in the block is zero, split a 1x1 block off
+*              element of B in the block is zero, split a 1x1 block off
 *              at the top. (I.e., at the J-th row/column) The leading
-*              diagonal entry of the remainder can also be zero, so
+*              diagonal element of the remainder can also be zero, so
 *              this may have to be done repeatedly.
 *
                IF( ILAZRO .OR. ILAZR2 ) THEN
@@ -705,9 +721,15 @@
 *
          DO 120 J = ILAST - 1, IFIRST + 1, -1
             ISTART = J
-            IF( ABS( ( S1*A( J, J-1 ) )*( ASCALE*A( J+1, J ) ) ).LE.
-     $          ABS( S1*A( J, J )-WR*B( J, J ) )*( ASCALE*ATOL ) )
-     $          GO TO 130
+            TEMP = ABS( S1*A( J, J-1 ) )
+            TEMP2 = ABS( S1*A( J, J )-WR*B( J, J ) )
+            TEMPR = MAX( TEMP, TEMP2 )
+            IF( TEMPR.LT.ONE .AND. TEMPR.NE.ZERO ) THEN
+               TEMP = TEMP / TEMPR
+               TEMP2 = TEMP2 / TEMPR
+            END IF
+            IF( ABS( ( ASCALE*A( J+1, J ) )*TEMP ).LE.( ASCALE*ATOL )*
+     $          TEMP2 )GO TO 130
   120    CONTINUE
 *
          ISTART = IFIRST
@@ -871,7 +893,7 @@
             A22 = A( ILAST, ILAST )
 *
 *           Compute complex Givens rotation on right
-*           (Assume some entry of C = (sA - wB) > unfl )
+*           (Assume some element of C = (sA - wB) > unfl )
 *                            __
 *           (sA - wB) ( CZ   -SZ )
 *                     ( SZ    CZ )
