@@ -1,13 +1,13 @@
       SUBROUTINE ZTIM26( LINE, NSIZES, NN, MM, NTYPES, DOTYPE, NPARMS,
      $                   NNB, LDAS, TIMMIN, NOUT, ISEED, A, H, U, VT, D,
      $                   DC, E, EC, TAUP, TAUQ, WORK, LWORK, RWORK,
-     $                   LLWORK, TIMES, LDT1, LDT2, LDT3, OPCNTS, LDO1,
-     $                   LDO2, LDO3, INFO )
+     $                   IWORK, LLWORK, TIMES, LDT1, LDT2, LDT3, OPCNTS,
+     $                   LDO1, LDO2, LDO3, INFO )
 *
-*  -- LAPACK timing routine (version 2.0) --
+*  -- LAPACK timing routine (version 3.0) --
 *     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
 *     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*     June 30, 1999
 *
 *     .. Scalar Arguments ..
       CHARACTER*80       LINE
@@ -17,8 +17,8 @@
 *     ..
 *     .. Array Arguments ..
       LOGICAL            DOTYPE( * ), LLWORK( * )
-      INTEGER            ISEED( * ), LDAS( * ), MM( * ), NN( * ),
-     $                   NNB( * )
+      INTEGER            ISEED( * ), IWORK( * ), LDAS( * ), MM( * ),
+     $                   NN( * ), NNB( * )
       DOUBLE PRECISION   D( * ), E( * ), OPCNTS( LDO1, LDO2, LDO3, * ),
      $                   RWORK( * ), TIMES( LDT1, LDT2, LDT3, * )
       COMPLEX*16         A( * ), DC( * ), EC( * ), H( * ), TAUP( * ),
@@ -79,19 +79,24 @@
 *                                       left singular vectors and N
 *                                       right singular vectors)
 *              (labeled LAPSVD(B) in the output)
+*          12: ZGESDD (singular values and min(M,N) left singular
+*                      vectors and N right singular vectors if M>=N,
+*                      singular values and M left singular vectors
+*                      and min(M,N) right singular vectors otherwise.)
+*              (labeled ZGESDD(B) in the output)
 *          LINPACK:
-*          12: ZSVDC (singular values only) (comparable to 7 above)
+*          13: ZSVDC (singular values only) (comparable to 7 above)
 *              (labeled LINSVD in the output)
-*          13: ZSVDC (singular values and min(M,N) left singular
+*          14: ZSVDC (singular values and min(M,N) left singular
 *                     vectors) (comparable to 8 above)
 *              (labeled LINSVD(l) in the output)
-*          14: ZSVDC (singular values and M left singular vectors)
+*          15: ZSVDC (singular values and M left singular vectors)
 *                     (comparable to 9 above)
 *              (labeled LINSVD(L) in the output)
-*          15: ZSVDC (singular values and N right singular vectors)
+*          16: ZSVDC (singular values and N right singular vectors)
 *                     (comparable to 10 above)
 *              (labeled LINSVD(R) in the output)
-*          16: ZSVDC (singular values and min(M,N) left singular
+*          17: ZSVDC (singular values and min(M,N) left singular
 *                     vectors and N right singular vectors)
 *                     (comparable to 11 above)
 *              (labeled LINSVD(B) in the output)
@@ -216,6 +221,8 @@
 *  RWORK   (workspace) DOUBLE PRECISION array, dimension( LWORK )
 *          May be equivalenced to WORK in calling routine.
 *
+*  IWORK   (workspace) INTEGER array, dimension at least 8*min(M,N).
+*
 *  LLWORK  (workspace) LOGICAL array, dimension( NPARMS ),
 *
 *  TIMES   (output) DOUBLE PRECISION array,
@@ -255,19 +262,19 @@
 *
 *     .. Parameters ..
       INTEGER            MAXTYP, NSUBS
-      PARAMETER          ( MAXTYP = 5, NSUBS = 16 )
+      PARAMETER          ( MAXTYP = 5, NSUBS = 17 )
       DOUBLE PRECISION   ZERO, ONE, TWO
-      PARAMETER          ( ZERO = 0.0D+0, ONE = 1.0D+0, TWO = 2.0D+0 )
+      PARAMETER          ( ZERO = 0.0D0, ONE = 1.0D0, TWO = 2.0D0 )
       COMPLEX*16         CONE, CTWO
-      PARAMETER          ( CONE = ( 1.0D+0, 0.0D+0 ),
-     $                   CTWO = ( 2.0D+0, 0.0D+0 ) )
+      PARAMETER          ( CONE = ( 1.0D0, 0.0D0 ),
+     $                   CTWO = ( 2.0D0, 0.0D0 ) )
 *     ..
 *     .. Local Scalars ..
       LOGICAL            RUNBRD, TRNBRD
       CHARACTER          UPLO
-      INTEGER            IC, IINFO, IMODE, IN, IPAR, IQU, IQVT, ISUB,
-     $                   ITYPE, J, J1, J2, J3, J4, KU, KVT, LASTNL, LDA,
-     $                   LDH, M, MAXMN, MINMN, MTYPES, N, NB
+      INTEGER            IC, IINFO, IMODE, IN, IPAR, ISUB, ITYPE, J, J1,
+     $                   J2, J3, J4, KU, KVT, LASTNL, LDA, M, MINMN,
+     $                   MTYPES, N, NB
       DOUBLE PRECISION   CONDS, S1, S2, TIME, ULP, ULPINV, UNTIME
 *     ..
 *     .. Local Arrays ..
@@ -284,7 +291,8 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ATIMIN, DCOPY, DPRTBV, XLAENV, ZBDSQR, ZGEBRD,
-     $                   ZLACPY, ZLASET, ZLATMR, ZLATMS, ZSVDC, ZUNGBR
+     $                   ZGESDD, ZLACPY, ZLASET, ZLATMR, ZLATMS, ZSVDC,
+     $                   ZUNGBR
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, DBLE, EXP, LOG, MAX, MIN
@@ -299,11 +307,11 @@
       DATA               SUBNAM / 'ZGEBRD', 'ZBDSQR', 'ZBDSQR(L)',
      $                   'ZBDSQR(R)', 'ZBDSQR(B)', 'ZBDSQR(V)',
      $                   'LAPSVD', 'LAPSVD(l)', 'LAPSVD(L)',
-     $                   'LAPSVD(R)', 'LAPSVD(B)', 'LINSVD',
-     $                   'LINSVD(l)', 'LINSVD(L)', 'LINSVD(R)',
-     $                   'LINSVD(B)' /
-      DATA               INPARM / 2, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 1, 1,
-     $                   1, 1, 1 /
+     $                   'LAPSVD(R)', 'LAPSVD(B)', 'ZGESDD(B)',
+     $                   'LINSVD', 'LINSVD(l)', 'LINSVD(L)',
+     $                   'LINSVD(R)', 'LINSVD(B)' /
+      DATA               INPARM / 2, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 1,
+     $                   1, 1, 1, 1 /
       DATA               PNAMES / 'LDA', 'NB' /
       DATA               KMODE / 4, 3, 1 /
 *     ..
@@ -354,6 +362,7 @@
 *
       ULP = DLAMCH( 'Epsilon' )*DLAMCH( 'Base' )
       ULPINV = ONE / ULP
+      CALL XLAENV( 9, 25 )
 *
 *     Zero out OPCNTS, TIMES
 *
@@ -370,28 +379,19 @@
 *
 *     Do for each value of N:
 *
-      DO 680 IN = 1, NSIZES
+      DO 710 IN = 1, NSIZES
 *
          N = NN( IN )
          M = MM( IN )
          MINMN = MIN( M, N )
-         MAXMN = MAX( M, N )
          IF( M.GE.N ) THEN
             UPLO = 'U'
             KU = MINMN
             KVT = MAX( MINMN-1, 0 )
-            IQU = 0
-            IQVT = 1
-            IF( N.EQ.0 )
-     $         IQVT = 0
          ELSE
             UPLO = 'L'
             KU = MAX( MINMN-1, 0 )
             KVT = MINMN
-            IQU = 1
-            IQVT = 0
-            IF( M.EQ.0 )
-     $         IQU = 0
          END IF
 *
 *        Do for each .TRUE. value in DOTYPE:
@@ -399,9 +399,9 @@
          MTYPES = MIN( MAXTYP, NTYPES )
          IF( NTYPES.EQ.MAXTYP+1 .AND. NSIZES.EQ.1 )
      $      MTYPES = NTYPES
-         DO 670 ITYPE = 1, MTYPES
+         DO 700 ITYPE = 1, MTYPES
             IF( .NOT.DOTYPE( ITYPE ) )
-     $         GO TO 670
+     $         GO TO 700
 *
 *           Save random number seed for error messages
 *
@@ -474,7 +474,7 @@
                      WRITE( NOUT, FMT = 9998 )SUBNAM( 1 ), IINFO, M, N,
      $                  ITYPE, IPAR, IOLDSD
                      INFO = ABS( IINFO )
-                     GO TO 670
+                     GO TO 700
                   END IF
 *
                   S2 = DSECND( )
@@ -497,7 +497,6 @@
                   OPCNTS( IPAR, ITYPE, IN, 1 ) = DOPLA( 'ZGEBRD', M, N,
      $               0, 0, NB )
   130          CONTINUE
-               LDH = LDA
             ELSE
                IF( RUNBRD ) THEN
                   CALL ZLACPY( 'Full', M, N, A, M, H, M )
@@ -507,9 +506,8 @@
                      WRITE( NOUT, FMT = 9998 )SUBNAM( 1 ), IINFO, M, N,
      $                  ITYPE, 0, IOLDSD
                      INFO = ABS( IINFO )
-                     GO TO 670
+                     GO TO 700
                   END IF
-                  LDH = M
                END IF
             END IF
 *
@@ -547,7 +545,7 @@
                         WRITE( NOUT, FMT = 9998 )SUBNAM( 2 ), IINFO, M,
      $                     N, ITYPE, IPAR, IOLDSD
                         INFO = ABS( IINFO )
-                        GO TO 670
+                        GO TO 700
                      END IF
                      S2 = DSECND( )
                      TIME = S2 - S1
@@ -615,7 +613,7 @@
                         WRITE( NOUT, FMT = 9998 )SUBNAM( 3 ), IINFO, M,
      $                     N, ITYPE, IPAR, IOLDSD
                         INFO = ABS( IINFO )
-                        GO TO 670
+                        GO TO 700
                      END IF
                      S2 = DSECND( )
                      TIME = S2 - S1
@@ -686,7 +684,7 @@
                         WRITE( NOUT, FMT = 9998 )SUBNAM( 4 ), IINFO, M,
      $                     N, ITYPE, IPAR, IOLDSD
                         INFO = ABS( IINFO )
-                        GO TO 670
+                        GO TO 700
                      END IF
                      S2 = DSECND( )
                      TIME = S2 - S1
@@ -759,7 +757,7 @@
                         WRITE( NOUT, FMT = 9998 )SUBNAM( 5 ), IINFO, M,
      $                     N, ITYPE, IPAR, IOLDSD
                         INFO = ABS( IINFO )
-                        GO TO 670
+                        GO TO 700
                      END IF
                      S2 = DSECND( )
                      TIME = S2 - S1
@@ -833,7 +831,7 @@
                         WRITE( NOUT, FMT = 9998 )SUBNAM( 6 ), IINFO, M,
      $                     N, ITYPE, IPAR, IOLDSD
                         INFO = ABS( IINFO )
-                        GO TO 670
+                        GO TO 700
                      END IF
                      S2 = DSECND( )
                      TIME = S2 - S1
@@ -904,7 +902,7 @@
                      WRITE( NOUT, FMT = 9998 )SUBNAM( 8 ), IINFO, M, N,
      $                  ITYPE, IPAR, IOLDSD
                      INFO = ABS( IINFO )
-                     GO TO 670
+                     GO TO 700
                   END IF
                   S2 = DSECND( )
                   TIME = S2 - S1
@@ -955,7 +953,7 @@
                      WRITE( NOUT, FMT = 9998 )SUBNAM( 9 ), IINFO, M, N,
      $                  ITYPE, IPAR, IOLDSD
                      INFO = ABS( IINFO )
-                     GO TO 670
+                     GO TO 700
                   END IF
                   S2 = DSECND( )
                   TIME = S2 - S1
@@ -1006,7 +1004,7 @@
                      WRITE( NOUT, FMT = 9998 )SUBNAM( 10 ), IINFO, M,
      $                  N, ITYPE, IPAR, IOLDSD
                      INFO = ABS( IINFO )
-                     GO TO 670
+                     GO TO 700
                   END IF
                   S2 = DSECND( )
                   TIME = S2 - S1
@@ -1059,7 +1057,7 @@
                      WRITE( NOUT, FMT = 9998 )SUBNAM( 11 ), IINFO, M,
      $                  N, ITYPE, IPAR, IOLDSD
                      INFO = ABS( IINFO )
-                     GO TO 670
+                     GO TO 700
                   END IF
                   CALL ZLACPY( 'U', MINMN, N, H, LDA, VT, LDA )
                   CALL ZUNGBR( 'P', N, N, KVT, VT, LDA, TAUP, WORK,
@@ -1068,7 +1066,7 @@
                      WRITE( NOUT, FMT = 9998 )SUBNAM( 11 ), IINFO, M,
      $                  N, ITYPE, IPAR, IOLDSD
                      INFO = ABS( IINFO )
-                     GO TO 670
+                     GO TO 700
                   END IF
                   S2 = DSECND( )
                   TIME = S2 - S1
@@ -1095,21 +1093,74 @@
   460          CONTINUE
             END IF
 *
-*           Time ZSVDC (singular values only) for each pair
+*           Time ZGESDD( singular values and min(M,N) left singular
+*           vectors and N right singular vectors when M>=N,
+*           singular values and M left singular vectors and min(M,N)
+*           right singular vectors otherwise) for each pair
 *           NNB(j), LDAS(j)
 *
             IF( TIMSUB( 12 ) ) THEN
-               DO 500 IPAR = 1, NPARMS
+               DO 490 IPAR = 1, NPARMS
+                  LDA = LDAS( IPAR )
+                  NB = MIN( N, NNB( IPAR ) )
+                  CALL XLAENV( 1, NB )
+                  CALL XLAENV( 2, 2 )
+                  CALL XLAENV( 3, NB )
+*
+*                 Time ZGESDD (singular values and
+*                 min(M,N) left singular vectors and N right singular
+*                 vectors)
+*
+                  IC = 0
+                  OPS = ZERO
+                  S1 = DSECND( )
+  470             CONTINUE
+                  CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
+                  CALL ZGESDD( 'S', M, N, H, LDA, RWORK, U, LDA, VT,
+     $                         LDA, WORK, LWORK, RWORK( 2*MINMN+1 ),
+     $                         IWORK, IINFO )
+                  S2 = DSECND( )
+                  IF( IINFO.NE.0 ) THEN
+                     WRITE( NOUT, FMT = 9998 )SUBNAM( 12 ), IINFO, M,
+     $                  N, ITYPE, IPAR, IOLDSD
+                     INFO = ABS( IINFO )
+                     GO TO 700
+                  END IF
+                  TIME = S2 - S1
+                  IC = IC + 1
+                  IF( TIME.LT.TIMMIN )
+     $               GO TO 470
+*
+*                 Subtract the time used in ZLACPY.
+*
+                  S1 = DSECND( )
+                  DO 480 J = 1, IC
+                     CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
+  480             CONTINUE
+                  S2 = DSECND( )
+                  UNTIME = S2 - S1
+*
+                  TIMES( IPAR, ITYPE, IN, 12 ) = MAX( TIME-UNTIME,
+     $               ZERO ) / DBLE( IC )
+                  OPCNTS( IPAR, ITYPE, IN, 12 ) = OPS / DBLE( IC )
+  490          CONTINUE
+            END IF
+*
+*           Time ZSVDC (singular values only) for each pair
+*           NNB(j), LDAS(j)
+*
+            IF( TIMSUB( 13 ) ) THEN
+               DO 530 IPAR = 1, NPARMS
                   LDA = LDAS( IPAR )
 *
 *                 If this value of LDA has been used before, just
 *                 use that value
 *
                   LASTNL = 0
-                  DO 470 J = 1, IPAR - 1
+                  DO 500 J = 1, IPAR - 1
                      IF( LDA.EQ.LDAS( J ) )
      $                  LASTNL = J
-  470             CONTINUE
+  500             CONTINUE
 *
                   IF( LASTNL.EQ.0 ) THEN
 *
@@ -1118,91 +1169,28 @@
                      IC = 0
                      OPS = ZERO
                      S1 = DSECND( )
-  480                CONTINUE
+  510                CONTINUE
                      CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
                      CALL ZSVDC( H, LDA, M, N, DC, EC, U, LDA, VT, LDA,
      $                           WORK, 0, IINFO )
-                     IF( IINFO.NE.0 ) THEN
-                        WRITE( NOUT, FMT = 9998 )SUBNAM( 12 ), IINFO,
-     $                     M, N, ITYPE, IPAR, IOLDSD
-                        INFO = ABS( IINFO )
-                        GO TO 670
-                     END IF
-                     S2 = DSECND( )
-                     TIME = S2 - S1
-                     IC = IC + 1
-                     IF( TIME.LT.TIMMIN )
-     $                  GO TO 480
-*
-*                    Subtract the time used in ZLACPY.
-*
-                     S1 = DSECND( )
-                     DO 490 J = 1, IC
-                        CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
-  490                CONTINUE
-                     S2 = DSECND( )
-                     UNTIME = S2 - S1
-*
-                     TIMES( IPAR, ITYPE, IN, 12 ) = MAX( TIME-UNTIME,
-     $                  ZERO ) / DBLE( IC )
-                     OPCNTS( IPAR, ITYPE, IN, 12 ) = OPS / DBLE( IC )
-*
-                  ELSE
-*
-                     TIMES( IPAR, ITYPE, IN, 12 ) = TIMES( LASTNL,
-     $                  ITYPE, IN, 12 )
-                     OPCNTS( IPAR, ITYPE, IN, 12 ) = OPCNTS( LASTNL,
-     $                  ITYPE, IN, 12 )
-                  END IF
-  500          CONTINUE
-            END IF
-*
-*           Time ZSVDC (singular values and min(M,N) left singular
-*           vectors) for each pair NNB(j), LDAS(j)
-*
-            IF( TIMSUB( 13 ) ) THEN
-               DO 540 IPAR = 1, NPARMS
-                  LDA = LDAS( IPAR )
-*
-*                 If this value of LDA has been used before, just
-*                 use that value
-*
-                  LASTNL = 0
-                  DO 510 J = 1, IPAR - 1
-                     IF( LDA.EQ.LDAS( J ) )
-     $                  LASTNL = J
-  510             CONTINUE
-*
-                  IF( LASTNL.EQ.0 ) THEN
-*
-*                    Time ZSVDC (singular values and min(M,N) left
-*                    singular vectors)
-*
-                     IC = 0
-                     OPS = ZERO
-                     S1 = DSECND( )
-  520                CONTINUE
-                     CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
-                     CALL ZSVDC( H, LDA, M, N, DC, EC, U, LDA, VT, LDA,
-     $                           WORK, 20, IINFO )
                      IF( IINFO.NE.0 ) THEN
                         WRITE( NOUT, FMT = 9998 )SUBNAM( 13 ), IINFO,
      $                     M, N, ITYPE, IPAR, IOLDSD
                         INFO = ABS( IINFO )
-                        GO TO 670
+                        GO TO 700
                      END IF
                      S2 = DSECND( )
                      TIME = S2 - S1
                      IC = IC + 1
                      IF( TIME.LT.TIMMIN )
-     $                  GO TO 520
+     $                  GO TO 510
 *
 *                    Subtract the time used in ZLACPY.
 *
                      S1 = DSECND( )
-                     DO 530 J = 1, IC
+                     DO 520 J = 1, IC
                         CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
-  530                CONTINUE
+  520                CONTINUE
                      S2 = DSECND( )
                      UNTIME = S2 - S1
 *
@@ -1217,55 +1205,55 @@
                      OPCNTS( IPAR, ITYPE, IN, 13 ) = OPCNTS( LASTNL,
      $                  ITYPE, IN, 13 )
                   END IF
-  540          CONTINUE
+  530          CONTINUE
             END IF
 *
-*           Time ZSVDC (singular values and M left singular
+*           Time ZSVDC (singular values and min(M,N) left singular
 *           vectors) for each pair NNB(j), LDAS(j)
 *
             IF( TIMSUB( 14 ) ) THEN
-               DO 580 IPAR = 1, NPARMS
+               DO 570 IPAR = 1, NPARMS
                   LDA = LDAS( IPAR )
 *
 *                 If this value of LDA has been used before, just
 *                 use that value
 *
                   LASTNL = 0
-                  DO 550 J = 1, IPAR - 1
+                  DO 540 J = 1, IPAR - 1
                      IF( LDA.EQ.LDAS( J ) )
      $                  LASTNL = J
-  550             CONTINUE
+  540             CONTINUE
 *
                   IF( LASTNL.EQ.0 ) THEN
 *
-*                    Time ZSVDC (singular values and M left singular
-*                    vectors)
+*                    Time ZSVDC (singular values and min(M,N) left
+*                    singular vectors)
 *
                      IC = 0
                      OPS = ZERO
                      S1 = DSECND( )
-  560                CONTINUE
+  550                CONTINUE
                      CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
                      CALL ZSVDC( H, LDA, M, N, DC, EC, U, LDA, VT, LDA,
-     $                           WORK, 10, IINFO )
+     $                           WORK, 20, IINFO )
                      IF( IINFO.NE.0 ) THEN
                         WRITE( NOUT, FMT = 9998 )SUBNAM( 14 ), IINFO,
      $                     M, N, ITYPE, IPAR, IOLDSD
                         INFO = ABS( IINFO )
-                        GO TO 670
+                        GO TO 700
                      END IF
                      S2 = DSECND( )
                      TIME = S2 - S1
                      IC = IC + 1
                      IF( TIME.LT.TIMMIN )
-     $                  GO TO 560
+     $                  GO TO 550
 *
 *                    Subtract the time used in ZLACPY.
 *
                      S1 = DSECND( )
-                     DO 570 J = 1, IC
+                     DO 560 J = 1, IC
                         CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
-  570                CONTINUE
+  560                CONTINUE
                      S2 = DSECND( )
                      UNTIME = S2 - S1
 *
@@ -1280,55 +1268,55 @@
                      OPCNTS( IPAR, ITYPE, IN, 14 ) = OPCNTS( LASTNL,
      $                  ITYPE, IN, 14 )
                   END IF
-  580          CONTINUE
+  570          CONTINUE
             END IF
 *
-*           Time ZSVDC (singular values and N right singular
+*           Time ZSVDC (singular values and M left singular
 *           vectors) for each pair NNB(j), LDAS(j)
 *
             IF( TIMSUB( 15 ) ) THEN
-               DO 620 IPAR = 1, NPARMS
+               DO 610 IPAR = 1, NPARMS
                   LDA = LDAS( IPAR )
 *
 *                 If this value of LDA has been used before, just
 *                 use that value
 *
                   LASTNL = 0
-                  DO 590 J = 1, IPAR - 1
+                  DO 580 J = 1, IPAR - 1
                      IF( LDA.EQ.LDAS( J ) )
      $                  LASTNL = J
-  590             CONTINUE
+  580             CONTINUE
 *
                   IF( LASTNL.EQ.0 ) THEN
 *
-*                    Time ZSVDC (singular values and N right singular
+*                    Time ZSVDC (singular values and M left singular
 *                    vectors)
 *
                      IC = 0
                      OPS = ZERO
                      S1 = DSECND( )
-  600                CONTINUE
+  590                CONTINUE
                      CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
                      CALL ZSVDC( H, LDA, M, N, DC, EC, U, LDA, VT, LDA,
-     $                           WORK, 1, IINFO )
+     $                           WORK, 10, IINFO )
                      IF( IINFO.NE.0 ) THEN
-                        WRITE( NOUT, FMT = 9998 )SUBNAM( 15 ), IINFO,
+                        WRITE( NOUT, FMT = 9998 )SUBNAM( 14 ), IINFO,
      $                     M, N, ITYPE, IPAR, IOLDSD
                         INFO = ABS( IINFO )
-                        GO TO 670
+                        GO TO 700
                      END IF
                      S2 = DSECND( )
                      TIME = S2 - S1
                      IC = IC + 1
                      IF( TIME.LT.TIMMIN )
-     $                  GO TO 600
+     $                  GO TO 590
 *
 *                    Subtract the time used in ZLACPY.
 *
                      S1 = DSECND( )
-                     DO 610 J = 1, IC
+                     DO 600 J = 1, IC
                         CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
-  610                CONTINUE
+  600                CONTINUE
                      S2 = DSECND( )
                      UNTIME = S2 - S1
 *
@@ -1343,56 +1331,55 @@
                      OPCNTS( IPAR, ITYPE, IN, 15 ) = OPCNTS( LASTNL,
      $                  ITYPE, IN, 15 )
                   END IF
-  620          CONTINUE
+  610          CONTINUE
             END IF
 *
-*           Time ZSVDC (singular values and min(M,N) left singular
-*           vectors and N right singular vectors) for each pair
-*           NNB(j), LDAS(j)
+*           Time ZSVDC (singular values and N right singular
+*           vectors) for each pair NNB(j), LDAS(j)
 *
             IF( TIMSUB( 16 ) ) THEN
-               DO 660 IPAR = 1, NPARMS
+               DO 650 IPAR = 1, NPARMS
                   LDA = LDAS( IPAR )
 *
 *                 If this value of LDA has been used before, just
 *                 use that value
 *
                   LASTNL = 0
-                  DO 630 J = 1, IPAR - 1
+                  DO 620 J = 1, IPAR - 1
                      IF( LDA.EQ.LDAS( J ) )
      $                  LASTNL = J
-  630             CONTINUE
+  620             CONTINUE
 *
                   IF( LASTNL.EQ.0 ) THEN
 *
-*                    Time ZSVDC (singular values and min(M,N) left
-*                    singular vectors and N right singular vectors)
+*                    Time ZSVDC (singular values and N right singular
+*                    vectors)
 *
                      IC = 0
                      OPS = ZERO
                      S1 = DSECND( )
-  640                CONTINUE
+  630                CONTINUE
                      CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
                      CALL ZSVDC( H, LDA, M, N, DC, EC, U, LDA, VT, LDA,
-     $                           WORK, 21, IINFO )
+     $                           WORK, 1, IINFO )
                      IF( IINFO.NE.0 ) THEN
-                        WRITE( NOUT, FMT = 9998 )SUBNAM( 16 ), IINFO,
+                        WRITE( NOUT, FMT = 9998 )SUBNAM( 15 ), IINFO,
      $                     M, N, ITYPE, IPAR, IOLDSD
                         INFO = ABS( IINFO )
-                        GO TO 670
+                        GO TO 700
                      END IF
                      S2 = DSECND( )
                      TIME = S2 - S1
                      IC = IC + 1
                      IF( TIME.LT.TIMMIN )
-     $                  GO TO 640
+     $                  GO TO 630
 *
 *                    Subtract the time used in ZLACPY.
 *
                      S1 = DSECND( )
-                     DO 650 J = 1, IC
+                     DO 640 J = 1, IC
                         CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
-  650                CONTINUE
+  640                CONTINUE
                      S2 = DSECND( )
                      UNTIME = S2 - S1
 *
@@ -1407,17 +1394,81 @@
                      OPCNTS( IPAR, ITYPE, IN, 16 ) = OPCNTS( LASTNL,
      $                  ITYPE, IN, 16 )
                   END IF
-  660          CONTINUE
+  650          CONTINUE
             END IF
 *
-  670    CONTINUE
-  680 CONTINUE
+*           Time ZSVDC (singular values and min(M,N) left singular
+*           vectors and N right singular vectors) for each pair
+*           NNB(j), LDAS(j)
+*
+            IF( TIMSUB( 17 ) ) THEN
+               DO 690 IPAR = 1, NPARMS
+                  LDA = LDAS( IPAR )
+*
+*                 If this value of LDA has been used before, just
+*                 use that value
+*
+                  LASTNL = 0
+                  DO 660 J = 1, IPAR - 1
+                     IF( LDA.EQ.LDAS( J ) )
+     $                  LASTNL = J
+  660             CONTINUE
+*
+                  IF( LASTNL.EQ.0 ) THEN
+*
+*                    Time ZSVDC (singular values and min(M,N) left
+*                    singular vectors and N right singular vectors)
+*
+                     IC = 0
+                     OPS = ZERO
+                     S1 = DSECND( )
+  670                CONTINUE
+                     CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
+                     CALL ZSVDC( H, LDA, M, N, DC, EC, U, LDA, VT, LDA,
+     $                           WORK, 21, IINFO )
+                     IF( IINFO.NE.0 ) THEN
+                        WRITE( NOUT, FMT = 9998 )SUBNAM( 16 ), IINFO,
+     $                     M, N, ITYPE, IPAR, IOLDSD
+                        INFO = ABS( IINFO )
+                        GO TO 700
+                     END IF
+                     S2 = DSECND( )
+                     TIME = S2 - S1
+                     IC = IC + 1
+                     IF( TIME.LT.TIMMIN )
+     $                  GO TO 670
+*
+*                    Subtract the time used in ZLACPY.
+*
+                     S1 = DSECND( )
+                     DO 680 J = 1, IC
+                        CALL ZLACPY( 'Full', M, N, A, M, H, LDA )
+  680                CONTINUE
+                     S2 = DSECND( )
+                     UNTIME = S2 - S1
+*
+                     TIMES( IPAR, ITYPE, IN, 16 ) = MAX( TIME-UNTIME,
+     $                  ZERO ) / DBLE( IC )
+                     OPCNTS( IPAR, ITYPE, IN, 16 ) = OPS / DBLE( IC )
+*
+                  ELSE
+*
+                     TIMES( IPAR, ITYPE, IN, 16 ) = TIMES( LASTNL,
+     $                  ITYPE, IN, 16 )
+                     OPCNTS( IPAR, ITYPE, IN, 16 ) = OPCNTS( LASTNL,
+     $                  ITYPE, IN, 16 )
+                  END IF
+  690          CONTINUE
+            END IF
+*
+  700    CONTINUE
+  710 CONTINUE
 *
 *-----------------------------------------------------------------------
 *
 *     Print a table of results for each timed routine.
 *
-      DO 690 ISUB = 1, NSUBS
+      DO 720 ISUB = 1, NSUBS
          IF( TIMSUB( ISUB ) ) THEN
             CALL DPRTBV( SUBNAM( ISUB ), NTYPES, DOTYPE, NSIZES, MM, NN,
      $                   INPARM( ISUB ), PNAMES, NPARMS, LDAS, NNB,
@@ -1425,7 +1476,7 @@
      $                   TIMES( 1, 1, 1, ISUB ), LDT1, LDT2, RWORK,
      $                   LLWORK, NOUT )
          END IF
-  690 CONTINUE
+  720 CONTINUE
 *
       RETURN
 *
